import QtQuick 2.4

ModalDialog {
    id: root

    property string message: "Notice"
    property bool hideWhen: false // expression that overrides visible setting
    property bool beep: true

    Component.onCompleted: hide()
    onTimedOut: hide()  // hide the pop-up when timer expires

    function showMessage(string, seconds) {
        message = string
        showWithTimeout(seconds)
    }

    function showWithTimeout(seconds) {
        if (beep) {
            buzzer.buttonPress()
        }
        startTimeout(seconds)
        show()
    }

    function show() {
        if (!hideWhen) {
            dialogManager.alertShown(root)
            visible = true
        }
   }

    width: 1000
    height: 58

    Rectangle {   // pop-up dialog background
        id: bannerBackground

        anchors.fill: parent
        color: "#5f6062"
        opacity: 0.5
    }
    Text {
        id: bannerText
        anchors.verticalCenter: bannerBackground.verticalCenter
        anchors.horizontalCenter: bannerBackground.horizontalCenter
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        scale: paintedWidth > (bannerBackground.width-40) ? ((bannerBackground.width - 40)/ paintedWidth) : 1
        height: bannerBackground.height
        width: paintedWidth
        color: "#ffffff"
        text: root.message
        opacity: 0.8
        font.bold: true
        font.pixelSize: 40
    }
}
