import QtQuick 2.4
import "MediaBrowser"
import "."
import Components 1.0

ModalDialog {
    id: root
    property variant list: bluetoothAdapter.scannedHeadSets
    isTop: false
    isTransparent: true
    visible: false
    state: "idle"
    opacity: 1.0
    property bool keysAccepted
    property bool isDiscovering: bluetoothAdapter.nonLeScan
    property bool isLowEnergy: false
    property bool pairingAllowed: true

    signal closed()
    signal deviceConnected()
    signal deviceDisconnected()
    signal headsetConnected()
    signal headsetDisconnected()

    onVisibleChanged: {
        state = "list"
        if(visible) {
            if(isLowEnergy == false){
                if(!bluetoothAdapter.discovering){
                    bluetoothAdapter.startDiscovery(true)
                }
            } else {
                bluetoothLEAdapter.scan()
            }
        } else {
            if(isLowEnergy == false){
                if(bluetoothAdapter.discovering){
                    bluetoothAdapter.stopDiscovery()
                }
            }
        }
    }

    Connections{
        target: workoutScreen
        onWorkoutStopped: {
           hide();
        }
    }

    Connections{
        target: bluetoothAdapter
        onPasskeyAvailable:{
            var text = passkey.toString()
            root.state = "pairing"
            btPairCodeKeyText.text = paddy(text,6)
        }

        onNonLeScanChanged: {
            if(bluetoothAdapter.nonLeScan){
                root.state = "list"
            }
        }

        onPairingChanged: {
            if(pairing) {
                root.state = "gettingpairingcode"
            }
        }

        onPairingComplete: {
            if(result) {
                root.state = "connecting"
            } else {
                root.state = "list"
            }
        }

        onConnectingChanged: {
            if(connecting) {
                root.state = "connecting"
            }
        }

        onPairingHeadsetComplete:{
            if(result) {
                root.state = "connecting"
            } else {
                root.state = "list"
            }
        }

        onConnectionFailed: {
            root.state = "list"
        }

        onConnectedHeadsetChanged:{
            if(connected){
                headsetConnected()
            }
        }

        onDisconnectingHeadset:{
            root.state = "disconnecting"
        }

        onDisconnectingHeadsetComplete:{
            headsetDisconnected()
        }

        onConnectedChanged:{
            if(connected){
                deviceConnected()
            }
        }

        onDisconnecting:{
            root.state = "disconnecting"
        }

        onDisconnectingComplete:{
            deviceDisconnected()
        }

        onPairingCancelling:{
            root.state = "disconnecting"
        }

        onPairingCancelled:{
            root.state = "idle"
        }
    }

    Connections {
        target: main.isTft && !main.blockKeys && root.keysAccepted && root.visible && !btHelpDialog.visible ? keymapper : null

        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "MediaBrowser", "(btStatusDialog)")
            btExitButton.clicked()
        }
    }

    BorderImage {   // pop-up dialog background
        id: btStatusDialogborder

        anchors.fill: root
        anchors.topMargin: -15
        anchors.bottomMargin: -33
        anchors.leftMargin: -14
        anchors.rightMargin: -33

        source: "graphics/Pop_Up_Lrg_Grey.png"
        border { top: height*0.33; bottom: height*0.33; left: width*0.33; right: width*0.33 }

        // This rectangle is to give the GUI component a reference to a drawing area. This
        // was added to allow adjustments for the shadows offset of the graphic border image.
        Rectangle{
            id: referenceArea
            color:"transparent"
            height: parent.height + parent.anchors.topMargin + parent.anchors.bottomMargin
            width: parent.width + parent.anchors.rightMargin + parent.anchors.leftMargin
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.topMargin: -parent.anchors.topMargin
            anchors.leftMargin: -parent.anchors.leftMargin
        }

        Item {
            id: btPairingItems
            visible: false
            anchors.verticalCenter: referenceArea.verticalCenter
            anchors.horizontalCenter: referenceArea.horizontalCenter
            width: referenceArea.width
            height: referenceArea.height

            Text {
                id: btPairCodeText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -implicitHeight / 2
                width: parent.width * 0.50

                color: "white"
                text: qsTr("CONFIRM ON DEVICE:") + application.emptyString
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.14
            }
            Text {
                id: btPairCodeKeyText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: implicitHeight / 2
                width: parent.width * 0.50
                color: "white"
                text: ""
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.14
            }
        }

        Item{
            id: btDeviceListBox
            visible: false
            anchors.verticalCenter: referenceArea.verticalCenter
            anchors.horizontalCenter: referenceArea.horizontalCenter
            width: referenceArea.width
            height: referenceArea.height

            Text{
                id: btSelectDeviceText
                text: qsTr("SELECT YOUR DEVICE:") + application.emptyString
                width: parent.width * 0.6
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: parent.height * 0.08

                color: "white"
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.15
            }

            Item {
                id: scanningAnimation
                height: 58
                width: 108
                anchors.horizontalCenter: parent.left
                anchors.horizontalCenterOffset: 100
                anchors.verticalCenter: parent.verticalCenter

                Image{
                    id: scanningBluetoothWave
                    property int opacityInteger: 0
                    anchors.fill: parent
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    source: "graphics/Bluetooth/Bluetooth_waves.png"
                    opacity: opacityInteger / 100.0
                    visible: waveAnimation.running
                    NumberAnimation on opacityInteger {
                        id: waveAnimation
                        from: 0;
                        to: 100;
                        duration: 500
                        running : isDiscovering
                        loops: Animation.Infinite
                    }
                }
                ImageButton{
                    id: scanningBluetoothIcon
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    upimage: "graphics/Bluetooth/Bluetooth_icon_medium.png"
                    downimage: upimage
                }
            }

            Rectangle {
                id: bluetoothDeviceListBoxBrowser

                visible: root.pairingAllowed
                color: "transparent"
                radius: 10
                width: parent.width * 0.5
                height: 180
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 3
                anchors.horizontalCenter: parent.horizontalCenter

                DeviceListModel {
                    id: deviceListModel
                    base: root.list
                }

                Item {
                    id: clippingItem

                    anchors.fill: parent
                    clip: true
                    height: 180

                    ListView {
                        id: bluetoothDeviceList
                        spacing: main.isTouch ? 20 : 1
                        height: 180
                        anchors.fill: parent
                        anchors.margins: 10

                        Connections {
                            target: main.isTft && !main.blockKeys && root.keysAccepted && root.visible && root.state === "list" && !btHelpDialog.visible ? keymapper : null

                            onUpButtonPressed: {
                                main.debugKeys("upButtonPressed", "MediaBrowser", "(bluetoothDeviceList)")
                                bluetoothDeviceList.decrementCurrentIndex()
                            }

                            onDownButtonPressed: {
                                main.debugKeys("downButtonPressed", "MediaBrowser", "(bluetoothDeviceList)")
                                bluetoothDeviceList.incrementCurrentIndex()
                            }

                            onEnter2Pressed: {
                                main.debugKeys("enter2Pressed", "MediaBrowser", "(bluetoothDeviceList)")
                                bluetoothDeviceList.currentItem.pressed()
                            }
                        }

                        interactive: false
                        //clip: true
                        model: deviceListModel.model
                        Component {
                            id: highlightComponent
                            Rectangle { color: "#5f9e45"; radius: 0 ; opacity: 1.0; width: 410 }
                        }
                        highlight: highlightComponent
                        highlightMoveVelocity: 1500
                        delegate: Component {
                            Item{
                                id: listItem
                                function pressed() {
                                    bluetoothDeviceList.currentIndex = index
                                    var item;
                                    item = bluetoothDeviceList.model.getItem(index);
                                    if (item.dummy) {
                                        switch(item.action){
                                        case "refresh":
                                            //if(!bluetoothAdapter.discovering) bluetoothAdapter.startDiscovery(true)
                                            break
                                        case "help":
                                            btHelpDialog.show()
                                            btHelpDialog.startTimeout(10)
                                            break
                                        }
                                    } else {
                                        root.state = "gettingpairingcode"
                                        bluetoothAdapter.connect(item)
                                    }
                                }
                                height: 40
                                width: parent.width
                                Text {
                                    text: name
                                    color: "white"
                                    font.bold: true
                                    font.family: "sans serif"
                                    font.pixelSize: parent.height * 0.45
                                    verticalAlignment: Text.AlignVCenter
                                    anchors.left: parent.left
                                    anchors.leftMargin: 10
                                    anchors.verticalCenter: parent.verticalCenter
                                    MouseArea {
                                        anchors.fill: parent
                                        onClicked: {
                                            bluetoothDeviceList.currentIndex = index
                                        }
                                    }
                                }
                                ImageButton {
                                    id: selectDeviceButton
                                    visible: main.isTouch
                                    onClicked: listItem.pressed(index)
                                    anchors { top: parent.top; topMargin: -13; right: parent.right }
                                    upimage: "graphics/205/SM_Button_GRAY.png"
                                    downimage: "graphics/205/SM_Button_ORANGE.png"
                                }
                            }
                        }
                    }
                }
            }
            Rectangle {
                id: pairingNotAvailableRect
                visible: !root.pairingAllowed

                color: "transparent"
                radius: 10
                width: parent.width * 0.5
                height: 180
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 3
                anchors.horizontalCenter: parent.horizontalCenter

                Text {
                    id: pairingNotAvailable
                    text: qsTr("Please Wait") + "..." + application.emptyString

                    font.pixelSize: 36
                    font.bold: true
                    color: "white"
                    anchors {
                        top: parent.top; horizontalCenter: parent.horizontalCenter
                        topMargin: 25
                    }
                }


            }
            Column {
                id: btDeviceListArrows

                width: 40
                height: 160
                spacing: 50
                visible: main.isTft && bluetoothDeviceList.model.count > 0
                anchors {
                    left: bluetoothDeviceListBoxBrowser.right
                    verticalCenter: bluetoothDeviceListBoxBrowser.verticalCenter
                }

                Image {
                    id: dataUpArrow
                    visible: bluetoothDeviceList.contentY > 30
                    source: "graphics/Swipe_Arrows_Left.png"
                    rotation: 90
                }
                Image {
                    id: dataDownArrow
                    visible: bluetoothDeviceList.contentHeight - bluetoothDeviceList.height - bluetoothDeviceList.contentY > 10
                    source: "graphics/Swipe_Arrows_Left.png"
                    rotation: -90
                }

            }
        }

        Text {
            id: btGettingPairingCodeText
            visible: false
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width * 0.8
            height: parent.height * 0.5
            color: "white"
            text: qsTr("GETTING PAIRING CODE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.family: "sans serif"
            font.pixelSize: parent.height * 0.15
        }

        Text {
            id: btConnectingText
            visible: false
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width * 0.8
            height: parent.height * 0.5
            color: "white"
            text: qsTr("CONNECTING TO BLUETOOTH DEVICE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.family: "sans serif"
            font.pixelSize: parent.height * 0.15
        }

        Text {
            id: btDisconnectingText
            visible: false
            anchors.verticalCenter: referenceArea.verticalCenter
            anchors.horizontalCenter: referenceArea.horizontalCenter
            width: referenceArea.width * 0.8
            height: referenceArea.height * 0.8
            color: "white"
            text: qsTr("DISCONNECTING FROM BLUETOOTH DEVICE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.family: "sans serif"
            font.pixelSize: parent.height * 0.15
        }

        ImageButton{
            id: btExitButton
            visible: false
            upimage: "Keypad/KeyPad_X_Large.png"
            downimage: "Keypad/KeyPad_X_Large.png"
            anchors.top: referenceArea.top
            anchors.topMargin: 70
            anchors.right: referenceArea.right
            anchors.rightMargin: 70
            onClicked: {
                if(bluetoothAdapter.pairing == true){
                    bluetoothAdapter.cancelDeviceCreation()
                }
                root.state = "list"
                closed()

            }
        }

    }

    states: [
        State{
            name: "idle"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}

        },
        State{
            name: "list"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: true}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: main.isTouch}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
        },
        State{
            name: "pairing"
            PropertyChanges {target: btPairingItems; visible: true}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: main.isTouch}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
        },
        State{
            name: "connecting"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: true}
            PropertyChanges {target: btExitButton; visible: main.isTouch}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
        },
        State{
            name: "disconnecting"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: true}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
        },
        State{
            name: "gettingpairingcode"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: true}
        }
    ]

    function paddy(n, p, c){
        var pad_char = typeof c !== 'undefined' ? c : '0';
        var pad = new Array(1+p).join(pad_char);
        return (pad+n).slice(-pad.length);
    }
}
