import QtQuick 2.4
import Brainboard 1.0
import Process 0.1
import "."
import "../Television"
import ".."
import "../Keypad"
import FileIO 1.0
import VLCVideo 1.0
import Components 1.0

Item {
    id: root
    property bool isActive: main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0
    state: "Menu"

    anchors { fill: parent ; leftMargin: 100 ; topMargin: 10 }

    Connections {
        target: root.isActive ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsCAB")
            diagnostics_screen.item.unselectScreen()
        }
    }

    ListView{
        id: menu
        anchors.horizontalCenter: root.horizontalCenter
        anchors.top: root.top
        anchors.topMargin: 20
        width: root.width * 0.8
        height: 130
        interactive: false
        model: controlList.model
        clip: true
        snapMode: ListView.SnapToItem
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveVelocity: 10000
        currentIndex: controlList.curIndex
        highlight: Component {
            Item {
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && controlList.listening
                    border { left: 70; top: 5; bottom: 5; right: 70 }
                    source: "../graphics/tft/maintenance_menus_cursor.png"
                    width: menu.currentItem ? menu.currentItem.navCursorWidth + 30 : 0
                    height: 56
                    horizontalTileMode: BorderImage.Stretch
                }
            }
        }
    }
    KeyedControlList {
        id: controlList
        listening: main.isTft && root.isActive && root.state === "Menu"
        listView: menu

        ToggleButtonLabeled{
            id: cabEnabledToggle

            labelString: qsTr("C.A.B. Enabled?") + application.emptyString
            onValueChanged: {
                options.cabEnabled = value ? true : false
                if(value){
                    startTv()
                } else {
                    stopTv()
                }
            }
            Component.onCompleted: value = options.cabEnabled
        }

        InlineButton {
            property string currentSTB: stbSettingListView.selectedIndex >= 0 ? stbSettingList.get(stbSettingListView.selectedIndex).displayString : qsTr("None")
            label: qsTr("Set Top Box") + ": " + currentSTB + application.emptyString
            labelWidth: 510
            visible: cabEnabledToggle.value
            enabled: cabEnabledToggle.value
            labelColor: "black"
            onPressed: {
                root.state = "SelectBox"
            }
        }

    }

    ImageButton {
        id: selectSTBButton
        label: qsTr("Select Set Top Box") + application.emptyString
        label_color: "black"
        label_x_offset: 80
        wrapWidth: 130
        anchors { top: menu.bottom; topMargin: 0; left: menu.left; leftMargin: 20 }
        visible: main.isTouch && cabEnabledToggle.value
        upimage: "../graphics/205/SM_Button_BLUE.png"
        downimage: "../graphics/205/SM_Button_ORANGE.png"
        onClicked: root.state = "SelectBox"
    }

    ListModel{
        id: stbSettingList
        ListElement{displayString: "Disable STB (TV only)"; settingString: "STB_00"}
        ListElement{displayString: "Motorola Cable STBs"; settingString: "STB_02"}
        ListElement{displayString: "Dish Network (provider) STBs"; settingString: "STB_03"}
        ListElement{displayString: "DirecTV (provider) STBs"; settingString: "STB_04"}
        ListElement{displayString: "Samsung/Scientific Atlanta Cable STBs"; settingString: "STB_05"}
        ListElement{displayString: "SciAtlanta IPN330HD Cable STB"; settingString: "STB_06"}
        ListElement{displayString: "Most small-sized Cable STBs"; settingString: "STB_07"}
        ListElement{displayString: "Most Cable STBs"; settingString: "STB_08"}
        ListElement{displayString: "Most Satellite STBs"; settingString: "STB_09"}
        ListElement{displayString: "YES (provider) STBs (Blk/Silver remote)"; settingString: "STB_13"}
        ListElement{displayString: "HOT (provider) STBs (Select btn remote)"; settingString: "STB_14"}
        ListElement{displayString: "HOT (provider) STBs (OK btn remote)"; settingString: "STB_15"}
        ListElement{displayString: "Integra IPTV STB"; settingString: "STB_16"}
        ListElement{displayString: "COX (provider) Cable STBs"; settingString: "STB_17"}
        ListElement{displayString: "Rogers (provider) Cable STBs"; settingString: "STB_18"}
        ListElement{displayString: "Version 19 STBs"; settingString: "STB_19"}
        ListElement{displayString: "Version 20 STBs"; settingString: "STB_20"}
        ListElement{displayString: "Version 21 STBs"; settingString: "STB_21"}
        ListElement{displayString: "Version 22 STBs"; settingString: "STB_22"}
        ListElement{displayString: "Version 23 STBs"; settingString: "STB_23"}
        ListElement{displayString: "Version 24 STBs"; settingString: "STB_24"}
        ListElement{displayString: "Version 25 STBs"; settingString: "STB_25"}
        ListElement{displayString: "Version 26 STBs"; settingString: "STB_26"}
        ListElement{displayString: "Version 27 STBs"; settingString: "STB_27"}
        ListElement{displayString: "Version 28 STBs"; settingString: "STB_28"}
        ListElement{displayString: "Version 29 STBs"; settingString: "STB_29"}
        ListElement{displayString: "Version 30 STBs"; settingString: "STB_30"}
    }

    function getIndexFromCABSetting(setting){
        var i
        var item
        for(i = 0; i < stbSettingList.count; i++){
            item = stbSettingList.get(i)
            if(item.settingString === setting){
                return i;
            }
        }
        return -1;
    }

    Rectangle {
        id: rightControlArea

        radius: 5
        height: previewTv.height + 200
        color: "#7f8082"
        anchors {
            left: cabSTBBoxBrowser.right
            leftMargin: 50
            top: cabSTBBoxBrowser.visible ? cabSTBBoxBrowser.top : menu.top
            topMargin: 0
            right: parent.right
            rightMargin: 50
        }

        VLCSurface{
            id: previewTv
            player: tv.player
            aspect: tv.aspect
            playing: 1
            width: parent.width * 0.9
            height: width/tv.aspect
            anchors { top: parent.top; right: parent.right; margins: 20 }
            anchors.topMargin: 0
            onPlayingChanged: tv.on = playing
            z: 1000
        }
        Item {
            id: tftControls
            visible: main.isTft
            width: parent.width - 50
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: previewTv.bottom
                topMargin: 25
                bottom: parent.bottom
            }

            Connections {
                target: root.isActive ? keymapper : null

                onDoubleLeftPressed: {
                    main.debugKeys("doubleLeftPressed", "DiagnosticsCAB")
                    channelDownButton.clicked()
                }

                onDoubleRightPressed: {
                    main.debugKeys("doubleRightPressed", "DiagnosticsCAB")
                    channelUpButton.clicked()
                }
            }
            Item {
                id: upRow
                visible: true
                anchors.top: parent.top
                anchors.left: parent.left
                height: upImage.height
                Image {
                    id: upImage
                    source: "../graphics/tft/FWD_icon.png"
                }
                Text {
                    text: qsTr("Channel Up") + application.emptyString
                    anchors.left: upImage.right
                    anchors.leftMargin: 20
                    anchors.verticalCenter: upImage.verticalCenter
                    font { pixelSize: 18; bold: true }
                }
            }
            Item {
                id: downRow
                visible: true
                anchors.top: upRow.bottom
                anchors.topMargin: 20
                anchors.left: parent.left
                height: downImage.height
                Image {
                    id: downImage
                    source: "../graphics/tft/REW_icon.png"
                }
                Text {
                    text: qsTr("Channel Down") + application.emptyString
                    anchors.left: downImage.right
                    anchors.leftMargin: 20
                    anchors.verticalCenter: downImage.verticalCenter
                    font { pixelSize: 18; bold: true }
                }
            }
        }

        Item {
            id: touchControls
            visible: main.isTouch
            width: parent.width - 50
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: previewTv.bottom
                topMargin: 25
                bottom: parent.bottom
            }

            Item {
                id: channelUpRow
                visible: true
                anchors.top: parent.top
                anchors.left: parent.left
                height: channelUpButton.height
                ImageButton {
                    id: channelUpButton
                    upimage: "../graphics/205/SM_Button_BLUE.png"
                    downimage: "../graphics/205/SM_Button_ORANGE.png"
                    onClicked: brainboard.cabChannelUp()
                }
                Text {
                    text: qsTr("Channel Up") + application.emptyString
                    anchors.left: channelUpButton.right
                    anchors.leftMargin: 20
                    anchors.verticalCenter: channelUpButton.verticalCenter
                    font { pixelSize: 18; bold: true }
                }
            }
            Item {
                id: channelDownRow
                anchors.top: channelUpRow.bottom
                anchors.topMargin: 10
                anchors.left: parent.left
                height: channelDownButton.height
                ImageButton {
                    id: channelDownButton
                    upimage: "../graphics/205/SM_Button_BLUE.png"
                    downimage: "../graphics/205/SM_Button_ORANGE.png"
                    onClicked: brainboard.cabChannelDown()
                }
                Text {
                    text: qsTr("Channel Down") + application.emptyString
                    anchors.left: channelDownButton.right
                    anchors.leftMargin: 20
                    anchors.verticalCenter: channelDownButton.verticalCenter
                    font { pixelSize: 18; bold: true }
                }
            }
        }
    }

    Timer {
        id: tvRetryTimer
        interval: 1500
        running: true
        repeat: false
        onTriggered: {
            if (tv.on === false) {
                startTv()
            }
        }
    }

    function startTv() {
        /* Get the first item on the list */
        var item = tv.channelList.getChannelItem(0)

        /* Tune to preview item if valid */
        if(item !== null) {
            tv.tuneChannelID(item.id)
        }
    }

    function stopTv() {
        tv.stop()
    }

    Rectangle {
        id: cabSTBBoxBrowser
        enabled: cabEnabledToggle.value

        visible: false
        color: "#7f8082"
        radius: 5
        width: parent.width * 0.5
        anchors.top: menu.bottom
        anchors.topMargin: 3
        anchors.bottom: parent.bottom
        anchors.bottomMargin: main.isTft ? 75 : 18
        anchors.left: menu.left


        Item {
            id: clippingItem

            anchors.fill: parent
            clip: true

            ListView {
                id: stbSettingListView
                property int selectedIndex: -1

                spacing: main.isTouch ? 20 : 1
                height: 180
                anchors.fill: parent
                anchors.margins: 10
                keyNavigationWraps: true

                onSelectedIndexChanged: {
                    currentIndex = selectedIndex
                }

                Connections {
                    target: main.isTft && root.isActive && root.state === "SelectBox" ? keymapper : null
                    onDownButtonPressed: {
                        main.debugKeys("downButtonPressed", "DiagnosticsCAB")
                        stbSettingListView.incrementCurrentIndex()
                    }
                    onUpButtonPressed: {
                        main.debugKeys("upButtonPressed", "DiagnosticsCAB")
                        stbSettingListView.decrementCurrentIndex()
                    }

                    onEnter2Pressed: {
                        main.debugKeys("enter2Pressed", "DiagnosticsCAB")
                        stbSettingListView.currentItem.pressed(stbSettingListView.currentIndex)
                    }
                }

                interactive: true
                model: stbSettingList
                highlight: Component {
                    Item {
                        width: parent.width
                        z: 9999999
                        BorderImage {
                            id: selectionCursor
                            visible: main.isTft
                            border { left: 70; top: 5; bottom: 5; right: 70 }
                            source: "../graphics/tft/maintenance_menus_cursor.png"
                            width: parent.width + 30
                            x: -15
                            y: -5
                            height: 56
                            horizontalTileMode: BorderImage.Stretch
                        }
                    }
                }
                highlightMoveVelocity: 1500
                delegate: Component {
                    Rectangle{
                        id: listItem

                        enabled: cabEnabledToggle.value
                        height: 40
                        width: parent.width
                        color: index === stbSettingListView.selectedIndex ? "#5f9e45" : "transparent"
                        radius: 0

                        function sendCommand(index){
                            switch(index){
                            case 0:
                                brainboard.cabDisableOutputToSTB()
                                break;
                            case 1:
                                brainboard.cabEnableSTB_Motorola_STB()
                                break;
                            case 2:
                                brainboard.cabEnableSTB_DishNetwork_STB()
                                break;
                            case 3:
                                brainboard.cabEnableSTB_DirectTV_STB()
                                break;
                            case 4:
                                brainboard.cabEnableSTB_SamsungSciAtlanta_STB()
                                break;
                            case 5:
                                brainboard.cabEnableSTB_SciAtlantaIPN330HD_STB()
                                break;
                            case 6:
                                brainboard.cabEnableSTB_MostComcast_STB()
                                break;
                            case 7:
                                brainboard.cabEnableUnicode_cable_STB()
                                break;
                            case 8:
                                brainboard.cabEnableUnicode_satallite_STB()
                                break;
                            case 9:
                                brainboard.cabEnableYesBlkSilverRemote_STB()
                                break;
                            case 10:
                                brainboard.cabEnableHotSelectBtnRemote_STB()
                                break;
                            case 11:
                                brainboard.cabEnableHotOkBtnRemote_STB()
                                break;
                            case 12:
                                brainboard.cabEnableIntegraIPTV_STB()
                                break;
                            case 13:
                                brainboard.cabEnableCOXCable_STB()
                                break;
                            case 14:
                                brainboard.cabEnableRogersCable_STB()
                                break;
                            case 15:
                                brainboard.cabEnableVersion19_STB()
                                break;
                            case 16:
                                brainboard.cabEnableVersion20_STB()
                                break;
                            case 17:
                                brainboard.cabEnableVersion21_STB()
                                break;
                            case 18:
                                brainboard.cabEnableVersion22_STB()
                                break;
                            case 19:
                                brainboard.cabEnableVersion23_STB()
                                break;
                            case 20:
                                brainboard.cabEnableVersion24_STB()
                                break;
                            case 21:
                                brainboard.cabEnableVersion25_STB()
                                break;
                            case 22:
                                brainboard.cabEnableVersion26_STB()
                                break;
                            case 23:
                                brainboard.cabEnableVersion27_STB()
                                break;
                            case 24:
                                brainboard.cabEnableVersion28_STB()
                                break;
                            case 25:
                                brainboard.cabEnableVersion29_STB()
                                break;
                            case 26:
                                brainboard.cabEnableVersion30_STB()
                                break;
                            }
                        }

                        function pressed(index){
                            var str = stbSettingList.get(index).settingString
                            stbSettingListView.selectedIndex = index
                            options.cabSetting = str
                            if(brainboard.enabled)
                                sendCommand(index)
                            root.state = "Menu"
                        }

                        Text {
                            text: displayString
                            opacity: cabEnabledToggle.value ? 1.0 : 0.5
                            color: "white"
                            font.bold: true
                            font.family: "sans serif"
                            font.pixelSize: parent.height * 0.45
                            verticalAlignment: Text.AlignVCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 10
                            anchors.verticalCenter: parent.verticalCenter
                            MouseArea {
                                anchors.fill: parent
                            }
                        }
                        ImageButton {
                            id: selectSTBSettingButton
                            visible: main.isTouch
                            onClicked: listItem.pressed(index)
                            anchors { top: parent.top; topMargin: -13; right: parent.right }
                            upimage: "../graphics/205/SM_Button_GRAY.png"
                            downimage: "../graphics/205/SM_Button_ORANGE.png"
                        }
                    }
                }

                Component.onCompleted: selectedIndex = getIndexFromCABSetting(options.cabSetting)
            }
        }
    }

    Item {
        id: dataArrows

        width: 40
        height: cabSTBBoxBrowser.height / 2
        anchors.left: cabSTBBoxBrowser.right
        anchors.leftMargin: -60
        anchors.verticalCenter: cabSTBBoxBrowser.verticalCenter
        visible: cabSTBBoxBrowser.visible

        Image {
            id: dataUpArrow
            source: "../graphics/Swipe_Arrows_Left.png"
            rotation: 90
            anchors { top: parent.top ; left: parent.right }
            opacity: stbSettingListView.atYBeginning ? 0.0 : 1.0
        }
        Image {
            id: dataDownArrow
            source: "../graphics/Swipe_Arrows_Left.png"
            rotation: -90
            anchors { bottom: parent.bottom ; left: parent.right }
            opacity: stbSettingListView.atYEnd ? 0.0 : 1.0
        }
    }

    Component.onDestruction: tv.on = false

    Text {
        id: bottomHelpText
        visible: main.isTft && root.isActive

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: {
            return qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to navigate, press ENTER to select") + application.emptyString
        }

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -50
    }

    states: [
        State {
            name: "Menu"
            PropertyChanges { target: cabSTBBoxBrowser; visible: false }
            AnchorChanges { target: rightControlArea; anchors.top: menu.top }
        },

        State {
            name: "SelectBox"
            PropertyChanges { target: cabSTBBoxBrowser; visible: true }
            AnchorChanges { target: rightControlArea; anchors.top: cabSTBBoxBrowser.top }
        }
    ]

    transitions: [
        Transition {
            AnchorAnimation { duration: 300 }
        }

    ]
}
