// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import Process 0.1
import Components 1.0
import ".."

Rectangle {
    id: root
    state: "DateTimeState"

    property string scriptsdir: "scripts"
    property bool isSetupWizard: false
    property string cursorState: "datetime" // datetime, next, timezone, or save
    property bool isActive: (main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || isSetupWizard

    signal timeSet()

    function saveDateTime() {
        dateProcess.start()

    }

    anchors.fill: parent
    width: 1366
    height: 768
    color: "transparent"

    Connections {
        target: main.isTft && root.visible && root.isActive && cursorState === "next" ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "DiagnosticsClockSetup")
            datePicker.curIndex = 5
            cursorState = "datetime"
        }
        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsClockSetup")
            datePicker.curIndex = 0
            cursorState = "datetime"
        }
    }

    Connections {
        target: main.isTft && root.visible && root.isActive && root.state === "TimeZoneState" ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "DiagnosticsClockSetup")
            cursorState = (cursorState === "timezone") ? "save" : "timezone"
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsClockSetup")
            cursorState = (cursorState === "timezone") ? "save" : "timezone"
        }
    }

    Connections {
        target: main.isTft && root.visible && root.isActive ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsClockSetup")
            if (root.state === "TimeZoneState") {
                cursorState = "next"
                root.state = "DateTimeState"
            } else {
                diagnostics_screen.item.unselectScreen()
            }
        }
        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsClockSetup")
            if (cursorState === "next") {
                cursorState = "timezone"
                nextButton.clicked()
            } else if (cursorState === "save") {
                saveButton.clicked()
                cursorState = "datetime"
                datePicker.curIndex = 0
            }
        }
    }

    DateTimePicker {
        id: datePicker
        listenKeys: root.visible && root.isActive && cursorState === "datetime"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -100
        onExitedList: {
            console.log("exited list")
            cursorState = "next"
        }
    }

    Text {
        id: selectTimezoneLabel
        anchors.horizontalCenter: parent.horizontalCenter
        text: qsTr("Select Timezone") + application.emptyString
        font.pixelSize: 48
        anchors.top: parent.top
        anchors.topMargin: 50
    }

    TimezoneSelection {
        id: timezoneSelection
        listenKeys: root.visible && cursorState === "timezone"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 0
        anchors.top: selectTimezoneLabel.bottom
        anchors.topMargin: -50
        height: 500
        width: 350
    }

    ImageButton { id: nextButton
        downimage: "../graphics/setup/Start_Button_Down.png"
        upimage: "../graphics/setup/Start_Button.png"

        visible: !root.isSetupWizard || (main.isTft && root.isSetupWizard)
        label: qsTr("NEXT") + application.emptyString
        label_color: "black"
        label_under: true
        fontsize: 18

        anchors {
            bottom: parent.bottom ; bottomMargin: 25
            right: parent.right ; rightMargin: 46
        }

        onClicked: {
            root.state = "TimeZoneState"
        }
    }

    Image {
        source: "../graphics/tft/NAV_selector_2.png"
        visible: main.isTft && root.isActive && (cursorState === "next" || cursorState === "save")
        anchors.centerIn: cursorState === "next" || isSetupWizard ? nextButton : saveButton
        z: saveButton.z - 1
    }

    ImageButton {
        id:saveButton
        label: qsTr("SAVE") + application.emptyString
        upimage:"../graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"../graphics/200/TRU_200_other_small_Button_Down.png"
        label_under: false
        label_y_offset: -3
        anchors.right: parent.right
        anchors.rightMargin: 70
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 50
        onClicked: {
            if (isSetupWizard) {
                root.timeSet()
                return
            }

            root.saveDateTime()
            root.state = "DateTimeState"
            dialogText.text = qsTr("Time has been updated")
            actionSuccessfulDialog.show()
            actionSuccessfulDialog.startTimeout(1)
        }
        visible: !root.isSetupWizard
    }

    Text {
        id: backButton

        text: "< " + qsTr("BACK TO TIME") + application.emptyString
        anchors.right: parent.right
        anchors.rightMargin: 10
        anchors.top: parent.top
        anchors.topMargin: 10
        color: "#cccccc"
        font.bold: true
        MouseArea {
            anchors.fill: parent
            onClicked: root.state = "DateTimeState"
        }
    }

    ModalDialog {
        id: actionSuccessfulDialog
        BorderImage {   // pop-up dialog background
            id: border

            x: 332
            y: 161
            width: 800
            height: 350
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Text {
                id: dialogText
                anchors.fill: parent
                anchors.verticalCenter: parent.verticalCenter
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    Process {
        id: dateProcess
        program: root.scriptsdir + '/set_datetime.sh'
        arguments: [datePicker.getDateString(), timezoneSelection.selectedItem.LinuxID]
        onReadyReadStandardError: {
            var output = new String(readAllStandardError())
            console.log("output from stderr:", output)
        }

        onReadyReadStandardOutput: {
            var output = new String(readAllStandardOutput())
            console.log("output from stdout:", output)
        }
        onFinished: {
            Date.timeZoneUpdated()
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && root.isActive

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: {
            if (cursorState === "next") {
                return qsTr("press ENTER to select") + application.emptyString
            } else if (cursorState === "timezone") {
                return qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to change selection") + application.emptyString
            } else if (cursorState === "save") {
                return qsTr("press ENTER to select") + application.emptyString
            } else {
                return qsTr("use <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to navigate, use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to change value") + application.emptyString
            }
        }

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }

    states: [
        State {
            name: "DateTimeState"
            PropertyChanges {target: datePicker ; visible: true }
            PropertyChanges {target: nextButton ; visible: true }
            PropertyChanges {target: selectTimezoneLabel ; visible: false }
            PropertyChanges {target: timezoneSelection ; visible: false }
            PropertyChanges {target: backButton ; visible: false }
            PropertyChanges {target: saveButton ; visible: false }
        },
        State {
            name: "TimeZoneState"
            PropertyChanges {target: datePicker ; visible: false }
            PropertyChanges {target: nextButton ; visible: main.isTft && root.isSetupWizard }
            PropertyChanges {target: selectTimezoneLabel ; visible: true }
            PropertyChanges {target: timezoneSelection ; visible: true }
            PropertyChanges {target: backButton ; visible: main.isTouch }
            PropertyChanges {target: saveButton ; visible: !root.isSetupWizard}
        }
    ]
}
