import QtQuick 2.4

import FileIO 1.0
import QtQuick 2.4
import ".."
import ConfigurationData 1.0
import Process 0.1
import "../string_format.js" as Format
import Components 1.0


Rectangle {
    id: root
    width: 1366
    height: 768
    anchors.fill: parent
    state: ""
    color: "transparent"

    property int topOffset: 130
    property int itemSpacing: -10

    property int menuItemWidth: 150
    property int menuItemHeight: 75

    property bool datadirty: false

    signal close()

    Component.onCompleted: {
        simMode.value = options.simulationMode ? true : false
        pedalTimeout.value = options.disableNoPedalStop ? false : true
        showStimulusAreaMode.value = options.showStimulusArea ? true : false
        showCursorMode.value = options.showCursor ? true : false
        standAloneMode.value = options.ignoreFaults ? true: false
        tvAccelerationMode.value = options.tvHwAccel
        tvFrameDropMode.value = !options.tvNoFrameDrop
        erpEnabled.value = options.erpEnabled ? true: false
        disableBuzzerMode.value = options.disableBuzzer
        logginEnabledMode.value = options.loggingEnabled ? true : false
        modestyModeSwitch.value = options.modestyMode
        brainboardDebugLevelMode.value = options.brainboardDebugLogLevel

        if(options.fanOption === "2-Wire")
            fanOption.value = false;
        else
            fanOption.value = true;

        messageCenterBrightnessControl.value = options.messageCenterBrightness
        messageCenterContrastControl.value = options.messageCenterContrast

    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsDevelop")
            diagnostics_screen.item.unselectScreen()
        }
    }

    KeyedControlList {
        id: controlList
        listening: root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0
        listView: mode

        ToggleButtonLabeled{
            id: simMode
            labelString: qsTr("Simulation Mode") + application.emptyString

            onValueChanged:
            {
                options.simulationMode = value ? true : false
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: pedalTimeout
            labelString: qsTr("Zero RPM Timeout") + application.emptyString

            onValueChanged:
            {
                options.disableNoPedalStop = value ? false : true
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: showStimulusAreaMode
            labelString: qsTr("Stimulus Area Enabled") + application.emptyString
            onValueChanged:
            {
                options.showStimulusArea = value ? true : false
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: showCursorMode
            labelString: qsTr("Show Cursor") + application.emptyString
            onValueChanged:
            {
                options.showCursor = value ? true : false
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: standAloneMode
            labelString: qsTr("Stand Alone Mode") + application.emptyString
            onValueChanged:
            {
                options.ignoreFaults = value ? true : false
                if(value == true) {
                    errorManager.fatalError = false
                    errorManager.preventUse = false
                    errorManager.degradedUse = false
                }
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: erpEnabled
            visible: main.erpIsSupported
            labelString: qsTr("Energy Saving Timer Enabled") + application.emptyString
            onValueChanged:
            {
                options.erpEnabled = value ? true : false
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: tvFrameDropMode
            labelString: qsTr("TV Drop Late Frames (restart needed)") + application.emptyString
            onValueChanged:
            {
                options.tvNoFrameDrop = value ? false : true
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: tvAccelerationMode
            labelString: qsTr("TV Acceleration (restart needed)") + application.emptyString
            onValueChanged:
            {
                options.tvHwAccel = value ? true : false
                datadirty = true
            }
        }
        ToggleButtonLabeled{
            id: disableBuzzerMode
            labelString: qsTr("Disable Buzzer") + application.emptyString
            onValueChanged:
            {
                options.disableBuzzer = value
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: fanOption
            labelString: qsTr("3 Wire Fan?") + application.emptyString
            onValueChanged:
            {
                options.fanOption = value ? "3-Wire" : "2-Wire"
                if(value)
                    brainboard.set3WireFanOption()
                else
                    brainboard.set2WireFanOption()
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: messageCenterBrightnessControl
            headingString: qsTr("Message Center Brightness:") + application.emptyString
            minValue: 0
            maxValue: 100
            stepValue: 1
            onValueChanged:
            {
                options.messageCenterBrightness = value
                messagecenter.setBrightness(value)
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: messageCenterContrastControl
            headingString: qsTr("Message Center Contrast:") + application.emptyString
            minValue: 0
            maxValue: 100
            stepValue: 1
            onValueChanged:
            {
                options.messageCenterContrast = value
                messagecenter.setContrast(value)
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: logginEnabledMode
            labelString: qsTr("Logging Enabled") + application.emptyString
            onValueChanged:
            {
                if(value == false){
                    console.debug("Logging Enabled is off");
                }

                options.loggingEnabled = value ? true : false
                datadirty = true

                if(value == true){
                    console.debug("Logging Enabled is on");
                }
            }
        }
        ToggleButtonLabeled{
            id: modestyModeSwitch
            labelString: qsTr("Display Images M.E.") + application.emptyString
            onValueChanged: {
                options.modestyMode = value
            }
        }

        SliderControlLabeled{
            id: brainboardDebugLevelMode
            headingString: qsTr("Brainboard Debug Level") + application.emptyString
            minValue: 0
            maxValue: 3
            stepValue: 1
            displayValue: value
            onValueChanged:
            {
                options.brainboardDebugLogLevel = value
                brainboard.setDebugLogLevel(options.brainboardDebugLogLevel)
                datadirty = true
            }
        }

        InlineButton {
            property string progressDots: dotAnim.txt

            label: qsTr("Export Diagnostics") + progressDots + application.emptyString
            labelWidth: 300
            enabled: main.isTft && storageMgr.usbDeviceLoaded && diagExportProcess.processState == Process.NotRunning
            labelColor: enabled ? "black" : "green"
            visible: main.isTft && storageMgr.usbDeviceLoaded
            onPressed: {
                if (diagExportProcess.processState == Process.NotRunning)
                    diagExportProcess.startExport()
            }
            Timer {
                id: dotAnim

                property string txt: ""
                property int i: 0

                interval: 400
                running: diagExportProcess.processState != Process.NotRunning
                repeat: true
                onTriggered: {
                    i = (i + 1) % 4
                    txt = (new Array(i+1)).join(".")
                }

                onRunningChanged: {
                    if (!running) {
                        txt = ""
                        i = 0
                    }
                }
            }
        }

    }

    Item {
        id: dataArrows

        width: 40
        height: parent.height - 90

        anchors { left: parent.left; leftMargin: 630; verticalCenter: mode.verticalCenter }
        Image {
            id: dataUpArrow
            visible: !mode.atYBeginning
            source: "../graphics/Swipe_Arrows_Left.png"
            rotation: 90
            anchors { top: parent.top; topMargin: 50; right: parent.right }
        }
        Image {
            id: dataDownArrow
            visible: !mode.atYEnd
            source: "../graphics/Swipe_Arrows_Right.png"
            rotation: 90
            anchors { bottom: parent.bottom; bottomMargin: 50; right: parent.right }
        }

    }

    ListView{
        id: mode
        anchors.horizontalCenter: root.horizontalCenter
        anchors.top: root.top
        anchors.topMargin: 20
        width: root.width * 0.8
        height: 540
        model: controlList.model
        clip: true
        snapMode: ListView.SnapToItem
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveVelocity: 10000
        currentIndex: controlList.curIndex
        highlight: Component {
            Item {
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && controlList.listening
                    border { left: 70; top: 5; bottom: 5; right: 70 }
                    source: "../graphics/tft/maintenance_menus_cursor.png"
                    width: mode.currentItem ? mode.currentItem.navCursorWidth + 30 : 0
                    height: 56
                    horizontalTileMode: BorderImage.Stretch
                }
            }
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to navigate, use <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to change value") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }

    ImageButton {
        id: exportDiagButton

        enabled: storageMgr.usbDeviceLoaded && !(diagExportProcess.processState != Process.NotRunning)
        visible: main.isTouch && storageMgr.usbDeviceLoaded

        upimage:"../graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"../graphics/200/TRU_200_other_small_Button_Down.png"
        anchors { right: parent.right ; rightMargin: 100;  bottom: mode.bottom }
        label: qsTr("Export Diagnostics") + application.emptyString
        label_under: true
        label_y_offset: 5
        label_color: "black"

        onClicked: {
            diagExportProcess.startExport()
        }
    }

    Connections {
        target: language_menu
        onLanguageSelected: {
            if (languageDiagnosticMenu) {
               main.state = "DiagnosticState"
               if (lang)
               {
                   application.selectLanguage(lang)
                   options.defaultLanguage = lang
                   defaultLanguageText.text = language_menu.getLanguageName(options.defaultLanguage)
                   defaultLanguageIcon.source = "../LanguageMenu/" + language_menu.getLanguageIcon(options.defaultLanguage)
               }
               languageDiagnosticMenu = false
            }
        }
    }

    Loader {
        id: statsLoader
        property bool active: false
        sourceComponent: active ? statsComponent : null
        Component {
            id: statsComponent
            Item {
                property alias statsItem: stats
                property alias programStatsItem: programStats
                property alias miscStatsItem: miscStats
                DiagnosticsStatistics {
                    id: stats
                    visible: false
                }
                DiagnosticsProgramStatistics {
                    id: programStats
                    visible: false
                }
                DiagnosticsMiscStatistics {
                    id: miscStats
                    visible: false
                }
            }
        }
    }

    function exportStats(dir) {
        statsLoader.active = true
        console.log("Exporting Stats to", dir)
        fileio.source = dir + "/statistics"
        fileio.fileMode = FileIO.READ_WRITE
        fileio.open()
        fileio.writeLine("[Statistics]\n")
        fileio.writeLine(statsLoader.item.statsItem.getExportString())
        fileio.writeLine("[Program Statistics]\n")
        fileio.writeLine(statsLoader.item.programStatsItem.getExportString())
        fileio.writeLine("[Other]\n")
        fileio.writeLine(statsLoader.item.miscStatsItem.getExportString())
        fileio.close()
        console.log("Done")
    }

    FileIO {
        id: fileio
    }

    Process {
        id: diagExportProcess

        property string dirName: ""

        function startExport() {
            var unixTime = (new Date).getTime()
            dirName = main.serialNumber + "-diag-" + unixTime
            diagExportProcess.arguments = ["/media/usb/"+dirName]
            diagExportProcess.start()
        }

        program: "scripts/export_diag.sh"
        arguments: ["/media/usb/000-diag-000"]

        onFinished: {
            exportStats("/media/usb/"+dirName)
            syncDisk.start()
        }
    }
}
