import QtQuick 2.4

import ".."
import "DiagnosticsMenu.js" as DiagnosticsMenu
import Components 1.0

Rectangle {
    id: root
    width: 1366
    height: 768
    anchors.fill: parent
    state: ""

    function getTopMenu() {
        if (machineinfo.productTypeString == "Treadmill") {
            return main.isTft ? DiagnosticsMenu.diagnosticsMenuMainTreadTft() : DiagnosticsMenu.diagnosticsMenuMainTread()
        } else if (machineinfo.productTypeString.search("Elliptical") != -1) {
            if (main.isCSA) {
                return main.isTft ? DiagnosticsMenu.diagnosticsMenuMainStrideTft() : DiagnosticsMenu.diagnosticsMenuMainStride()
            } else {
                return main.isTft ? DiagnosticsMenu.diagnosticsMenuMainTft() : DiagnosticsMenu.diagnosticsMenuMain()
            }
        } else {
            return main.isTft ? DiagnosticsMenu.diagnosticsMenuMainTft() : DiagnosticsMenu.diagnosticsMenuMain()
        }
    }

    property variant menu:DiagnosticsMenu.diagnosticsMenuMain()
    property variant topmenu: getTopMenu()
    property string headingText: ""
    property string textText: ""

    property int topOffset: 130
    property int itemSpacing: 0

    property int menuItemWidth: 150
    property int menuItemHeight: 75
    property int numberOfItems: 11

    property string headingString: qsTr("Summary") + application.emptyString

    property alias menuIndex: sideMenuListView.currentIndex

    property int currentSelectedIndex: -1

    signal close()

    function unselectScreen() {
        // called by back-button handlers in the currently visible screen
        root.currentSelectedIndex = -1
    }

    function exitButtonPressedHandler() {
        menureset()
        close()
    }

    function backButtonPressedHandler() {
        textText = QT_TRANSLATE_NOOP("Diagnostics", "Main")
        root.state = "MAIN"
        root.currentSelectedIndex = -1
        test_menu_model.changeMenu(root.topmenu)
    }

    function menureset(){
        menuIndex = 0
        root.currentSelectedIndex = -1
        root.state = "MAIN"
        headingText = QT_TRANSLATE_NOOP("Diagnostics", "Main")
        textText = QT_TRANSLATE_NOOP("Diagnostics", "Main")
        page_loader.source = "DiagnosticsSummary.qml"
        test_menu_model.changeMenu(root.topmenu)
    }

    // re-translate the menu strings when the language changes
    Connections {
        target: application
        onLanguageChanged: { test_menu_model.updateStrings() }
    }

    Connections {
        target: brainboard
        onProductTypeStringChanged: root.menureset()
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" ? keymapper : null

        // Press-and-hold of STOP button exits diagnostic menu from any screen
        onPressAndHold: {
            main.debugKeys("press and hold", "DiagnosticsMain", functionIndex)
            if (functionIndex === 18) {
                root.exitButtonPressedHandler()
            }
        }
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && root.currentSelectedIndex < 0 ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsMain")
            sideMenuListView.decrementCurrentIndex()
            if (test_menu_model.indexIsMenu(menuIndex)) {
                console.log("sub-menu: not entering")
                page_loader.source = "DiagnosticsTftHelp.qml"
                headingText = test_menu_model.get(menuIndex).label
            } else {
                test_menu_model.selectIndex(menuIndex)
            }
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsMain")
            sideMenuListView.incrementCurrentIndex()
            var item = test_menu_model.get(menuIndex)
            if (test_menu_model.indexIsMenu(menuIndex)) {
                console.log("sub-menu: not entering")
                page_loader.source = "DiagnosticsTftHelp.qml"
                headingText = test_menu_model.get(menuIndex).label
            } else {
                test_menu_model.selectIndex(menuIndex)
            }
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsMain")
            if (test_menu_model.indexIsMenu(menuIndex))
                test_menu_model.selectIndex(menuIndex)
            else {
                if (test_menu_model.get(menuIndex).hasControls)
                    root.currentSelectedIndex = menuIndex
            }
        }

        onBackPressed: {
            if (root.state === "SECONDARY")
                root.backButtonPressedHandler()
            else
                root.exitButtonPressedHandler()
        }

    }

    Component.onCompleted: {  // set the top level menu at startup
        menureset()
    }

    OnScreenCursor {
        id: onScreenCursor
        listenKeys: main.isTft && page_loader.source == Qt.resolvedUrl("DiagnosticsTV.qml") && (main.state === "DiagnosticState" || page_loader.item.isSetupWizard)
        z: 10000
    }

    MenuModel{
        id: test_menu_model

        onMenu_currentChanged: {
            root.menu = menu_current // keep top level property in sync with model
            sideMenuListView.model = undefined
            sideMenuListView.model = test_menu_model
            test_menu_model.selectIndex(0)
            menuIndex = 0

        }

        // calling selectItem() causes either the menuSelected or optionSelected signals handled below
        onMenuSelected: {  // a sub-menu was selected
            textText = item.label

            root.state = "SECONDARY"
        }

        // a workout program was selected       
        onOptionSelected: {
            if( item.qmlSource )
            {
                page_loader.source = item.qmlSource
                headingText = item.label
            }
        }
    }


    Image {
        id: background
        visible: true
        anchors.fill: root
        source: "../graphics/Background.png"

    }

    Item{
        id: headingSection

        anchors.top: parent.top
        anchors.left: sideMenuSection.right
        anchors.right: parent.right
        height: 100
        opacity: page_loader.opacity

        Text{
            id: heading
            text: qsTranslate("Diagnostics", root.headingText) + application.emptyString
            font.pointSize: 36
            anchors.fill: parent
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
        }

        Text{
            id:serialNumber
            font.pointSize: 12
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 3
            color: "black"

            text:qsTr("Serial: ") + main.serialNumber + "   " + qsTr("Version: ") + application.appVersion.split(".g")[0] + " / " + machineinfo.brainboardFirmwareVersion.split(".g")[0] + " / " + main.productVersion +  application.emptyString

        }
    }

    Loader{
        focus: main.state == "DiagnosticState"
        opacity: main.isTft && root.currentSelectedIndex < 0 && test_menu_model.get(menuIndex).hasControls ? 0.5 : 1.0
        anchors.left: sideMenuSection.right
        anchors.top: headingSection.bottom
        anchors.bottom: root.bottom
        anchors.right: root.right
        id: page_loader
    }

    Component{
        id: menuItemDelegate
        ImageButton
        {
            id: button1
            width: 160
            height: 59
            upimage:"../graphics/224/224_Data_Bar_4.png"
            downimage:"../graphics/224/224_Data_Bar_4.png"
            label: model.label != undefined ? qsTranslate("Diagnostics", model.label) + application.emptyString : ""
            label_color: "black"
            fontsize: 15
            wrapWidth: 150
            beep: false
            onClicked: {           
                buzzer.buttonPress()
                menuIndex = index
                test_menu_model.selectIndex(index)
            }
            mouseAreaScale: 0.6
            Image {
                id: highlightCursor
                source: main.isTouch ? "../graphics/maintenance_menus_cursor3.png" : "../graphics/tft/maintenance_menus_cursor.png"
                anchors.horizontalCenterOffset: 18
                anchors.verticalCenterOffset: 20
                anchors.centerIn: button1
                visible: root.currentSelectedIndex < 0 && sideMenuListView.currentIndex === index
                z: parent.z + 1
            }
        }
    }

    // side Menu

    Rectangle{
        anchors.top: root.top
        anchors.bottom: root.bottom
        anchors.left: root.left
        width: 200
        color: "steelblue"
        opacity: 0.7
    }

    Item{
        id:sideMenuSection
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        width: 200



        Rectangle{
            id: sideMenuSectionHeading
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            height: parent.height * 0.1
            color: "transparent"
            Text{
                id: text
                text: qsTranslate("Diagnostics", textText) + application.emptyString
                anchors.fill: parent
                scale: paintedWidth > width ? (width / paintedWidth) : 1
                transformOrigin: Item.Left
                horizontalAlignment: scale == 1 ? Text.AlignHCenter : Text.AlignLeft
                verticalAlignment: Text.AlignVCenter
                font.pixelSize: 35
                font.bold: true
            }
        }

        ListView{
            id: sideMenuListView
            anchors{
                top: sideMenuSectionHeading.bottom
                bottom: menuNavigationSection.top
                left: parent.left
                right: parent.right
            }


            keyNavigationWraps: true
            spacing: 0
            model: menu
            delegate: menuItemDelegate
            interactive: false
        }

        Rectangle{
            id: menuNavigationSection
            visible: main.isTouch
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            height: parent.height * 0.2
            color: "transparent"
            Column{
                spacing:-40
                ImageButton
                {
                    id: backButton
                    upimage:"../graphics/224/224_Data_Bar_4.png"
                    downimage:"../graphics/224/224_Data_Bar_4.png"
                    label: qsTr("Back") + application.emptyString
                    label_color: "black"
                    fontsize: 15
                    visible: true
                    onClicked: {
                        root.backButtonPressedHandler()
                    }
                    mouseAreaScale: 0.6
                }
                ImageButton
                {
                    id: exitButton
                    upimage:"../graphics/224/224_Data_Bar_4.png"
                    downimage:"../graphics/224/224_Data_Bar_4.png"
                    fontsize: 15
                    label: qsTr("Exit") + application.emptyString
                    label_color: "black"
                    visible: true
                    onClicked: root.exitButtonPressedHandler()
                    mouseAreaScale: 0.6

                }
            }
        }

        Item {
            id: navHelp
            visible: main.isTft
            anchors.left: parent.left
            anchors.leftMargin: 10
            anchors.bottom: parent.bottom
            height: 150

            Item {
                id: help1
                visible: root.currentSelectedIndex < 0 && (test_menu_model.get(menuIndex).hasControls || test_menu_model.indexIsMenu(menuIndex))
                width: 182
                height: 50
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.topMargin: 5
                Text {
                    id: help1_enter
                    text: qsTr("ENTER") + application.emptyString
                    font { pixelSize: 18; family: "arial"; bold: true }
                    x: 0
                    y: 3
                }
                Image {
                    id: help1_equals
                    source: "../graphics/tft/equals.png"
                    x: 62
                    y: 4
                }
                Text {
                    id: help1_select
                    text: qsTr("Select") + application.emptyString
                    font { pixelSize: 18; family: "arial"; bold: true }
                    x: 91
                    y: 3
                }
            }

            Item {
                id: helpScreen
                visible: root.currentSelectedIndex >= 0
                width: 182
                height: 50
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.topMargin: 5
                Text {
                    id: helpScreen_enter
                    text: qsTr("BACK") + application.emptyString
                    font { pixelSize: 18; family: "arial"; bold: true }
                    x: 3
                    y: 3
                }
                Image {
                    id: helpScreen_equals
                    source: "../graphics/tft/equals.png"
                    x: 62
                    y: 4
                }
                Text {
                    id: helpScreen_select
                    text: qsTr("Return") + application.emptyString
                    font { pixelSize: 18; family: "arial"; bold: true }
                    x: 91
                    y: 3
                }
            }

            Item {
                id: help2
                visible: root.currentSelectedIndex < 0
                width: 182
                height: 50
                anchors.left: parent.left
                anchors.top: help1.bottom
                anchors.topMargin: 5
                Text {
                    id: help2_enter
                    text: qsTr("BACK") + application.emptyString
                    font { pixelSize: 18; family: "arial"; bold: true }
                    x: 3
                    y: 3
                }
                Image {
                    id: help2_equals
                    source: "../graphics/tft/equals.png"
                    x: 62
                    y: 4
                }
                Text {
                    id: help2_select
                    text: (root.state === "MAIN" ? qsTr("Exit") : qsTr("Main Menu")) + application.emptyString
                    font { pixelSize: 18; family: "arial"; bold: true }
                    x: 91
                    y: 3
                }
            }
        }
    }


    states: [
             State {
                 name: "MAIN"
                 PropertyChanges { target: backButton; visible: false}
             },
             State {
                 name: "SECONDARY"
                 PropertyChanges { target: backButton; visible: true}
             }
         ]
}
