import QtQuick 2.4
import ConfigurationData 1.0
import Brainboard 1.0
import ".."
import Components 1.0
Item{
    id: root
    anchors.fill: parent
    state: brainboard.detectedMachineTypeString

    property int fontSize: 24
    property int topOffset: 80
    property int itemSpacing: 5
    property int itemColumnSpacing: 50
    property int currentSelectedIndex
    property bool isSetupWizard: false
    property string cursorState: "product" // product, or save

    signal itemSelected()

    signal declineTogglePressed()

    function saveProduct() {
        var item = productList.model.get(currentSelectedIndex)
        productConfig.configureProduct(item.name, item.decline ? true : false)
        productSelectedConfirmation.text = qsTr("Console Configured for") + "\n"+ item.name + " " + qsTr(item.type)
        productSelectedConfirmation.show()
        productSelectedConfirmation.startTimeout(1)
        options.setProductDependentDefaults(item.name)
    }

    onItemSelected: saveButton.visible = main.isTouch && !root.isSetupWizard
    onDeclineTogglePressed: saveButton.visible = main.isTouch && !root.isSetupWizard

    Connections {
        id: arrowHandler
        target: main.isTft && root.visible && ((!isSetupWizard && main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || (isSetupWizard && main.state === "SetupWizardState")) && cursorState === "product" ? keymapper : null

        function handleLeftPress() {
            if (root.currentSelectedIndex > 0) {
                if (productList.itemAt(root.currentSelectedIndex - 1).visible)
                    root.currentSelectedIndex--
            }
        }
        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "DiagnosticsSetup")
            arrowHandler.handleLeftPress()
        }

        // Allow minus to act as left, as workaround for unconfigured keypad during Setup Wizard
        onMinusPressed: {
            main.debugKeys("minusPressed", "DiagnosticsSetup")
            arrowHandler.handleLeftPress()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsSetup")
            if (root.currentSelectedIndex < productList.model.count - 1){
                if (productList.itemAt(root.currentSelectedIndex + 1).visible)
                    root.currentSelectedIndex++
            } else if (root.currentSelectedIndex === productList.model.count - 1){
                root.currentSelectedIndex = 0
            }
        }

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsSetup")
            // since a Flow is used, we have to make the assumption that there are three items in a row
            // if the layout changes then this code will break
            if (root.currentSelectedIndex - 3 >= 0)
                root.currentSelectedIndex -= 3
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsSetup")
            // since a Flow is used, we have to make the assumption that there are three items in a row
            // if the layout changes then this code will break
            if (root.currentSelectedIndex +3 <= productList.model.count-1)
                root.currentSelectedIndex += 3
        }

    }

    Connections {
        target: main.isTft && root.visible && ((!isSetupWizard && main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || (isSetupWizard && main.state === "SetupWizardState")) ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsSetup")
            switch (cursorState) {
                case "product": {
                    itemSelected()
                    if (!isSetupWizard) saveProduct()
                    if (!isSetupWizard) diagnostics_screen.item.unselectScreen()
                    break
                }
            }
        }

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsSetup")
            if (cursorState === "product") {
                if (!isSetupWizard) diagnostics_screen.item.unselectScreen()
            }
        }
    }

    ListModel {
        id: endexListModel

        ListElement {
            name: "TES900"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TES900_sideview.png"
            typeIndex: 3
            decline: 0
        }

        ListElement {
            name: "TPS825"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TES900_sideview.png"
            typeIndex: 3
            decline: 0
        }
    }

    ListModel {
        id: dciListModel_12Count
        ListElement {
            name: "TCS400"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS400_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS600"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS600_sideview.png"
            typeIndex: 3
            decline: 0
        }
    }

    ListModel {
        id: dciListModel_24Count
        ListElement {
            name: "TCS650"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS650_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS650"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS650_sideview.png"
            typeIndex: 3
            decline: 1
        }
        ListElement {
            name: "TCS900"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS900_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS900"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS900_sideview.png"
            typeIndex: 3
            decline: 1
        }
    }

    ListModel {
        id: metaListModel

        ListElement {
            name: "TCS400"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS400_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS600"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS600_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS650"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS650_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS650"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS650_sideview.png"
            typeIndex: 3
            decline: 1
        }
        ListElement {
            name: "TCS900"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS900_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS900"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS900_sideview.png"
            typeIndex: 3
            decline: 1
        }
    }
    ListModel {
        id: chihuaListModel

        ListElement {
            name: "XCS400"
            type: QT_TR_NOOP("Elliptical")
            imageName: "../graphics/product_images/2013/TRU_XCS400_sideview.png"
            typeIndex: 2
            decline: 0
        }
        ListElement {
            name: "XCS900"
            type: QT_TR_NOOP("Elliptical")
            imageName: "../graphics/product_images/2013/TRU_XCS900_sideview.png"
            typeIndex: 2
            decline: 0
        }
        ListElement {
            name: "RCS400"
            type: QT_TR_NOOP("Bike")
            imageName: "../graphics/product_images/2013/TRU_RCS400_sideview.png"
            typeIndex: 1
            decline: 0
        }
        ListElement {
            name: "UCS400"
            type: QT_TR_NOOP("Bike")
            imageName: "../graphics/product_images/2013/TRU_UCS400_sideview.png"
            typeIndex: 1
            decline: 0

        }
        ListElement {
            name: "UCS900"
            type: QT_TR_NOOP("Bike")
            imageName: "../graphics/product_images/2013/TRU_UCS900_sideview.png"
            typeIndex: 1
            decline: 0
        }
        ListElement {
            name: "RCS900"
            type: QT_TR_NOOP("Bike")
            imageName: "../graphics/product_images/2013/TRU_RCS900_sideview.png"
            typeIndex: 1
            decline: 0
        }

    }
    ListModel {
        id: rexonListModel

        ListElement {
            name: "XCS900"
            type: QT_TR_NOOP("Elliptical")
            imageName: "../graphics/product_images/2013/TRU_XCS900_sideview.png"
            typeIndex: 2
            decline: 0
        }
    }

    ListModel {
        id: csaListModel

        ListElement {
            name: "TS1000"
            type: QT_TR_NOOP("Elliptical")
            imageName: "../graphics/product_images/2013/TRU_XCS900_sideview.png"
            typeIndex: 2
            decline: 0
        }
    }

    ListModel {
        id: productListModel

        ListElement {
            name: "TES900"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TES900_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS400"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS400_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS600"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS600_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS650"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS650_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS650"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS650_sideview.png"
            typeIndex: 3
            decline: 1
        }
        ListElement {
            name: "TCS900"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS900_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "TCS900"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TCS900_sideview.png"
            typeIndex: 3
            decline: 1
        }
        ListElement {
            name: "TPS825"
            type: QT_TR_NOOP("Treadmill")
            imageName: "../graphics/product_images/2013/TRU_TES900_sideview.png"
            typeIndex: 3
            decline: 0
        }
        ListElement {
            name: "XCS400"
            type: QT_TR_NOOP("Elliptical")
            imageName: "../graphics/product_images/2013/TRU_XCS400_sideview.png"
            typeIndex: 2
            decline: 0
        }
        ListElement {
            name: "XCS900"
            type: QT_TR_NOOP("Elliptical")
            imageName: "../graphics/product_images/2013/TRU_XCS900_sideview.png"
            typeIndex: 2
            decline: 0
        }
        ListElement {
            name: "TS1000"
            type: QT_TR_NOOP("Elliptical")
            imageName: "../graphics/product_images/2015/TRU_TS1000_sideview.png"
            typeIndex: 2
            decline: 0
        }
        ListElement {
            name: "RCS400"
            type: QT_TR_NOOP("Bike")
            imageName: "../graphics/product_images/2013/TRU_RCS400_sideview.png"
            typeIndex: 1
            decline: 0
        }
        ListElement {
            name: "UCS400"
            type: QT_TR_NOOP("Bike")
            imageName: "../graphics/product_images/2013/TRU_UCS400_sideview.png"
            typeIndex: 1
            decline: 0
        }
        ListElement {
            name: "UCS900"
            type: QT_TR_NOOP("Bike")
            imageName: "../graphics/product_images/2013/TRU_UCS900_sideview.png"
            typeIndex: 1
            decline: 0
        }
        ListElement {
            name: "RCS900"
            type: QT_TR_NOOP("Bike")
            imageName: "../graphics/product_images/2013/TRU_RCS900_sideview.png"
            typeIndex: 1
            decline: 0
        }

    }

    Text {
        id: currentConfigurationText
        text: qsTr("Current Console Configuration")+application.emptyString
        font.pixelSize: 36
        font.bold: true
        font.underline: true
        anchors.top: parent.top
        anchors.topMargin: 20
        anchors.horizontalCenter: parent.horizontalCenter
    }
    Text {
        id: currentProductConfigurationText
        text: machineinfo.modelString + " " + qsTr(machineinfo.productTypeString) + application.emptyString
        font.pixelSize: 36
        font.bold: true
        anchors.top: currentConfigurationText.bottom
        anchors.topMargin: 10
        anchors.horizontalCenter: parent.horizontalCenter
    }

    function getIndexFromModel(model)
    {
        var name
        var i
        for(i = 0; i < model.count; i++){
            name = model.get(i).name
            if(name === machineinfo.modelString && model.get(i).decline === (machineinfo.treadmillInclineMinPercentGrade < 0 ? 1 : 0)) return i
        }
        return 0
    }

    Item{
        id: productListArea

        width: parent.width * 0.5
        height: parent.width * 0.25
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -width * 0.35
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -30

        Flow{
            anchors.fill: parent
            spacing: 15
            Repeater{
                id:productList
                model: productListModel
                delegate: testComp
                onModelChanged: currentSelectedIndex = getIndexFromModel(model)
            }
        }
    }

    Item{
        id: productImageArea
        width: height
        height: parent.width * 0.25
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: width * 1.25
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -70
        Image{
            id:productImage
            anchors.fill: parent
            smooth: true
            source: productList.model.get(currentSelectedIndex).imageName
        }
    }

    Item{
        id: declineOptionArea
        width: 280
        height: footImage.height

        anchors.right: productImageArea.right
        anchors.rightMargin: 65
        anchors.top: productImageArea.bottom
        anchors.topMargin: 20

        visible: productList.model.get(currentSelectedIndex).decline === 1 ? true : false

        ToggleButton{
            id:declineToggleButton
            visible: false
            height: 27
            width: 70
            anchors.verticalCenter: parent.verticalCenter
            Component.onCompleted: machineinfo.treadmillInclineMinPercentGrade === -30 ? value = true : value = false
            onToggled: declineTogglePressed()
        }

        Text{
            id: declineToggleText
            text: qsTr("Decline Option") + application.emptyString
            font.pointSize: 18
            font.bold: true
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
        }

        Image {
            id: footImage
            source: "../graphics/product_images/2013/decline_foot_small.png"
            anchors {
                left: declineToggleText.right
                leftMargin: 20
                top: parent.top
                topMargin: 0
            }

        }
    }

    Component{
        id: testComp
        Rectangle{
            property bool isCurrentItem: currentSelectedIndex === model.index

            visible: model.name !== "TPS825" || (model.name === "TPS825" && main.isTft) ? true : false
            height: 50
            width: 180
            color: "darkgray"
//            color: isCurrentItem ? "orange" : "darkgray" //(name === machineinfo.modelString && typeIndex === brainboard.productType) ? "orange" : "darkgray"
            border.width: 4
            border.color: "black"
            radius: 4
            Text{
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: model.decline ? -8 : 0
                text: qsTr(model.name) + application.emptyString
                font.pointSize: 26
                font.bold: true
            }
            Text {
                text: "With Decline"
                visible: model.decline === 1
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                font { pointSize: 12 }
            }
            MouseArea{
                anchors.fill: parent
                onClicked: {
                    itemSelected()
                    buzzer.buttonPress()
                    currentSelectedIndex = model.index
                }
            }
            BorderImage {
                id: highlightImage
                visible: parent.isCurrentItem
                width: parent.width + 40
                anchors.left: parent.left
                anchors.leftMargin: -20
                border { left: 70; top: 5; right: 70; bottom: 5 }
                horizontalTileMode: BorderImage.Stretch
                source: main.isTouch ? "../graphics/maintenance_menus_cursor3.png" : "../graphics/tft/maintenance_menus_cursor.png"
                z: productListArea.z + 1
            }
        }

    }

    Component {
        id: sectionHeading
        Rectangle {
            width: listView.width
            height: childrenRect.height
            color: "steelblue"

            Text {
                text: section
                anchors.horizontalCenter: parent.horizontalCenter
                font.bold: true
                font.pointSize: 24
            }
        }
    }

    ImageButton{
        id:saveButton
        label: qsTr("SAVE")+application.emptyString
        upimage:"../graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"../graphics/200/TRU_200_other_small_Button_Down.png"
        label_under: false
        label_y_offset: -3
        anchors.right: parent.right
        anchors.rightMargin: main.isTft ? 70 : 20
        anchors.bottom: parent.bottom
        anchors.bottomMargin: main.isTft ? 30 : 20
        onClicked: saveProduct()
        visible: false
    }

    function getListFromSubsystemID(string,id){

        if(options.simulationMode){
            return productListModel
        }

        if(string === "DCI"){
            switch(id){
            case 0:
                return metaListModel;
            case 1:
                return dciListModel_12Count
            case 2:
                return dciListModel_24Count
            default:
                return metaListModel
            }
        } else if(string === "Endex IDC8X"){
            return endexListModel;

        } else if(string === "Chihua"){
            return chihuaListModel
        } else if(string === "CSA"){
            return csaListModel
        } else{
            return productListModel
        }
    }

    onStateChanged: productList.model = getListFromSubsystemID(state,brainboard.lowerboardSubsystemID)

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' />,<img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to navigate, press ENTER to select") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
