import QtQuick 2.4
import ConfigurationData 1.0
import Brainboard 1.0
import ".."
import Components 1.0
Item{
    id: root
    anchors.fill: parent
    state: brainboard.detectedMachineTypeString

    property int fontSize: 24
    property int topOffset: 130
    property int itemSpacing: 5
    property int itemColumnSpacing: 50

    signal configurationChanged(variant name, variant type, variant config)

    Connections{
        target: root
        //onConfigurationChanged: brainboard.testSlot(config)
        onConfigurationChanged: brainboard.sendConfigurationData(name,type,config)
    }

    ListModel {
        id: endexListModel

        ListElement {
            name: "ES900"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS500_side.png"
            typeIndex: 3
        }

    }
    ListModel {
        id: metaListModel

        ListElement {
            name: "CS400"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS500_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS600"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS550_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS650"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS800_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS900"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS800_side.png"
            typeIndex: 3
        }
    }
    ListModel {
        id: chihuaListModel

        ListElement {
            name: "CS400"
            type: "Elliptical"
            imageName: "graphics/product_images/XCS800_side.png"
            typeIndex: 2
        }
        ListElement {
            name: "CS900"
            type: "Elliptical"
            imageName: "graphics/product_images/XCS800_side.png"
            typeIndex: 2
        }
        ListElement {
            name: "RCS400"
            type: "Bike"
            imageName: "graphics/product_images/UCS800_side.png"
            typeIndex: 1
        }
        ListElement {
            name: "UCS400"
            type: "Bike"
            imageName: "graphics/product_images/UCS800_side.png"
            typeIndex: 1
        }
        ListElement {
            name: "UCS900"
            type: "Bike"
            imageName: "graphics/product_images/UCS800_side.png"
            typeIndex: 1
        }
        ListElement {
            name: "RCS900"
            type: "Bike"
            imageName: "graphics/product_images/UCS800_side.png"
            typeIndex: 1
        }

    }
    ListModel {
        id: rexonListModel

        ListElement {
            name: "CS900"
            type: "Elliptical"
            imageName: "graphics/product_images/XCS800_side.png"
            typeIndex: 2
        }
    }

    ListModel {
        id: productListModel

        ListElement {
            name: "ES900"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS500_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS400"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS500_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS600"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS550_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS650"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS800_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS900"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS800_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS400"
            type: "Treadmill"
            imageName: "graphics/product_images/TCS500_side.png"
            typeIndex: 3
        }
        ListElement {
            name: "CS400"
            type: "Elliptical"
            imageName: "graphics/product_images/XCS800_side.png"
            typeIndex: 2
        }
        ListElement {
            name: "CS900"
            type: "Elliptical"
            imageName: "graphics/product_images/XCS800_side.png"
            typeIndex: 2
        }
        ListElement {
            name: "RCS400"
            type: "Bike"
            imageName: "graphics/product_images/UCS800_side.png"
            typeIndex: 1
        }
        ListElement {
            name: "UCS400"
            type: "Bike"
            imageName: "graphics/product_images/UCS800_side.png"
            typeIndex: 1
        }
        ListElement {
            name: "UCS900"
            type: "Bike"
            imageName: "graphics/product_images/UCS800_side.png"
            typeIndex: 1
        }
        ListElement {
            name: "RCS900"
            type: "Bike"
            imageName: "graphics/product_images/UCS800_side.png"
            typeIndex: 1
        }

    }

    Text {
        id: currentConfigurationText
        text: qsTr("Current Console Configuration") + application.emptyString
        font.pixelSize: 36
        font.bold: true
        font.underline: true
        anchors.top: parent.top
        anchors.topMargin: 50
        anchors.horizontalCenter: parent.horizontalCenter
    }
    Text {
        id: currentProductConfigurationText
        text: machineinfo.modelString + " " + machineinfo.productTypeString
        font.pixelSize: 36
        font.bold: true
        anchors.top: currentConfigurationText.bottom
        anchors.topMargin: 10
        anchors.horizontalCenter: parent.horizontalCenter
    }

    ListView {
        id: listView
        clip: true
        //anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        width: parent.width
        height: parent.height * 0.5

        orientation: ListView.Horizontal
        //model: productListModel
        delegate: productListDelegate


        //section.property: "type"
        //section.criteria: ViewSection.FullString
        //section.delegate: sectionHeading


    }

    Component {
        id: sectionHeading
        Rectangle {
            width: listView.width
            height: childrenRect.height
            color: "steelblue"

            Text {
                text: section
                anchors.horizontalCenter: parent.horizontalCenter
                font.bold: true
                font.pointSize: 24
            }
        }
    }

    Component {
        id: productListDelegate
        Rectangle{
            width: 250
            height: 250
            color: "transparent"
            anchors.verticalCenter: parent.verticalCenter
            Rectangle
            {
                radius: width/2

                color: "lightgray"
                anchors.margins: 20
                anchors.fill: parent
                opacity: 0.5
            }

            Rectangle{

                radius: width/2
                color:"transparent"
                border.width: 15
                border.color: (name === machineinfo.modelString && typeIndex === machineinfo.productType) ? "orange" : "darkgray"
                anchors.margins: 20
                anchors.fill: parent
                ImageButton{
                    preventStealing: false
                    useParentContainerSize: true
                    anchors.fill: parent
                    fontsize: 32
                    upimage:imageName
                    downimage:imageName
                    onClicked:
                    {
                        switch(typeIndex)
                        {
                            //Bike
                        case 1:
                            if(name==="RCS400") root.configurationChanged(name,typeIndex,configurationDataCS400_RB)
                            else if(name === "UCS400") root.configurationChanged(name,typeIndex,configurationDataCS400_UB)
                            else if(name === "UCS900") root.configurationChanged(name,typeIndex,configurationDataCS900_UB)
                            else if(name === "RCS900") root.configurationChanged(name,typeIndex,configurationDataCS900_RB)
                            break;
                            //Elliptical
                        case 2:
                            if(name === "CS400") root.configurationChanged(name,typeIndex,configurationDataCS400_E)
                            else if(name === "CS900") root.configurationChanged(name,typeIndex,configurationDataCS900_E)
                            break;
                            //Treadmill
                        case 3:
                            if(name === "CS400") root.configurationChanged(name,typeIndex,configurationDataCS400_T)
                            else if(name === "CS600") root.configurationChanged(name,typeIndex,configurationDataCS600_T)
                            else if(name === "CS650") root.configurationChanged(name,typeIndex,configurationDataCS650_T)
                            else if(name === "CS900") root.configurationChanged(name,typeIndex,configurationDataCS900_T)
                            else if(name === "ES900") root.configurationChanged(name,typeIndex,configurationDataES900_T)
                            break;

                        }

                        //configurationData.writeDefaultConfigurationData(name,typeIndex)
                        dialogText.text = qsTr("Console Configured for") + "\r\n"+ name + " " + qsTr(type) + application.emptyString
                        productSelectedConfirmation.show()
                        productSelectedConfirmation.startTimeout(1)

                    }
                }
                Text{
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.top: parent.bottom
                    anchors.topMargin: -20
                    color: "black"
                    opacity: 0.8
                    text: name
                    font.pixelSize: 50
                    font.bold: true
                }
            }
        }
    }

    //    ImageButton{
    //        label: qsTr("SAVE") + application.emptyString
    //        upimage:"../graphics/200/TRU_200_other_small_Button_Up.png"
    //        downimage:"../graphics/200/TRU_200_other_small_Button_Down.png"
    //        label_under: false
    //        label_y_offset: -3
    //        anchors.right: parent.right
    //        anchors.rightMargin: 20
    //        anchors.bottom: parent.bottom
    //        anchors.bottomMargin: 20
    //        onClicked: console.debug("write to defaults to eeprom")
    //    }


    states:[
        State {
            name: "Endex IDC8X"
            PropertyChanges {target: listView ; model: endexListModel }
        },
        State {
            name: "Meta"
            PropertyChanges {target: listView ; model: metaListModel }
        },
        State {
            name: "DCI"
            PropertyChanges {target: listView ; model: metaListModel }
        },
//        State {
//            name: "Rexon"
//            PropertyChanges {target: listView ; model: rexonListModel }
//        },
        State {
            name: "Chihua"
            PropertyChanges {target: listView ; model: chihuaListModel }
        },
        State {
            name: "Invalid"
            PropertyChanges {target: listView ; model: productListModel }

        }

    ]

    ModalDialog{
        id:productSelectedConfirmation
        BorderImage {   // pop-up dialog background
            id: border

            x: 332
            y: 161
            width: 800
            height: 350
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Text {
                id: dialogText
                anchors.fill: parent
                anchors.verticalCenter: parent.verticalCenter
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50

//                Rectangle{
//                    color: "red"
//                    anchors.fill: parent
//                    opacity: 0.3
//                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    ConfigurationData{
        id: configurationDataCS600_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:80
        crankRatio:350
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 11
        userWeightMax: 400
        inclineFactor1: 15
        inclineFactor2: 36

    }
    ConfigurationData{
        id: configurationDataCS650_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:-30
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:80
        crankRatio:350
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 12
        userWeightMax: 500
        inclineFactor1: 15
        inclineFactor2: 36

    }
    ConfigurationData{
        id: configurationDataCS900_T
        maxInclinePercentGrade:180
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:150
        rollerDiameter:92
        crankRatio:293
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 13
        userWeightMax: 500
        inclineFactor1: -3
        inclineFactor2: 40

    }

    ConfigurationData{
        id: configurationDataES900_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:-30
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:84
        crankRatio:0
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_ENDEX_IDC8X
        csafeID: 10
        userWeightMax: 400
        inclineFactor1: 121
        inclineFactor2: 138

    }

    ConfigurationData{
        id: configurationDataCS400_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:80
        crankRatio:357
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 0
        userWeightMax: 350
        inclineFactor1: -30
        inclineFactor2: 54

    }


    ConfigurationData{
        id: configurationDataCS400_UB
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:867
        ticksPerRevolution:600
        torqueFactor0:650
        torqueFactor1:382
        torqueFactor2:141428
        torqueFactor3:0
        torqueFactor4:10500
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 0
        userWeightMax: 350
        inclineFactor1: 0
        inclineFactor2: 0
    }
    ConfigurationData{
        id: configurationDataCS400_RB
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:1227
        ticksPerRevolution:600
        torqueFactor0:650
        torqueFactor1:382
        torqueFactor2:141428
        torqueFactor3:0
        torqueFactor4:10500
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 0
        userWeightMax: 350
        inclineFactor1: 0
        inclineFactor2: 0
    }
    ConfigurationData{
        id: configurationDataCS900_UB
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:1290
        ticksPerRevolution:600
        torqueFactor0:650
        torqueFactor1:382
        torqueFactor2:141428
        torqueFactor3:0
        torqueFactor4:10500
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 21
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
    }
    ConfigurationData{
        id: configurationDataCS900_RB
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:1290
        ticksPerRevolution:600
        torqueFactor0:650
        torqueFactor1:382
        torqueFactor2:141428
        torqueFactor3:0
        torqueFactor4:10500
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 20
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
    }
    ConfigurationData{
        id: configurationDataCS400_E
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:647
        ticksPerRevolution:600
        torqueFactor0:650
        torqueFactor1:382
        torqueFactor2:141428
        torqueFactor3:0
        torqueFactor4:10500
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 0
        userWeightMax: 350
        inclineFactor1: 0
        inclineFactor2: 0
    }
    ConfigurationData{
        id: configurationDataCS900_E
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:1043
        ticksPerRevolution:600
        torqueFactor0:650
        torqueFactor1:382
        torqueFactor2:141428
        torqueFactor3:0
        torqueFactor4:10500
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 30
        userWeightMax: 450
        inclineFactor1: 0
        inclineFactor2: 0
    }
}
