import QtQuick 2.4
import ".."
import Brainboard 1.0
import Components 1.0
import TrueTouch 1.0

Item {
    id: root

    anchors { fill: parent ; leftMargin: 100 ; topMargin: 10 }

    state: main.isCSA ? "EllipticalStride" : machineinfo.productTypeString

    property int rpm
    property int watts
    property int resistance: brainboard.resistance
    property int contactHR
    property int telemetryHR
    property int fanSpeed
    property int buttonNumber
    property int strideAdc
    property int striderpm


    onWattsChanged: wattDisplay.value = watts
    onRpmChanged: rpmDisplay.value = rpm
    onContactHRChanged: contactHRDisplay.value = contactHR
    onTelemetryHRChanged: telemetryHRDisplay.value = telemetryHR
    onButtonNumberChanged: keypressDisplay.value = buttonNumber
    onStrideAdcChanged: strideAdcDisplay.value = strideAdc
    onStriderpmChanged: strideRpmDisplay.value = striderpm


    Connections{
        target:brainboard
        onWattsChanged: root.watts = watts
        onResistanceChanged: root.resistance = resistance
        onFanSpeedChanged: fanSpeed = percent
        onButtonPressed: buttonNumber = button
        onButtonReleased: buttonNumber = 0
        //onStrideAdcChanged: root.strideAdc = brainboard.strideAdc
    }

    Connections {
        target: heartrate
        onTelemetryHeartRateChanged: telemetryHR = telemetryHeartRate
        onContactHeartRateChanged: contactHR = contactHeartRate
    }

    Connections {
        target: machinecontrol
        onTreadmillSpeedActualChanged: speedDisplay.value = treadmillSpeedActual
        onEstopChanged: {
            estopDisplay.value = estop
            // stop change diagnostic speed control to zero target when safety key opened
            if(!estop)
                speedControl.value = 0
        }
        onPedalRPMChanged: {root.rpm = pedalRPM; root.striderpm = pedalRPM}
        onStrideLengthAdcActualChanged: strideAdc = machinecontrol.strideLengthAdcActual
    }

    Component.onDestruction: machinecontrol.treadmillSpeedTarget = 0

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        // handle exiting the screen
        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsOption")
            diagnostics_screen.item.unselectScreen()
        }
    }

    KeyedControlList {
        id: controlList
        listening: root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0
        listView: mode

        SliderControlLabeled{
            id: contactHRDisplay
            headingString: qsTr("Contact Heart Rate: ") + application.emptyString
            value:contactHR
            displayValue: value ? value + qsTr("BPM") : qsTr("NONE")
            sliderVisible: false
        }
        SliderControlLabeled{
            id: telemetryHRDisplay
            headingString: qsTr("Telemetry Heart Rate: ") + application.emptyString
            value:telemetryHR
            displayValue: value ? value + qsTr("BPM") : qsTr("NONE")
            sliderVisible: false
        }

        SliderControlLabeled{
            id: fanControl
            headingString: qsTr("Fan Speed Control") + application.emptyString
            //value: fanSpeed
            minValue: 0
            maxValue: 100
            onValueChanged: fan.fanSpeed = fanControl.value;
        }

        SliderControlLabeled{
            id: keypressDisplay
            headingString: qsTr("Keypress: ") + application.emptyString
            value:buttonNumber
            sliderVisible: false

        }

        SliderControlLabeled{
            id: rpmDisplay
            headingString: qsTr("Pedal RPM: ") + application.emptyString
            value:root.rpm
            sliderVisible: false

        }

        SliderControlLabeled{
            id: wattDisplay
            headingString: qsTr("Watts: ") + application.emptyString
            value:root.watts
            sliderVisible: false

        }

        SliderControlLabeled{
            id: speedControl
            headingString: qsTr("Target Speed") + application.emptyString
            displayValue: (value / 10.0).toFixed(1) + " MPH"
            minValue: 0
            maxValue: 150
            onValueChanged: machinecontrol.treadmillSpeedTarget = speedControl.value
            Component.onCompleted: value = machinecontrol.treadmillSpeedTarget
        }

        SliderControlLabeled{
            id: speedDisplay
            headingString: qsTr("Actual Speed") + application.emptyString
            value: 0
            displayValue: (value / 10.0).toFixed(1) + " MPH"
            minValue: 0
            maxValue: 100
            sliderVisible: false
        }

        SliderControlLabeled{
            id: inclineControl
            headingString: qsTr("Incline") + application.emptyString
            value: 0
            displayValue: (value / 10.0).toFixed(1) + " %"
            minValue: 0
            maxValue: 150
            stepValue: 5
            onValueChanged: machinecontrol.treadmillInclineTarget = inclineControl.value;
            Component.onCompleted: value = machinecontrol.treadmillInclineTarget
        }

        SliderControlLabeled{
            id: inclineADCDisplay
            headingString: qsTr("Incline ADC Value") + application.emptyString
            displayValue: machinecontrol.treadmillInclineADCActual
            minValue: 0
            maxValue: 4096
            sliderVisible: false
        }

        ToggleButtonLabeled{
            id: runModeToggle
            labelString: qsTr("Constant Power Mode") + application.emptyString

            onToggled: value == true ? machinecontrol.machineMode = MachineControl.MODE_CONSTANT_POWER : machinecontrol.machineMode = MachineControl.MODE_CONSTANT_TORQUE

            value: {
                switch(machinecontrol.machineMode){
                case MachineControl.MODE_CONSTANT_POWER: return true;
                case MachineControl.MODE_CONSTANT_TORQUE: return false;
                default: return false;

                }
            }
        }

        SliderControlLabeled{
            id: torqueControl
            headingString: qsTr("Torque Control") + application.emptyString
            minValue: 0
            maxValue: 470
            onValueChanged: {
                machinecontrol.machineMode = MachineControl.MODE_CONSTANT_TORQUE
                machinecontrol.workload = torqueControl.value;
            }
            //value: root.resistance
        }

        SliderControlLabeled{
            id: wattControl
            headingString:qsTr("Watt Control") + application.emptyString
            minValue: 0
            maxValue: 600
            onValueChanged: {
                machinecontrol.machineMode = MachineControl.MODE_CONSTANT_POWER
                machinecontrol.workload = wattControl.value
            }
            //value: root.resistance
        }

        SliderControlLabeled{
            id: estopDisplay
            headingString: qsTr("Safety Switch: ") + application.emptyString
            value: machinecontrol.estop
            displayValue: value ? qsTr("inserted") : qsTr("removed")
            sliderVisible: false

        }

        // Stride Adjust Elliptical
        SliderControlLabeled{
            id: strideAdjustControl
            headingString:qsTr("Stride Length") + application.emptyString
            minValue: machineinfo.adjustableStrideEllipticalMinStrideIn;
            maxValue: machineinfo.adjustableStrideEllipticalMaxStrideIn;
            onValueChanged: {
                machinecontrol.strideLengthTarget = value;
            }
            Component.onCompleted: value = machinecontrol.strideLengthTarget
            //value: brainboard.strideAdc / brainboard.strideAdcMax * 100
        }
        SliderControlLabeled{
            id: strideTorqueControl
            headingString:qsTr("Torque Control") + application.emptyString
            minValue: 0
            maxValue: 1000
            onValueChanged: {
                machinecontrol.machineMode = MachineControl.MODE_CONSTANT_TORQUE
                machinecontrol.workload = strideTorqueControl.value
            }
            //value: root.resistance
        }
        SliderControlLabeled{
            id: strideWattsControl
            headingString:qsTr("Watts Control") + application.emptyString
            minValue: 0
            maxValue: 600
            onValueChanged: {
                machinecontrol.machineMode = MachineControl.MODE_CONSTANT_POWER
                machinecontrol.workload = strideWattsControl.value
            }
            //value: root.resistance
        }

        SliderControlLabeled{
            id: strideRpmDisplay
            headingString: qsTr("Pedal RPM: ") + application.emptyString
            value:root.rpm
            sliderVisible: false
        }

        SliderControlLabeled{
            id: strideAdcDisplay
            headingString: qsTr("Stride ADC value: ") + application.emptyString
            value:root.strideAdc
            sliderVisible: false
        }

        InlineCheckbox {
            id: lowerLimitSwitchDisplay
            readOnly: true
            label: qsTr("Lower Limit Switch") + application.emptyString
            labelWidth: 360
            onImage: "../graphics/205/Red_Dot.png"
            offImage: "../graphics/205/Red_Dot_GRAYED.png"
            value: brainboard.strideLowerLimitSwitch
        }
        InlineCheckbox {
            id: upperLimitSwitchDisplay
            readOnly: true
            label: qsTr("Upper Limit Switch") + application.emptyString
            labelWidth: 360
            onImage: "../graphics/205/Red_Dot.png"
            offImage: "../graphics/205/Red_Dot_GRAYED.png"
            value: brainboard.strideUpperLimitSwitch
        }
    }

    ListView{
        id: mode
        spacing: -2
        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        width: root.width * 0.8
        height: root.height * 1.0
        model: controlList.model
        snapMode: ListView.SnapToItem
        interactive: false
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveVelocity: 10000
        currentIndex: controlList.curIndex
        highlight: Component {
            Item {
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && controlList.listening
                    border { left: 70; top: 5; bottom: 5; right: 70 }
                    source: "../graphics/tft/maintenance_menus_cursor.png"
                    width: mode.currentItem ? mode.currentItem.navCursorWidth + 70 : 0
                    height: 56
                    horizontalTileMode: BorderImage.Stretch
                }
            }
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to navigate, use <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to change value") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }

    states: [
        State {
            name: "EllipticalStride"
            PropertyChanges {target: estopDisplay ; visible:false }
            PropertyChanges {target: rpmDisplay ; visible:false }
            PropertyChanges {target: wattDisplay ; visible:false }
            PropertyChanges {target: speedDisplay ; visible:false }
            PropertyChanges {target: inclineADCDisplay ; visible:false }
            PropertyChanges {target: speedControl ; visible:false }
            PropertyChanges {target: inclineControl ; visible:false }
            PropertyChanges {target: runModeToggle ; visible: true }
            PropertyChanges {target: torqueControl ; visible:false }
            PropertyChanges {target: wattControl ; visible: false }
            PropertyChanges {target: strideAdjustControl; visible: true }
            PropertyChanges {target: strideTorqueControl; visible: !runModeToggle.value }
            PropertyChanges {target: strideWattsControl; visible: runModeToggle.value }
            PropertyChanges {target: strideRpmDisplay; visible: true }
            PropertyChanges {target: strideAdcDisplay; visible: true }
            PropertyChanges {target: lowerLimitSwitchDisplay; visible: true }
            PropertyChanges {target: upperLimitSwitchDisplay; visible: true }
        },
        State {
            name: "Elliptical"
            PropertyChanges {target: estopDisplay ; visible:false }
            PropertyChanges {target: rpmDisplay ; visible:true }
            PropertyChanges {target: wattDisplay ; visible:true }
            PropertyChanges {target: speedDisplay ; visible:false }
            PropertyChanges {target: inclineADCDisplay ; visible:false }
            PropertyChanges {target: speedControl ; visible:false }
            PropertyChanges {target: inclineControl ; visible:false }
            PropertyChanges {target: runModeToggle ; visible: true }
            PropertyChanges {target: torqueControl ; visible:!runModeToggle.value}
            PropertyChanges {target: wattControl ; visible: runModeToggle.value}
            PropertyChanges {target: strideAdjustControl; visible: false }
            PropertyChanges {target: strideTorqueControl; visible: false }
            PropertyChanges {target: strideWattsControl; visible: false }
            PropertyChanges {target: strideRpmDisplay; visible: false }
            PropertyChanges {target: strideAdcDisplay; visible: false }
            PropertyChanges {target: lowerLimitSwitchDisplay; visible: false }
            PropertyChanges {target: upperLimitSwitchDisplay; visible: false }
        },
        State {
            name: "Bike"
            PropertyChanges {target: estopDisplay ; visible:false }
            PropertyChanges {target: rpmDisplay ; visible:true }
            PropertyChanges {target: wattDisplay ; visible:true }
            PropertyChanges {target: speedDisplay ; visible:false }
            PropertyChanges {target: inclineADCDisplay ; visible:false }
            PropertyChanges {target: speedControl ; visible:false }
            PropertyChanges {target: inclineControl ; visible:false }
            PropertyChanges {target: runModeToggle ; visible: true }
            PropertyChanges {target: torqueControl ; visible:!runModeToggle.value}
            PropertyChanges {target: wattControl ; visible: runModeToggle.value}
            PropertyChanges {target: strideAdjustControl; visible: false }
            PropertyChanges {target: strideTorqueControl; visible: false }
            PropertyChanges {target: strideWattsControl; visible: false }
            PropertyChanges {target: strideRpmDisplay; visible: false }
            PropertyChanges {target: strideAdcDisplay; visible: false }
            PropertyChanges {target: lowerLimitSwitchDisplay; visible: false }
            PropertyChanges {target: upperLimitSwitchDisplay; visible: false }
        },
        State {
            name: "Treadmill"
            PropertyChanges {target: estopDisplay ; visible:true }
            PropertyChanges {target: rpmDisplay ; visible:false }
            PropertyChanges {target: wattDisplay ; visible:false }
            PropertyChanges {target: speedDisplay ; visible:true }
            PropertyChanges {target: inclineADCDisplay ; visible:true }
            PropertyChanges {target: speedControl ; visible:true }
            PropertyChanges {target: inclineControl ; visible:true }
            PropertyChanges {target: runModeToggle ; visible: false }
            PropertyChanges {target: torqueControl ; visible:false }
            PropertyChanges {target: wattControl ; visible:false }
            PropertyChanges {target: strideAdjustControl; visible: false }
            PropertyChanges {target: strideTorqueControl; visible: false }
            PropertyChanges {target: strideWattsControl; visible: false }
            PropertyChanges {target: strideRpmDisplay; visible: false }
            PropertyChanges {target: strideAdcDisplay; visible: false }
            PropertyChanges {target: lowerLimitSwitchDisplay; visible: false }
            PropertyChanges {target: upperLimitSwitchDisplay; visible: false }

        }
    ]

}
