import QtQuick 2.4
import ConfigurationData 1.0
import Brainboard 1.0
import Components 1.0
import "../string_format.js" as Format
import ".."


Rectangle {
    id: root
    width: 1366
    height: 768
    anchors.fill: parent
    state: ""
    color: "transparent"

    property int topOffset: 130
    property int itemSpacing: -10

    property int menuItemWidth: 150
    property int menuItemHeight: 75

    property int cooltime
    property int workouttimemax
    property int workoutsetuptimeout
    property int workoutsummarytimeout
    property int personpresenttimeout
    property bool languageDiagnosticMenu: false
    property int nouserdetecteddialogtimeout
    property int resumeworkouttimeout
    property bool userPresentDetection
    property int erpTimeout

    property bool datadirty: false

    signal close()

    onCooltimeChanged:{coolTimeControl.value = cooltime}
    onWorkoutsetuptimeoutChanged: {workoutSetupTimeoutControl.value = workoutsetuptimeout}
    onWorkouttimemaxChanged: {workoutTimeMaxControl.value = workouttimemax}
    onWorkoutsummarytimeoutChanged: {workoutSummaryTimeoutControl.value = workoutsummarytimeout}
    onPersonpresenttimeoutChanged: {personPresentTimeoutControl.value = personpresenttimeout}
    onNouserdetecteddialogtimeoutChanged: {noUserDetectedDialogTimeoutControl.value = nouserdetecteddialogtimeout}
    onResumeworkouttimeoutChanged: {resumeWorkoutTimeoutControl.value = resumeworkouttimeout}
    onUserPresentDetectionChanged: {userPresentDetectionToggle.value = userPresentDetection}
    onErpTimeoutChanged: {erpTimeoutControl.value = erpTimeout}

    Component.onCompleted: {
        cooltime = options.cooldownTime
        workouttimemax = options.workoutTimeMax
        workoutsetuptimeout = options.workoutSetupTimeout
        workoutsummarytimeout = options.workoutSummaryTimeout
        personpresenttimeout = options.personPresentTimeout
        nouserdetecteddialogtimeout = options.noUserDetectedDialogTimeout
        resumeworkouttimeout = options.resumeWorkoutTimeout
        userPresentDetection = options.ppdEnabled
        erpTimeout = options.erpTimeout
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        // handle exiting the screen
        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsTimers")
            diagnostics_screen.item.unselectScreen()
        }
    }

    KeyedControlList{
        id: controlList
        listening: root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0
        listView: mode

        SliderControlLabeled{
            id: coolTimeControl
            headingString: qsTr("Cooldown Time") + application.emptyString
            minValue: 0
            maxValue: 300
            stepValue: 60
            displayValue: Format.formatTimeStringMinAndSec(value)
            onValueChanged:
            {
                options.cooldownTime = value
                datadirty = true
            }
        }
        SliderControlLabeled{
            id: workoutTimeMaxControl
            headingString: qsTr("Maximum Workout Time") + application.emptyString
            minValue: 5
            maxValue: 99
            stepValue: 1
            displayValue: Format.formatTimeStringMinAndSec(value*60)
            onValueChanged:
            {
                options.workoutTimeMax = value
                datadirty = true
            }
        }
        SliderControlLabeled{
            id: workoutSetupTimeoutControl
            headingString: qsTr("Workout Setup Timeout") + application.emptyString
            minValue: 0
            maxValue: 120
            stepValue: 15
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF")
            onValueChanged:
            {
                options.workoutSetupTimeout = value
                datadirty = true
            }
        }
        SliderControlLabeled{
            id: workoutSummaryTimeoutControl
            headingString: qsTr("Workout Summary Timeout") + application.emptyString
            minValue: 0
            maxValue: 120
            stepValue: 15
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF")
            onValueChanged:
            {
                options.workoutSummaryTimeout = value
                datadirty = true
            }
        }
        SliderControlLabeled{
            id: resumeWorkoutTimeoutControl
            visible: true
            headingString: qsTr("Pause Timer") + application.emptyString
            minValue: 0
            maxValue: 60
            stepValue: 15
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF")
            onValueChanged:
            {
                options.resumeWorkoutTimeout = value
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: erpTimeoutControl
            visible: options.erpEnabled && main.erpIsSupported
            height: visible ? 60 : 0
            headingString: qsTr("Energy Saving Timer") + application.emptyString
            minValue: 900    // 15mins
            maxValue: 7200   // 2hrs(120mins)
            stepValue: 900   // 15mins
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF")
            onValueChanged:
            {
                options.erpTimeout = value
                datadirty = true
            }
        }

        ToggleButtonLabeled{
            id: userPresentDetectionToggle

            visible: brainboard.detectedMachineType === Brainboard.LOWERBOARD_DCI
            labelString: qsTr("User Present Detection") + application.emptyString
            onValueChanged:
            {
                options.ppdEnabled = value ? true : false
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: personPresentTimeoutControl
            visible: (brainboard.detectedMachineType === Brainboard.LOWERBOARD_DCI && options.ppdEnabled === true)
            headingString: qsTr("User Present Detection TIMER 1") + application.emptyString
            minValue: 20
            maxValue: 300
            stepValue: 20
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF")
            onValueChanged:
            {
                options.personPresentTimeout = value
                datadirty = true
            }
        }
        SliderControlLabeled{
            id: noUserDetectedDialogTimeoutControl
            visible: (brainboard.detectedMachineType === Brainboard.LOWERBOARD_DCI && options.ppdEnabled === true)
            headingString: qsTr("User Present Detection TIMER 2") + application.emptyString
            minValue: 0
            maxValue: 60
            stepValue: 20
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF")
            onValueChanged:
            {
                options.noUserDetectedDialogTimeout = value
                datadirty = true
            }
        }

    }

    ListView{
        id: mode
        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        width: root.width * 0.8
        height: root.height * 0.8
        model: controlList.model
        snapMode: ListView.SnapToItem
        interactive: false
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveVelocity: 10000
        currentIndex: controlList.curIndex
        highlight: Component {
            Item {
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && controlList.listening
                    border { left: 70; top: 5; bottom: 5; right: 70 }
                    source: "../graphics/tft/maintenance_menus_cursor.png"
                    width: mode.currentItem ? mode.currentItem.navCursorWidth + 70 : 0
                    height: 56
                    horizontalTileMode: BorderImage.Stretch
                }
            }
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to navigate, use <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> to change value") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
