import QtQuick 2.4
import "../Keypad"
import Components 1.0

BorderImage {
    id: root

    property variant model: wifiScanner.accessPoints
    property bool hideWireless: false

    signal selected(variant accessPoint)
    signal canceled()

    onVisibleChanged: {
        if(visible && !hideWireless)
            wifiScanner.startScan()
    }

    Component.onCompleted: {
        if (hideWireless) {
            wifiScanner.accessPoints.insert(0, { essid:"Wired Ethernet", interface:"p2p1", encrypted: false } )
        }
    }

    Connections {
        target: wifiScanner
        onScanComplete: {
            // add the hardwired Ethernet option at top of list
            wifiScanner.accessPoints.insert(0, { essid:"Wired Ethernet", interface:"p2p1", encrypted: false } )
        }
    }

    width: 600
    height: 500

    source: "../graphics/Pop_Up_Lrg_Grey.png"
    border { top: 152; bottom: 165; left: 145; right: 144 }

    MouseArea {
        // prevent under-clicks
        anchors.fill: parent
    }

    // gray background for wifi scan result list
    Rectangle {
        color: "gray" ;
        border { color: "black" ; width: 2 }
        anchors { fill: wifiList ; margins: -8 }
    }

    AlphaKeypad {
        id: wifiKeypad
        anchors { horizontalCenter: parent.horizontalCenter ; bottom: parent.bottom }
        visible: false
        password_entry: true
        instructions: qsTr("password: ") + application.emptyString
        z: 9999
        onClose: hide()
    }

    ListView {
        id: wifiList

        property variant selectedItem

        onCurrentIndexChanged: selectedItem = model.get(currentIndex)

        model: root.model
        delegate: listDelegate

        clip: true
        width: 260
        height: 280
        anchors{ left: parent.left ; leftMargin: 80 ; top: parent.top ; topMargin: 60 }

        highlight: Rectangle { color: "darkgray" ; radius: 5 ; opacity: 0.7 ; width: 400 }
        highlightMoveVelocity: 1500
    }

    Text {
        text: qsTr("Scanning for wireless networks...")
        visible: wifiScanner.scanning

        anchors { bottom: wifiList.top ; bottomMargin: 5 ; left: wifiList.left }
    }

    Component {
        id: listDelegate
        Item {
            width: wifiList.width
            height: accessPointDelegate.height

            MouseArea {
                anchors.fill: parent
                onClicked: wifiList.currentIndex = index
            }

            Row {
                id: accessPointDelegate
                spacing: 5
                Image { source: encrypted ? "../graphics/padlock.png" : "../graphics/padlock-unlocked.png" }
                Text { text: essid ? essid : "" ; height: paintedHeight ; anchors.verticalCenter: parent.verticalCenter }
            }
        }
    }

    // get password result typed in alpha keypad
    Connections {
        target: wifiKeypad
        ignoreUnknownSignals: true

        onValueEntered: {
            wifiKeypad.hide()
            wifiList.selectedItem.password = val
            selected(root.model.get(wifiList.currentIndex))
            wifiKeypad.clear()
        }

        onClose: wifiKeypad.clear()
    }

    ImageButton {
        id: connectButton

        upimage: "../graphics/205/SM_Button_Up.png"
        downimage: "../graphics/205/SM_Button_Down.png"
        visible: wifiList.selectedItem ? true : false

        label: wifiList.selectedItem ? qsTr("Connect " + wifiList.selectedItem.essid) : ""
        label_under: true
        label_color: "black"
        label_y_offset: 5

        width: 120
        anchors { right: parent.right ; rightMargin: 80 ; bottom: parent.bottom ; bottomMargin: 60 }

        onClicked: {
            if(!wifiList.selectedItem.encrypted)
                selected(root.model.get(wifiList.currentIndex))
            else {
                wifiKeypad.clear()

                if(wifiList.selectedItem.essid === netpulse.wirelessESSID)
                    wifiKeypad.setValue(netpulse.wirelessPSK)
                wifiKeypad.show()
            }
        }
    }

    ImageButton {
        id: cancelButton

        upimage: "../graphics/205/SM_Button_Up.png"
        downimage: "../graphics/205/SM_Button_Down.png"

        label: qsTr("Cancel")
        label_under: true
        label_color: "black"
        label_y_offset: 5

        anchors { left: parent.left; leftMargin: 110 ; bottom: parent.bottom ; bottomMargin: 60 }

        onClicked: {
            wifiKeypad.clear()
            root.canceled()
        }
    }

    ImageButton {
        id: scanButton

        upimage: "../graphics/205/SM_Button_Up.png"
        downimage: "../graphics/205/SM_Button_Down.png"
        visible: !hideWireless && !wifiScanner.scanning

        label: qsTr("Scan")
        label_under: true
        label_color: "black"
        label_y_offset: 5

        width: 120
        anchors { right: parent.right ; rightMargin: 80 ; top: wifiList.top; topMargin: 10 }

        onClicked: {
            wifiScanner.startScan()
        }
    }

    WifiScan {
        id: wifiScanner
    }
}
