import QtQuick 2.4
import "Diagnostics"
import Components 1.0

ModalDialog{
    id: firmwareUpdatingDialog

    property alias text: bootLoadStatusText.text
    property alias instructionText: instructionText.text

    signal complete()

    width: 950
    height: 450

    anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: parent.verticalCenter }

    state: "searching_state"

    Component.onCompleted:{ hexPollTimer.start() }

    BorderImage {   // pop-up dialog background
        id: borderImage

        anchors.fill: parent
        source: "graphics/Pop_Up_Lrg_Grey.png"
        border { top: 152; bottom: 165; left: 145; right: 144 }

        Text{
            id: bootLoadStatusText
            text:""
            color: "white"
            font { bold: true ; pixelSize: 50 }
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            anchors { horizontalCenter: parent.horizontalCenter ; bottom: bootloadProgress.top ; bottomMargin: 5 }
        }

        Text{
            id: instructionText
            text:""
            color: "white"
            font { bold: true ; pixelSize: 50 }
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            anchors { horizontalCenter: parent.horizontalCenter ; top: bootLoadStatusText.bottom ; topMargin: 5 }
        }

        Rectangle {
            id: bootloadProgress

            visible: firmwareLoader.progress > 0
            width: 400
            height: 50
            color: "transparent"
            border { color: "white" ; width: 5 }
            anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: parent.verticalCenter }

            radius: 5
            Rectangle {
                z: bootloadProgress - 1
                anchors { left: parent.left; top: parent.top ; bottom: parent.bottom }
                radius: 5
                color: "steelblue"
                width: firmwareLoader.progress * parent.width / 100
                height: parent.height
            }
        }
    }

    Timer {
        id: hexPollTimer
        interval: 5000
        repeat: true
        running: true
        onTriggered: firmwareLoader.checkForUpdates()
    }

    // Timer to allow removal of USB before loading to allow one to change one's mind
    Timer {
        id: waitToLoadTimer
        interval: 5000
        repeat: false
        running: false
        onTriggered: {
            // check the USB on last time.  If it's been removed, abort the load
            if(firmwareLoader.fromUSB) {
                firmwareLoader.checkForUpdates()
                if(firmwareLoader.fromUSB)
                    firmwareLoader.loadFirmware(firmwareLoader.firmwareUpdateFile)
                else
                    firmwareUpdatingDialog.state = "searching_state"
            } else {
                firmwareLoader.loadFirmware(firmwareLoader.firmwareUpdateFile)
            }
            running = false
        }
    }

    FirmwareLoader {
        id: firmwareLoader

        onFaultMsg:firmwareUpdatingDialog.text = message
        onStatus: firmwareUpdatingDialog.text = message

        onUpdateStarted: firmwareUpdatingDialog.state = "loading_state"
        onUpdateFinished: firmwareUpdatingDialog.state = "completed_state"

        onFirmwareFound: {
            firmwareUpdatingDialog.state = "waiting_state"
        }
    }

    states: [
        State {
            name: "searching_state"
            PropertyChanges{ target: firmwareUpdatingDialog ; instructionText: qsTr("Insert USB to load Firmware.") }
            PropertyChanges{ target: firmwareUpdatingDialog ; text: qsTr("Fault CN25: Firmware Mismatch") }
            PropertyChanges{ target: hexPollTimer; running: true }
        },
        State {
            name: "waiting_state"
            PropertyChanges{
                target: firmwareUpdatingDialog ;
                instructionText: qsTr("Load") + " " + firmwareLoader.firmwareUpdateVersion + ". " + (firmwareLoader.fromUSB ? qsTr("Remove USB now to abort") : "")
            }
            PropertyChanges{ target: hexPollTimer; running: false }
            PropertyChanges{ target: waitToLoadTimer; running: true }
        },
        State {
            name: "loading_state"
            PropertyChanges{ target: firmwareUpdatingDialog ; instructionText: "" }
            PropertyChanges{ target: hexPollTimer; running: false }
            PropertyChanges{ target: waitToLoadTimer; running: false }
        },
        State {
            name: "completed_state"
            PropertyChanges{ target: firmwareUpdatingDialog ; instructionText: qsTr("Power Cycle Required.")  }
            PropertyChanges{ target: hexPollTimer; running: false }
            PropertyChanges{ target: waitToLoadTimer; running: false }
        }
    ]
}

