import QtQuick 2.4
import Components 1.0

Item {
    id: item1

    width: 1366
    height: 760

    signal close()

    Connections {
        target: main.isTft && item1.visible && item1.opacity > 0 ? keymapper : null

        onBackPressed: {
            item1.close()
        }
    }

    // mouse area masks other mouse areas underneath
    MouseArea {
        anchors.fill: parent
    }

    Image {
        id: background
        z: -2
        visible: true
        anchors.fill: parent
        source: "graphics/Background.png"
    }
    // back button
    Row {
        id: row1
        visible: main.isTouch
        x: 1183
        y: 16
        anchors.top: parent.top
        anchors.topMargin: 13
        anchors.right: parent.right
        anchors.rightMargin: 15

        ImageButton {
            id: back_button
            upimage: "graphics/navbar/Navigation_Arrow_Disabled.png"
            downimage: "graphics/navbar/Navigation_Arrow_Down.png"
            onClicked: close()
            labelClickable: true
            label: qsTr("BACK") + application.emptyString
            font.bold: true
            label_color: "#A0A0A0"
            label_x_offset: 50
        }

    } // end back button row

    // build data set for heart rate chart
    Component.onCompleted: {
        var maxVals = [200, 195, 190, 185, 180, 175, 170, 165, 160, 155, 149, 143, 137 ]
        var age, i, max, min

        hrcWeightLossTable.append( { label: QT_TR_NOOP("60-75% MAX"), cellTextColor: "red" } )
        hrcAerobicTable.append( { label: QT_TR_NOOP("75-85% MAX"), cellTextColor: "red" } )
        hrcPerformanceTable.append( { label: QT_TR_NOOP("85%-100% MAX"), cellTextColor: "red" } )
        ageModel.append( { label: "" } )  // empty row in age column

        for (i=0, age=20 ; age< 85 ; i++, age+=5 ) {
            ageModel.append( { label: age } )

            min = maxVals[i] * 0.60
            max = maxVals[i] * 0.75
            hrcWeightLossTable.append( { label: min.toFixed(0) + "-" + max.toFixed(0) } )

            min = maxVals[i] * 0.75
            max = maxVals[i] * 0.85
            hrcAerobicTable.append( { label: min.toFixed(0) + "-" + max.toFixed(0) } )

            min = maxVals[i] * 0.85
            max = maxVals[i] * 1.0
            hrcPerformanceTable.append( { label: min.toFixed(0) + "-" + max.toFixed(0) } )
        }
    }

    Image {
        id: iconHRC
        x: 10
        y: 1
        source: "graphics/200/Workout_HRC_Icon.png"
    }

    Text {
        x: 130
        y: 43
        width: 427
        height: 58
        color: "#177ad7"
        text: qsTr("Use this Heart Rate Chart to determine the correct heart rate for your age and workout goal.") + application.emptyString
        anchors.bottom: iconHRC.bottom
        anchors.bottomMargin: 20
        anchors.left: iconHRC.right
        anchors.leftMargin: -5
        font.pointSize: 14
        wrapMode: Text.WordWrap
    }

    ListModel {
        id: ageModel

        property int width: 250
        property int hAlign: Text.AlignHCenter
        property string heading: qsTr("AGE") + application.emptyString
        property bool showLines: false
        property string cellTextColor: "#00808F"
        property string headingTextColor: cellTextColor
    }

    ListModel {
        id: hrcWeightLossTable

        property string heading: qsTr("WEIGHT LOSS") + application.emptyString
        property url bgimage: "graphics/summary/Work_Summary_Column1.png"
        property int hAlign: Text.AlignHCenter
    }

    ListModel {
        id: hrcAerobicTable

        property string heading: qsTr("AEROBIC") + application.emptyString
        property url bgimage: "graphics/summary/Work_Summary_Column2.png"
        property int hAlign: Text.AlignHCenter
    }

    ListModel {
        id: hrcPerformanceTable

        property string heading: qsTr("PERFORMANCE") + application.emptyString
        property url bgimage: "graphics/summary/Work_Summary_Column3.png"
        property int hAlign: Text.AlignHCenter
    }

    DataTable {
        id: heartRateTable
        sourceFile: "HeartRateGuide"
        x:-4
        y: main.isTouch ? 121 : 96

        colWidth: 430
        height: 630
        models: [ ageModel, hrcWeightLossTable, hrcAerobicTable, hrcPerformanceTable ]
    }

    Text {
        id: bottomHelpText

        visible: main.isTft
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("press BACK to return") + application.emptyString

        anchors {
            bottom: parent.bottom
            bottomMargin: 25
            horizontalCenter: parent.horizontalCenter
        }
    }

    Text {
        id: guideTitle
        x: 962
        y: 52
        text: qsTr("HEART RATE GUIDE") + application.emptyString
        anchors.top: parent.top
        anchors.topMargin: main.isTouch ? 77 : 52
        anchors.right: parent.right
        anchors.rightMargin: 76
        font.bold: true
        font.pixelSize: 35
    }
}
