import QtQuick 2.4
import StorageMgr 1.0
import WorkoutManager 1.0
import "tft_workout_menus.js" as TftMenus
import Components 1.0

Item {
    id: root

    property int maxFiles: 5
    property string savedProgramPath: "/data/saved_programs/"
    property string profile1Title: ""
    property string profile2Title: ""

    onVisibleChanged: {
        if (visible === false && setupScreenManager.state === "LoadSavedWorkouts")
            visible = true
    }

    function savedProgModel() {
        var modelList = savedFileList();
        modelList.unshift("Back");
        return modelList;
    }

    function show() {
        savedProgList.model = savedProgModel()
        savedProgList.currentIndex = 0
        showSynopsis(savedProgList.currentIndex)
        visible = true
    }

    function showSynopsis(index) {
        if (!visible) return

        console.log("showSynopsis: loading ", index)
        savedWorkoutSynopsis.visible = false
        if (savedProgList.model[index] == "Back") {
            loadingText.visible = false
            savedWorkoutSynopsis.visible = false
            mainProgItem.setProgramName("SAVED WORKOUTS")
        }
        else if (savedProgList.model[index] == "--") {
            loadingText.visible = false
            savedWorkoutSynopsis.visible = false
            image_model.setProperty(index, "image", "tft/blank.png")
            mainProgItem.setProgramName("SAVED WORKOUTS")
        }
        else {
            workoutProgram.loadSaveProg(index)
            savedWorkoutSynopsis.visible = false
            loadingText.visible = true
            mainProgItem.setProgramName(savedProgList.model[savedProgList.currentIndex])
        }
    }

    Connections {
        target: main.isTft && main.state === "SetupState" && setupScreenManager.state === "LoadSavedWorkouts" ? workoutProgram : null
        onLoadSaveProgramComplete: {
            image_model.setProperty(savedProgList.currentIndex, "image", TftMenus.getProgramImage(workoutProgram.programIndex))
            loadingText.visible = false
            savedWorkoutSynopsis.visible = true
        }
    }

    // populate the list of saved files from directory listing
    function savedFileList() {
        var storedFiles = storage.listFiles(savedProgramPath, "*.xml")
        var newList = [];
        var idx=0
        for(var i=0 ; i < root.maxFiles ; i++) {
            // files are prefixed with 1_, 2_, etc.  Assume list is sorted.
            if(storedFiles[idx] && (storedFiles[idx][0] == (i+1).toString()) ) {
                var progName = storedFiles[idx].split(".");
                var tempStr = progName[0];
                newList[i] = tempStr.substr(2);
                newList[i] = application.translateText("Menu", newList[i]);
                idx++
            }
            else
                newList[i] = "--"
        }
        return newList
    }

    StorageMgr {
        id: storage
    }

    SavedProgramSynopsis {
        id: savedWorkoutSynopsis
        visible: savedProgList.model[savedProgList.currentIndex] !== "--" && savedProgList.model[savedProgList.currentIndex] !== "Back"
        distanceFromTop: 50
        distanceFromLeft: 1090
        setupAge: ageForProgSummary
        setupWeight: weightForProgSummary
        profile1Title: root.profile1Title
        profile2Title: root.profile2Title
    }

    Item {
        id: centeringRectangle
        width: 530
        height: 410
        anchors { right: parent.right; rightMargin: 90; top: parent.top; topMargin: 55 }
        visible: false
    }

    Text {
        id: loadingText
        text: qsTr("LOADING...") + application.emptyString
        anchors.centerIn: centeringRectangle
        font { pixelSize: 16; family: "arial"; bold: true }
        visible: false
    }

    Connections {
        target: !main.blockKeys && main.state === "SetupState" && setupScreenManager.state === "LoadSavedWorkouts" ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "KeyedSavedProgramsBrowser")
            workoutProgram.abortWorkoutLoad()
            savedProgList.decrementCurrentIndex();
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "KeyedSavedProgramsBrowser")
            workoutProgram.abortWorkoutLoad()
            savedProgList.incrementCurrentIndex();
        }

        onBackPressed: {
            main.debugKeys("backPressed", "KeyedSavedProgramsBrowser")
            workoutProgram.abortWorkoutLoad()
            navbar.goBack();
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "KeyedSavedProgramsBrowser")
            if (workoutProgram.parsingFile)
                return

            if (savedProgList.model[savedProgList.currentIndex] === "Back") {
                navbar.goBack();
            } else if (savedProgList.model[savedProgList.currentIndex] !== "--") {
                mainProgItem.nextState();
            }
        }
    }

    ListModel {
        id: image_model
        ListElement { image: "WF/WF_window_back_nav.png"; modestyImage: "WF/MaleOnly/WF_image_BACK_15inTFT.png"; desc: QT_TR_NOOP("Return to workout menu") }
        ListElement { image: "tft/blank.png"; desc: "" }
        ListElement { image: "tft/blank.png"; desc: "" }
        ListElement { image: "tft/blank.png"; desc: "" }
        ListElement { image: "tft/blank.png"; desc: "" }
        ListElement { image: "tft/blank.png"; desc: "" }
    }

    ProgramBrowser {
        id: browser
        currentIndex: savedProgList.currentIndex
        width: 700
        opacity: root.opacity
        model: image_model
        showArrows: false
    }

    Text {
        id: noSavedText
        visible: savedProgList.model[savedProgList.currentIndex] == "--"
        text: qsTr("NO SAVED WORKOUT") + application.emptyString
        anchors {
            bottom: savedProgList.top
            bottomMargin: 200
            left: browser.right
            leftMargin: 50
        }
        smooth: true
        font.bold: true
        font.pixelSize: 14
    }


    ListView {
        id: savedProgList

        width: 900
        height: 200
        interactive: false
        onCurrentIndexChanged: showSynopsis(currentIndex)
        highlight: Component {
            id: customHighlight
            Image {
                source: "graphics/tft/NAV_selector.png"
                x: savedProgList.currentItem.x - 50
            }
        }
        highlightFollowsCurrentItem: false
        orientation: ListView.Horizontal
        keyNavigationWraps: true
        model: savedProgModel()
        delegate: savedProgramDelegate
        anchors { horizontalCenter: parent.horizontalCenter; bottomMargin: 115; bottom: parent.bottom }
    }

    Component { id: savedProgramDelegate
        Item { id: savedProgBackground
            width: 144
            height: 200
            anchors { leftMargin: 50; rightMargin: 50 }

            ImageButton {
                width: 126
                height: 76
                id: theButton
                fontsize: 16

                label: {
                    switch (modelData) {
                    case "Back":
                        return qsTr("Back") + application.emptyString
                    case "--":
                        return qsTr("SAVED WORKOUT") + " " + (index) + application.emptyString
                    default:
                        return qsTr("SAVED") + " " + modelData + application.emptyString
                    }
                }
                label_under: true
                label_y_offset: modelData === "--" ? 64 : 50
                label_color: "black"
                wrapWidth: 80

                anchors.top: parent.top
                anchors.topMargin: 30
                anchors.horizontalCenter: parent.horizontalCenter
                upimage: {
                    switch (modelData) {
                        case "Back":
                            return "graphics/tft/nav_icon_BACK.png"
                        case "--":
                            return "graphics/tft/dashdash.png"
                        default:
                            return "graphics/tft/nav_icon_SAVED.png"
                    }
                }
                downimage: upimage
                beep: false
                mouseAreaScale: 0.7
            }
        }
    }

    Text {
        id: bottomHelpText

        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: {
            var txt = ""
            if (savedProgList.model[savedProgList.currentIndex] == "--")
                txt = qsTr("there is NO SAVED WORKOUT")
            else if (savedProgList.model[savedProgList.currentIndex] == "Back")
                txt = ""
            else
                txt = qsTr("press ENTER to select")

            return txt + application.emptyString
        }

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
