import QtQuick 2.4
import Components 1.0

FocusScope {
    id: root

    // menu property is a menu dictionary from workout_menus.js to be displayed in the list
    property variant menu
    property alias currentIndex: linemenu.currentIndex

    signal workoutSelected( variant item, variant menu )
    signal menuSelected( variant menu ) // signal emitted when a sub-menu is selected. menu parameter is a javascript menu dictionary from workout_menus.js

    onActiveFocusChanged: print("!!!!!!!!!workout menu focus:" + activeFocus)
    function changeMenu( menu, highlightIndex ) {
        workout_menu_model.changeMenu(menu)
        linemenu.model = undefined
        linemenu.model = workout_menu_model
        linemenu.currentIndex = -1
        linemenu.currentIndex = highlightIndex || 0
        description_flip_timer.interval = 6000
        description_flip_timer.restart()
    }

    Connections {
        target: !main.blockKeys &&  main.state === "MenuState" ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "KeyedWorkoutMenu")
            if (!browser.moving) {
                if (linemenu.currentIndex === 0) {
                    linemenu.highlightMoveVelocity = 4000
                    linemenu.currentIndex = linemenu.count - 1
                    linemenu.positionViewAtEnd()
                    linemenu.highlightMoveVelocity = 400
                } else
                    linemenu.decrementCurrentIndex();
                description_flip_timer.restartWithDelay();
            }
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "KeyedWorkoutMenu")
            if (!browser.moving) {
                if (linemenu.currentIndex === linemenu.count - 1) {
                    linemenu.highlightMoveVelocity = 4000
                    linemenu.currentIndex = 0
                    linemenu.positionViewAtBeginning()
                    linemenu.highlightMoveVelocity = 400
                } else
                    linemenu.incrementCurrentIndex();
                description_flip_timer.restartWithDelay();
            }
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "KeyedWorkoutMenu")
            workout_menu_model.selectIndex(linemenu.currentIndex)
        }

        onBackPressed: {
            main.debugKeys("backPressed", "KeyedWorkoutMenu")
            navbar.goBack();
        }
    }

    // re-translate the menu strings when the language changes
    Connections {
        target: application
        onLanguageChanged: { workout_menu_model.updateStrings() }
    }

    ProgramBrowser {
        id: browser

        opacity: root.opacity
        focus: visible && (opacity > 0)
        showArrows: false

        // wait a full timer period after user flips before flipping again
        onMovingChanged: { description_flip_timer.restart() }

        model: workout_menu_model
    }

    MenuModel {
        id: workout_menu_model

        onChangeMenuCallback: {
            // remove the SAVED WORKOUTS menu item if the feature is disabled
            if (options.saveWorkoutEnabled === false) {
                var removeIndex = menudef.children.findIndex(function (child) { return child.program === "SAVED_WORKOUTS" })
                if (removeIndex >= 0)
                    remove(removeIndex)
            }

        }

        onMenu_currentChanged: {
            root.menu = menu_current // keep top level property in sync with model
            description_flip_timer.interval = 6000
            description_flip_timer.restart()
        }

        Component.onCompleted: {  // set the top level menu at startup
            changeMenu(root.menu)
        }

        // calling selectItem() causes either the menuSelected or optionSelected signals handled below
        onMenuSelected: {  // a sub-menu was selected
            root.menuSelected(workout_menu_model.menu_current)
        }

        // a workout program was selected
        onOptionSelected: {
            if( item.program )  // don't launch if program not implemented
            {
                workoutSelected(item, workout_menu_model.menu_current)
            } else if (item.action) {
                if (item.action === "back") {
                    navbar.goBack();
                } else if (item.action === "show_all_workouts") {
                    main.state = "AllWorkoutsState"
                }
            }
        }

    }
    Connections {
        target: workout_menu_model
        onMenu_currentChanged: {
            linemenu.model = undefined
            linemenu.model = workout_menu_model
            linemenu.currentIndex = 0
        }
    }

    Component {
        id: workoutNavDelegate
        Item {

            width: 160
            height: 220
            property alias button: theButton

            ImageButton {
                id: theButton
                fontsize: 16

                label: model.label
                label_under: true
                label_y_offset: 50
                label_color: "black"
                wrapWidth: 80

                anchors.top: parent.top
                anchors.topMargin: 30
                anchors.horizontalCenter: parent.horizontalCenter
                upimage: Globals.graphicsPath+model.icon
                downimage: Globals.graphicsPath+model.icon
                beep: false
                mouseAreaScale: 0.7

            }
        }
    }

    // pseudo-highlight item for the listview, so that the highlight can be wider than the delegates
    // without worrying about clipping issues, because it is drawn on top of the list view
    Image {
        source: "graphics/tft/NAV_selector.png"
        smooth: true
        x: linemenu.currentItem ? linemenu.x + (linemenu.currentItem.x - linemenu.contentX - 40) : linemenu.x
        y: linemenu.y
        Behavior on x {
            SmoothedAnimation {
                duration: 150
            }
        }
    }

    ListView {
        id: linemenu
        onCurrentIndexChanged: browser.currentIndex = linemenu.currentIndex

        model: workout_menu_model
        delegate: workoutNavDelegate
        cacheBuffer: 400
        width: linemenu.model ? (linemenu.model.count < 7 ? 160 * linemenu.model.count : 160*7) : 1366
        height: 230
        interactive: false
        orientation: ListView.Horizontal
        clip: true
        preferredHighlightBegin: width/2 - 80
        preferredHighlightEnd: width/2 + 80
        highlightRangeMode: ListView.ApplyRange
        anchors {
            bottom: parent.bottom; bottomMargin: 85
            horizontalCenter: parent.horizontalCenter
        }
    }

    Text {
        id: bottomHelpText

        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to select") + application.emptyString

        anchors {
            bottom: parent.bottom
            bottomMargin: 25
            horizontalCenter: parent.horizontalCenter
        }
    }

    ImageButton {
        id: moreButtonLeft
        visible: !linemenu.atXBeginning

        upimage: "graphics/tft/arrow_MORE_nav_left.png"
        downimage: upimage
        fontsize: 16

        label: qsTr("MORE") + application.emptyString
        label_under: true
        label_y_offset: 50
        label_color: "#9c9c9c"

        anchors {
            right: linemenu.left
            rightMargin: 10
            verticalCenter: linemenu.verticalCenter
        }
    }

    ImageButton {
        id: moreButtonRight
        visible: !linemenu.atXEnd

        upimage: "graphics/tft/arrow_MORE_nav.png"
        downimage: upimage
        fontsize: 16

        label: qsTr("MORE") + application.emptyString
        label_under: true
        label_y_offset: 50
        label_color: "#9c9c9c"

        anchors {
            left: linemenu.right
            leftMargin: 10
            verticalCenter: linemenu.verticalCenter
        }
    }

    Timer {
        id: description_flip_timer
        interval: 6000; running: true ; repeat: true
        function restartWithDelay() {
            interval = 15000;
            restart();
        }
        onTriggered: { linemenu.incrementCurrentIndex(); interval = 6000 }
    }

}
