import QtQuick 2.4

// Keypad.qml - Keypad control for entering numeric information.

import Components 1.0

import "../"

Item {
    id: root

    signal valueEntered (string val)
    signal keyPress(string key)
    signal close()

    property variant keys_model: state === "lowercase" ? lowercase_keys : uppercase_keys
    property string units: ""
    property int length:20
    property bool allow_close: true
    property bool show_entry: true
    property bool clear_after_enter: true
    property string instructions: ""
    property string keyEntryText: ""
    property string value: keyEntryText
    property string icon : ""
    property string keyImage: "keyboard_single"
    property Item targetItem: null
    property bool password_entry: false
    property bool showPassword: false

    property bool _enterPressed: false

    width: keypad_box.width
    height: childrenRect.height

    state: "lowercase"

    function getRootItem(child) {

        var top
        top = child

        if( !child )
            return child

        while( top.parent ) {
            top = top.parent
        }
        return top
    }

    function show() {
        root.parent = getRootItem(root)
        root.visible = true
    }

    function hide() {
        root.visible = false
    }

    function clear() {
        _enterPressed = false
        keyEntryText = ""
    }

    function setValue(val) {
        keyEntryText = val
        _enterPressed = true  // next keypress will first clear entry
    }

    onKeyPress: {
        add(key);
    }

    function keyFunction(val) {
        print("key function: " + val)
    }

    function add(val) {
        // clear the entry first if the old value is still shown after pressing enter
        if (keyEntryText[0] === "-" )
            keyEntryText = ""
        if (val === "<<" )
        {
            keyEntryText = keyEntryText.slice(0,-1)
            val = ""
        }
        else if (val === "ENTER" )
        {
            valueEntered(value)
            if (root.clear_after_enter)
                keyEntryText = ""
            root._enterPressed = true
            return
        }
        else {
            keyEntryText = keyEntryText + val
        }
    }

    // stack top entry box on top of keypad
    Item {
        id: keypad_top

        visible: show_entry

        height: visible ? 127 : 0
        width: keypad_box.width
        // rounded rectangle where entered data is displayed
        Rectangle {
            id: entrybox
            radius: 10
            border.color: "black"
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 5
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 0
            clip: true
            width: keypad_box.width
            height: 45

            Flickable {
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 5
                contentWidth: entrytext.width
                contentHeight: entrytext.height
                width: parent.width - 50
                height: parent.height
                contentX: Math.max(0, entrytext.width - entrybox.width + 50)
                Text {
                    id: entrytext
                    property string hiddenText: root.value.length ? Array(root.value.length).join("*") + root.value[root.value.length-1] : ""
                    text: instructions + (root.password_entry && !root.showPassword ? hiddenText : root.value) + "|"
                    font.pointSize: 16
                    font.bold: true
                    verticalAlignment: Text.AlignVCenter
//                    horizontalAlignment: (width < parent.width) ? Text.AlignLeft : Text.AlignRight
                }
            }

            Item {
                id: showPasswordCheckbox
                visible: root.password_entry
                width: childrenRect.width
                anchors { verticalCenter: entrybox.verticalCenter ; right: clear_button.left ; leftMargin: 20 }
                Text {
                    text: qsTr("Show?") + application.emptyString
                    font.bold: true
                    anchors { left: parent.left; verticalCenter: parent.verticalCenter }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            showPassToggle.setDown(!showPassToggle.isDown)
                        }
                    }
                }
                ImageButton {
                    id: showPassToggle
                    toggle: true
                    upimage: "../graphics/Unchecked.png"
                    downimage: "../graphics/Checked.png"
                    anchors { right: parent.right; verticalCenter: parent.verticalCenter }
                    onIsDownChanged: {
                        root.showPassword = isDown
                    }
                }
            }

            ImageButton {
                id: clear_button
                visible: root.value.length
                onClicked: setValue("")
                upimage: "KeyPad_X.png"
                downimage: "KeyPad_X.png"
                anchors { verticalCenter: entrybox.verticalCenter ; right: entrybox.right ; rightMargin: 3 }
                anchors.leftMargin: 0
            }
        }
    }

    ImageButton {
        id: close_button
        visible: root.allow_close
        onClicked: close()
        upimage: "../graphics/netpulse/GRAYbutton_video.png"
        downimage: "../graphics/netpulse/GRAYbutton_video_PRESSED.png"
        anchors.verticalCenter: keypad_top.verticalCenter
        anchors.left: keypad_top.right
        anchors.leftMargin: 0
        label: "X"
        label_color: "black"
        fontsize: 34
        label_x_offset: 1
        label_y_offset: 1
    }

    // main keypad body
    Rectangle {
        id: keypad_box

        visible: true
        anchors.top: keypad_top.bottom
        anchors.topMargin: -37
        anchors.horizontalCenter: keypad_top.horizontalCenter
        x: 10
        y: 90
        width: 815
        height: 300
        anchors.horizontalCenterOffset: 0
        smooth: true
        color: "gray"
        border.color: "black"
        border.width: 5
        radius: 20

        MouseArea {
            anchors.fill: parent
            onClicked: {} // Block clicks from affecting items underneath
        }

        Column {
            id: keypad_column
            anchors.fill: parent
//            anchors.top: parent.top
            anchors.topMargin: 10
//            anchors.left: parent.left
            anchors.leftMargin: 15
            anchors.rightMargin: 15
            //anchors.horizontalCenter: parent.horizontalCenter
            spacing: 0
            Flow {
                id: keygrid
                //rows: 4
                //columns: 10
                width: parent.width
                spacing: 5
                anchors.horizontalCenter: parent.horizontalCenter

                Repeater {
                    model: keys_model
                    delegate: keypad_button
                }
            }
        }
    }

    // delegate for keypad button
    Component {
        id: keypad_button
        ImageButton {
            upimage: model.buttonimage + "_UP.png"
            downimage: model.buttonimage + "_DOWN.png"
            icon: image ? image : ""
            label: size ? value : ""
            label_color: "black"
            label_visible: (application.currentLanguage !== "en" && value === "ENTER") ? false : true
            fontsize: size
            label_x_offset: x_off
            label_y_offset: y_off
            scale: 0.9
            enabled: true
            onClicked: {
                if(func) {
                    print(func)
                    eval(func)
                }
                else
                    keyPress(value)
            }
        }
    }

    states: [
        State {
            name: "uppercase"
            PropertyChanges { target: root ; keys_model: uppercase_keys }
        },
        State {
            name: "lowercase"
            PropertyChanges { target: root ; keys_model: lowercase_keys }
        },
        State {
            name: "numbers"
            PropertyChanges { target: root ; keys_model: number_keys }
        },
        State {
            name: "symbols"
            PropertyChanges { target: root ; keys_model: symbol_keys }
        }
    ]

    // model of keypad keys
    ListModel {
        id: uppercase_keys

        ListElement { value: "Q" ;buttonimage: "keyboard_single" ; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "W" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "E" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "R" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "T" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "Y" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "U" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "I" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "O" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "P" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}

        ListElement { value: "A" ;buttonimage: "keyboard_single" ; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "S" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "D" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "F" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "G" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "H" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "J" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "K" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "L" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "," ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}

        ListElement { value: "" ;buttonimage: "keyboard_single" ; image: "keyboard_SHIFT.png" ; size: 45; x_off: 0; y_off: 0 ; func: "root.state='lowercase'"}
        ListElement { value: "Z" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "X" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "C" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "V" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "B" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "N" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "M" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "@" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        // this is the backspace key.  The '<<' value indicates to the entry function to delete previous character
        ListElement { value: "<<" ; image: "keyboard_BACKSPACE.png"; buttonimage: "keyboard_single"; size: 0; x_off: 0; y_off: 0}
        ListElement { value: "?123" ;buttonimage: "keyboard_double"; size: 45; x_off: 0; y_off: 0 ; func: "root.state='numbers'"}
        ListElement { value: "SPACE" ;buttonimage: "keyboard_triple"; size: 45; x_off: 0; y_off: 0 ; func: "keyPress(' ')"}
        ListElement { value: "." ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "/" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ".com" ;buttonimage: "keyboard_single"; size: 16; x_off: 0; y_off: 0}
        ListElement { value: "ENTER" ; image: "keypad_returnicon.png" ;buttonimage: "keyboard_double"; size: 14; x_off: 0; y_off: -10}
    }

    ListModel {
        id: lowercase_keys

        ListElement { value: "q" ;buttonimage: "keyboard_single" ; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "w" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "e" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "r" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "t" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "y" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "u" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "i" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "o" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "p" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}

        ListElement { value: "a" ;buttonimage: "keyboard_single" ; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "s" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "d" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "f" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "g" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "h" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "j" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "k" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "l" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ";" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}

        ListElement { value: "" ;buttonimage: "keyboard_single" ; image: "keyboard_SHIFT.png" ; size: 45; x_off: 0; y_off: 0 ; func: "root.state='uppercase'"}
        ListElement { value: "z" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "x" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "c" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "v" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "b" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "n" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "m" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "?" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        // this is the backspace key.  The '<<' value indicates to the entry function to delete previous character
        ListElement { value: "<<" ; image: "keyboard_BACKSPACE.png"; buttonimage: "keyboard_single"; size: 0; x_off: 0; y_off: 0}

        ListElement { value: "?123" ;buttonimage: "keyboard_double"; size: 45; x_off: 0; y_off: 0 ; func: "root.state='numbers'"}
        ListElement { value: "SPACE" ;buttonimage: "keyboard_triple"; size: 45; x_off: 0; y_off: 0 ; func: "keyPress(' ')"}
        ListElement { value: "." ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "/" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ".com" ;buttonimage: "keyboard_single"; size: 16; x_off: 0; y_off: 0}
        ListElement { value: "ENTER" ; image: "keypad_returnicon.png" ;buttonimage: "keyboard_double"; size: 14; x_off: 0; y_off: -10}
    }

    ListModel {
        id: number_keys

        ListElement { value: "1" ;buttonimage: "keyboard_single" ; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "2" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "3" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "4" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "5" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "6" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "7" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "8" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "9" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "0" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}

        ListElement { value: "-" ;buttonimage: "keyboard_single" ; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "/" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ":" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ";" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "(" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ")" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "$" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "&" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "@" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: '"' ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}

        ListElement { value: "#+=" ;buttonimage: "keyboard_single" ; size: 30; x_off: 0; y_off: 0 ; func: "root.state='symbols'"}
        ListElement { value: "." ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "," ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "?" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "!" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "#" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "*" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "=" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "@" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        // this is the backspace key.  The '<<' value indicates to the entry function to delete previous character
        ListElement { value: "<<" ; image: "keyboard_BACKSPACE.png"; buttonimage: "keyboard_single"; size: 0; x_off: 0; y_off: 0}

        ListElement { value: "ABC" ;buttonimage: "keyboard_double"; size: 45; x_off: 0; y_off: 0 ; func: "root.state='lowercase'"}
        ListElement { value: "SPACE" ;buttonimage: "keyboard_triple"; size: 45; x_off: 0; y_off: 0 ; func: "keyPress(' ')"}
        ListElement { value: "." ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "/" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ".com" ;buttonimage: "keyboard_single"; size: 16; x_off: 0; y_off: 0}
        ListElement { value: "ENTER" ; image: "keypad_returnicon.png" ;buttonimage: "keyboard_double"; size: 14; x_off: 0; y_off: -10}
    }

    ListModel {
        id: symbol_keys

        ListElement { value: "[]" ;buttonimage: "keyboard_single" ; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "]" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "{" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "}" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "#" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "%" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "^" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "*" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "+" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "=" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}

        ListElement { value: "_" ;buttonimage: "keyboard_single" ; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "\\" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "|" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "~" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "<" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ">" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "$" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "&" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "@" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: '"' ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}

        ListElement { value: "123" ;buttonimage: "keyboard_single" ; size: 30; x_off: 0; y_off: 0 ; func: "root.state='numbers'"}
        ListElement { value: "." ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "," ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "?" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "!" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "#" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "*" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "=" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "@" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        // this is the backspace key.  The '<<' value indicates to the entry function to delete previous character
        ListElement { value: "<<" ; image: "keyboard_BACKSPACE.png"; buttonimage: "keyboard_single"; size: 0; x_off: 0; y_off: 0}

        ListElement { value: "ABC" ;buttonimage: "keyboard_double"; size: 45; x_off: 0; y_off: 0 ; func: "root.state='lowercase'"}
        ListElement { value: "SPACE" ;buttonimage: "keyboard_triple"; size: 45; x_off: 0; y_off: 0 ; func: "keyPress(' ')"}
        ListElement { value: "." ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: "/" ;buttonimage: "keyboard_single"; size: 45; x_off: 0; y_off: 0}
        ListElement { value: ".com" ;buttonimage: "keyboard_single"; size: 16; x_off: 0; y_off: 0}
        ListElement { value: "ENTER" ; image: "keypad_returnicon.png" ;buttonimage: "keyboard_double"; size: 14; x_off: 0; y_off: -10}
    }


}
