import QtQuick 2.4
import "../string_format.js" as Format

Item {
    id: scrub_control

    // duration and position in seconds
    property int duration: 120
    property int position: 0

    signal scrub( int new_time )

    height: 55

    Text {
        id: time_position

        text: Format.formatTimeString( scrub_control.position )
        anchors.left: track.left
        anchors.leftMargin: 3
        anchors.top: track.bottom
        anchors.topMargin: 2
    }

    Text {
        id: time_remain

        text: "-" + Format.formatTimeString( scrub_control.duration - scrub_control.position )
        anchors.top: track.bottom
        anchors.topMargin: 2
        anchors.right: track.right
        anchors.rightMargin: 3
    }
    Rectangle {
        id: track
        height: thumb.height
        color: "#00000000"
        property int scrubwidth: width
        clip: true
        radius: height*0.5
        border.color: "#000000"
        anchors.right: parent.right
        anchors.rightMargin: 5
        anchors.left: parent.left
        anchors.leftMargin: 5
        anchors.top: parent.top
        anchors.topMargin: 0

        BorderImage {
            border.right: 10
            border.left: 10
            anchors.left: parent.left
            anchors.leftMargin: 1
            anchors.right: thumb.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            source: "../graphics/205/Gradiant_Scrolling_Song.png"
        }
        MouseArea {
            id: track_mouse
            anchors.fill: parent

            drag.target: thumb
            drag.axis: Drag.XAxis
            drag.minimumX: 0 ; drag.maximumX: track.scrubwidth - thumb.width
            onPressed: { thumb.anchors.left = undefined }
            onReleased: {
                var newpos = scrub_control.duration * ( mouseX / track.scrubwidth ) | 0 // force to integer value with | 0
                if ( newpos < 0 )
                    newpos = 0
                if( newpos > scrub_control.duration)
                    newpos = scrub_control.duration
                scrub_control.scrub(newpos)
                thumb.anchors.left = parent.left
            }
        }

        Image {
            id: thumb
            anchors.left: parent.left
            anchors.leftMargin: (scrub_control.duration > 0) ? thumb.width + (track.width - thumb.width) * (scrub_control.position / scrub_control.duration) - thumb.width : 0
            anchors.verticalCenter: parent.verticalCenter
            source: "../graphics/205/IPOD_Red_Dot.png"
        }
    }
} // end scrub_control
