/* @file MenuModel.qml
  @brief Component to represent a hierarchical menu structure as a list model.
  */

import QtQuick 2.4

ListModel {
    id: root
    property variant menu_current

    function updateStrings() {
        changeMenu(menu_current)
    }
    signal optionSelected(variant item)
    signal menuSelected(variant item)
    signal changeMenuCallback(variant menudef)

    // call to navigate menu item from current options
    function selectIndex(index){
        var item = get(index)
        selectItem(item)
    }

    function removeNullItems(list) {
        // Remove null items
        var newArray = []
        var i
        for (i = 0; i <list.length; i++) {
            if (list[i] !== null) {
                newArray.push(list[i])
            }
        }
        return newArray
    }

    // call to navigate to new set of options
    function selectItem(item) {
        var menudef = item.menudef // get the javascript dict describing the menu
        // if there's no "menudef" role, then what was passed was a javascript dictionary from workoutmenus.js, just use it.
        if( !item.menudef )
            menudef = item
        // if there's a sub-menu defined, navigate to it
        if(menudef.children) {
            menuSelected(menudef)   // emit change signal before making the change
            changeMenu(menudef)
        }
        else {
            // if there's no submenu, it's a leaf menu item. Emit a signal.
            if(menudef.program || menudef.qmlSource || menudef.action)
                optionSelected( menudef );
        }

    }

    function changeMenu( menudef ) {
        if( !menudef || !menudef.children ) {
            return;
        }

        // Remove the null entries
        menudef.children = removeNullItems(menudef.children)

        var target_num = menudef.children.length
        var delnum
        if( menu_current )
            delnum = menu_current.children.length - target_num
        else
            delnum = -target_num

        if(delnum < 0) {
            for (var i=0 ; i < -delnum ; i++) {
                append( { label: "undefined" })
            }
            delnum = 0
            i = 0
        }
        var menuitem

        for( i=0; i < delnum ; i++) {
            remove(count-1)
        }


        var removeIndex = -1
        // change rest
        for ( i=0; i < menudef.children.length ; ++i ) {
            menuitem = menudef.children[i]

            var olditem = get(i)
            var newitem = {   "label" :application.translateText("Menu",menuitem.label),
                       "menudef": menuitem,
                       "workout": menuitem.workoutid,
                       "desc" : application.translateText("Menu", menuitem.desc),
                       "icon" : menuitem.icon,
                       "program" : menuitem.program,
                       "image" : menuitem.image,
                       "modestyImage": menuitem.modestyImage,
                       "action": menuitem.action,
                       "qmlSource": menuitem.qmlSource,
                       "shim": menuitem.shim ? true : false,
                       "hasControls": menuitem.hasControls ? true : false
                   }
            set(i, newitem)
        }

        // allow objects to make changes to the menudef
        changeMenuCallback(menudef)
        menu_current = menudef
    }

    function findItemIndex(f) {
        for (var i = 0; i < count; i++) {
            if (f(get(i)))
                return i
        }
        return -1 // not found
    }

    function indexIsMenu(index) {
        var item = get(index)
        return (item.menudef !== undefined && item.menudef.children !== undefined && item.menudef.children.length > 0)
    }
}
