import QtQuick 2.4
import Qt.labs.settings 1.0

Item {
    id: root

    // Alias into settings object values for convenience
    property alias defaultLanguage: settingsObj.defaultLanguage
    property alias metricUnits: settingsObj.metricUnits
    property alias cooldownTime: settingsObj.cooldownTime
    property alias workoutTimeMax: settingsObj.workoutTimeMax
    property alias saveWorkoutEnabled: settingsObj.saveWorkoutEnabled
    property alias workoutSetupTimeout: settingsObj.workoutSetupTimeout
    property alias workoutMenuTimeout: settingsObj.workoutMenuTimeout
    property alias workoutSummaryTimeout: settingsObj.workoutSummaryTimeout
    property alias screenSaveTimeout: settingsObj.screenSaveTimeout
    property alias dimDisplayTimeout: settingsObj.dimDisplayTimeout
    property alias sleepModeTimeout: settingsObj.sleepModeTimeout
    property alias contactHRPriority: settingsObj.contactHRPriority
    property alias simulationMode: settingsObj.simulationMode
    property alias showStimulusArea: settingsObj.showStimulusArea
    property alias netpulseEnabled: settingsObj.netpulseEnabled
    property alias browserEnabled: settingsObj.browserEnabled
    property alias disableNoPedalStop: settingsObj.disableNoPedalStop
    property alias systemVolume: settingsObj.systemVolume
    property alias lcdBrightness: settingsObj.lcdBrightness
    property alias showCursor: settingsObj.showCursor
    property alias ignoreFaults: settingsObj.ignoreFaults
    property alias resumeWorkoutTimeout: settingsObj.resumeWorkoutTimeout
    property alias disableBuzzer: settingsObj.disableBuzzer
    property alias ppdEnabled: settingsObj.ppdEnabled
    property alias personPresentTimeout: settingsObj.personPresentTimeout
    property alias noUserDetectedDialogTimeout: settingsObj.noUserDetectedDialogTimeout
    property alias tvNoFrameDrop: settingsObj.tvNoFrameDrop
    property alias tvHwAccel: settingsObj.tvHwAccel
    property alias loggingEnabled: settingsObj.loggingEnabled
    property alias brainboardDebugLogLevel: settingsObj.brainboardDebugLogLevel
    property alias messageCenterBrightness: settingsObj.messageCenterBrightness
    property alias messageCenterContrast: settingsObj.messageCenterContrast
    property alias iptvEnabled: settingsObj.iptvEnabled
    property alias erpEnabled: settingsObj.erpEnabled
    property alias erpTimeout: settingsObj.erpTimeout
    property alias homeURL: settingsObj.homeURL
    property alias browserCountryCode: settingsObj.browserCountryCode
    property alias cabEnabled: settingsObj.cabEnabled
    property alias cabSetting: settingsObj.cabSetting
    property alias fanOption: settingsObj.fanOption
    property alias modestyMode: settingsObj.modestyMode

    Item {
        id: defaults
        property string defaultLanguageDefault: "en"
        property bool metricUnitsDefault: false
        property int cooldownTimeDefault: 120 // 2 minutes
        property int workoutTimeMaxDefault: 60 // 60 minutes
        property bool saveWorkoutEnabledDefault: false
        property int workoutSetupTimeoutDefault: 45
        property int workoutMenuTimeoutDefault: 45
        property int workoutSummaryTimeoutDefault: 30
        property int screenSaveTimeoutDefault: 600 // 10 minutes
        property int sleepModeTimeoutDefault: 0 // 0 minutes
        property int dimDisplayTimeoutDefault: 600 // 10 minutes
        property bool contactHRPriorityDefault: true
        property bool simulationModeDefault: false
        property bool showStimulusAreaDefault: false
        property bool netpulseEnabledDefault: false
        property bool browserEnabledDefault: false
        property bool disableNoPedalStopDefault: false
        property bool showCursorDefault: false
        property int systemVolumeDefault: 60
        property int lcdBrightnessDefault: 80
        property bool ignoreFaultsDefault: false
        property int resumeWorkoutTimeoutDefault:30 // 30 seconds
        property bool erpEnabledDefault: false
        property int erpTimeoutDefault: 1800 // 30 minutes
        property bool disableBuzzerDefault: false
        property string homeURLDefault: "http://www.google.com"
        property string browserCountryCodeDefault: "us"
        property bool cabEnabledDefault: false
        property string cabSettingDefault: "STB_00"
        property string fanOptionDefault: "2-Wire"
        property int messageCenterBrightnessDefault: 100
        property int messageCenterContrastDefault: 98
        property bool ppdEnabledDefault: true
        property int ppdTimer1Default: 60 //ppd timer 1 60 seconds
        property int ppdTimer2Default: 20 // ppd timer 2 20 seconds
        property int resumeWorkoutTimeoutDefault_ES900:0
        property int sleepModeTimeoutDefault_ES900: 1800 // 30 minutes
        property bool saveWorkoutEnabledDefault_ES900: true
        property int screenSaveTimeoutDefault_ES900: 600 // 10 minutes
        property int cooldownTimeDefault_ES900: 120 // 2 minutes
        property int workoutTimeMaxDefault_ES900: 99 // 99 minutes
        property bool tvNoFrameDropDefault: false
        property bool tvHwAccelDefault: false
        property bool loggingEnabledDefault: false
        property int brainboardDebugLogLevelDefault: 0
        property bool iptvEnabledDefault: false
        property bool modestyModeDefault: false
    }

    Settings {
        id: settingsObj

        property string defaultLanguage: defaults.defaultLanguageDefault
        property bool metricUnits: defaults.metricUnitsDefault
        property int cooldownTime: defaults.cooldownTimeDefault
        property int workoutTimeMax: defaults.workoutTimeMaxDefault
        property bool saveWorkoutEnabled: defaults.saveWorkoutEnabledDefault
        property int workoutSetupTimeout: defaults.workoutSetupTimeoutDefault
        property int workoutMenuTimeout: defaults.workoutMenuTimeoutDefault
        property int workoutSummaryTimeout: defaults.workoutSummaryTimeoutDefault
        property int screenSaveTimeout: defaults.screenSaveTimeoutDefault
        property int dimDisplayTimeout: defaults.dimDisplayTimeoutDefault
        property int sleepModeTimeout: defaults.sleepModeTimeoutDefault
        property bool contactHRPriority: defaults.contactHRPriorityDefault
        property bool simulationMode: defaults.simulationModeDefault
        property bool showStimulusArea: defaults.showStimulusAreaDefault
        property bool netpulseEnabled: defaults.netpulseEnabledDefault
        property bool browserEnabled: defaults.browserEnabledDefault
        property bool disableNoPedalStop: defaults.disableNoPedalStopDefault
        property int systemVolume: defaults.systemVolumeDefault
        property int lcdBrightness: defaults.lcdBrightnessDefault
        property bool showCursor: defaults.showCursorDefault
        property bool ignoreFaults: defaults.ignoreFaultsDefault
        property int resumeWorkoutTimeout: defaults.resumeWorkoutTimeoutDefault
        property bool disableBuzzer: defaults.disableBuzzerDefault
        property bool ppdEnabled: defaults.ppdEnabledDefault
        property int personPresentTimeout: defaults.ppdTimer1Default
        property int noUserDetectedDialogTimeout: defaults.ppdTimer2Default
        property bool tvNoFrameDrop: defaults.tvNoFrameDropDefault
        property bool tvHwAccel: defaults.tvHwAccelDefault
        property bool loggingEnabled: defaults.loggingEnabledDefault
        property int brainboardDebugLogLevel: defaults.brainboardDebugLogLevelDefault
        property int messageCenterBrightness: defaults.messageCenterBrightnessDefault
        property int messageCenterContrast: defaults.messageCenterContrastDefault
        property bool iptvEnabled: defaults.iptvEnabledDefault
        property bool erpEnabled: defaults.erpEnabledDefault
        property int erpTimeout: defaults.erpTimeoutDefault
        property string homeURL: defaults.homeURLDefault
        property string browserCountryCode: defaults.browserCountryCodeDefault
        property bool cabEnabled: defaults.cabEnabledDefault
        property string cabSetting: defaults.cabSettingDefault
        property string fanOption: defaults.fanOptionDefault
        property bool modestyMode: defaults.modestyModeDefault
    }

    function resetToDefaults() {
        defaultLanguage = defaults.defaultLanguageDefault
        metricUnits = defaults.metricUnitsDefault
        workoutSetupTimeout = defaults.workoutSetupTimeoutDefault
        workoutMenuTimeout = defaults.workoutMenuTimeoutDefault
        workoutSummaryTimeout = defaults.workoutSummaryTimeoutDefault
        contactHRPriority = defaults.contactHRPriorityDefault
        simulationMode = defaults.simulationModeDefault
        showStimulusArea = defaults.showStimulusAreaDefault
        netpulseEnabled = defaults.netpulseEnabledDefault
        browserEnabled = defaults.browserEnabledDefault
        disableNoPedalStop = defaults.disableNoPedalStopDefault
        systemVolume = defaults.systemVolumeDefault
        showCursor = defaults.showCursorDefault
        lcdBrightness = defaults.lcdBrightnessDefault
        ignoreFaults = defaults.ignoreFaultsDefault
        personPresentTimeout = defaults.ppdTimer1Default
        noUserDetectedDialogTimeout = defaults.ppdTimer2Default
        ppdEnabled = defaults.ppdEnabledDefault
        tvNoFrameDrop = defaults.tvNoFrameDropDefault
        tvHwAccel = defaults.tvHwAccelDefault
        if(tv.tunerType == "ATSC")
            erpEnabled = false
        else
            erpEnabled = true
        iptvEnabled = defaults.iptvEnabledDefault
        erpTimeout = defaults.erpTimeoutDefault
        disableBuzzer = defaults.disableBuzzerDefault
        homeURL = defaults.homeURLDefault
        browserCountryCode = defaults.browserCountryCodeDefault
        loggingEnabled = defaults.loggingEnabledDefault
        brainboardDebugLogLevel = defaults.brainboardDebugLogLevelDefault
        cabEnabled = defaults.cabEnabledDefault
        cabSetting = defaults.cabSettingDefault
        fanOption = defaults.fanOptionDefault
        messageCenterBrightness = defaults.messageCenterBrightnessDefault
        messageCenterContrast = defaults.messageCenterContrastDefault
    }

    function setProductDependentDefaults(modelstring){
        // Forcefully set defaults when a product is selected...
        if(modelstring === "TES900"){
            resumeWorkoutTimeout = defaults.resumeWorkoutTimeoutDefault_ES900
            sleepModeTimeout = defaults.sleepModeTimeoutDefault_ES900
            saveWorkoutEnabled = defaults.saveWorkoutEnabledDefault_ES900
            screenSaveTimeout = defaults.screenSaveTimeoutDefault_ES900
            dimDisplayTimeout = defaults.dimDisplayTimeoutDefault
            cooldownTime = defaults.cooldownTimeDefault_ES900
            workoutTimeMax = defaults.workoutTimeMaxDefault_ES900
        } else {
            resumeWorkoutTimeout = defaults.resumeWorkoutTimeoutDefault
            sleepModeTimeout = defaults.sleepModeTimeoutDefault
            saveWorkoutEnabled = defaults.saveWorkoutEnabledDefault
            screenSaveTimeout = defaults.screenSaveTimeoutDefault
            dimDisplayTimeout = defaults.dimDisplayTimeoutDefault
            cooldownTime = defaults.cooldownTimeDefault
            workoutTimeMax = defaults.workoutTimeMaxDefault
        }
    }

    Component.onCompleted: {
        brainboard.setContactPriority(contactHRPriority)
//        amixer.setVolume(systemVolume)
    }

}

