import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property int rpm: 0
    property int paceTarget: 0
    property int paceLevel: 0
    property bool showPaceSetter: false
    property bool bikeModeEnabled: false

    signal levelUp()
    signal levelDown()

    width: 344
    height: 225
    state: showPaceSetter ? "PACESETTER" : "NOPACESETTER"

    function getIcon()
    {
        if(root.bikeModeEnabled)
            return "graphics/224/PACE-CADENCE_icon_bikemode.png"
        else
            return "graphics/netpulse/PACE-SPEED_icon_GRAY.png"
    }

    Image {
        id: paceSetterShape

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        source: "graphics/224/Pace_Setter_Shape.png"
    }

    Image{
        id:paceIcon

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset:-80
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -65
        source: root.getIcon()
    }

    Text {
        id: rpmValue

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: main.isTft && !showPaceSetter ? 40 : 0
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: main.isTft && !showPaceSetter ? -22 : -35
        color: "black"
        font.pointSize: 32
        font.bold: true
        text: root.rpm
    }

    Text {
        id: rpmLabelValue

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: main.isTft && !showPaceSetter ? 40 : 0
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: (main.isTft && !showPaceSetter ? 18 : 0 ) + ( text.length > 3 ? 0 : -5)
        color: "black"
        font.pointSize: text.length > 3 ? 9 : 12
        horizontalAlignment: Text.AlignHCenter
        width: 150
        wrapMode: Text.WordWrap
        font.bold: true
        text: qsTr("RPM") + application.emptyString
    }

    Text {
        id: paceSetterLabel

        anchors.top: parent.top
        anchors.topMargin: 25
        anchors.left: parent.left
        anchors.leftMargin: 30
        color: "black"
        font.pointSize: 12
        font.bold: true
        text: qsTr("PACE SETTER") + application.emptyString
    }

    ImageButton {
        id: paceSetterLevelUpButton
        visible: main.isTouch

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 95
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -59
        downimage: "graphics/Arrow_Up_Button_Pressed.png"
        upimage: "graphics/Arrow_Up_Button.png"
        icon: "graphics/224/Plus_Sign.png"
        onClicked: root.levelUp()
    }

    ImageButton {
        id: paceSetterLevelDownButton
        visible: main.isTouch

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 95
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: 11
        downimage: "graphics/Arrow_Down_Button_Pressed.png"
        upimage: "graphics/Arrow_Down_Button.png"
        icon: "graphics/224/Minus_Sign.png"
        onClicked: root.levelDown()
    }

    Text {
        id: paceSetterLevelLabel
        visible: main.isTouch

        anchors.horizontalCenter: paceSetterLevelUpButton.horizontalCenter
        anchors.top: paceSetterLevelDownButton.bottom
        anchors.topMargin: -8
        color: "black"
        font.pointSize: 10
        font.bold: true
        text: qsTr("LEVEL") + application.emptyString
    }

    Text {
        id: paceSetterLevel
        visible: main.isTouch

        anchors.horizontalCenter: paceSetterLevelUpButton.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -27
        color: "black"
        font.pointSize: 18
        font.bold: true
        text: root.paceLevel
    }

    PaceSetterMeter{
        id: paceSetterMeter

        rpm: root.rpm
        paceTarget: root.paceTarget
        anchors.horizontalCenter: rpmValue.horizontalCenter
        anchors.horizontalCenterOffset: 0
        anchors.bottom: paceSetterShape.bottom
        anchors.bottomMargin: 57
    }

    states: [
        State {
            name: "PACESETTER"
            PropertyChanges {target: paceSetterShape; visible: true}
            PropertyChanges {target: paceSetterLabel; visible: true}
            PropertyChanges {target: paceSetterLevelLabel; visible: main.isTouch}
            PropertyChanges {target: paceSetterLevel; visible: main.isTouch}
            PropertyChanges {target: paceSetterLevelUpButton; visible: main.isTouch}
            PropertyChanges {target: paceSetterLevelDownButton; visible: main.isTouch}
            PropertyChanges {target: paceSetterMeter; visible: true}
            PropertyChanges {target: paceIcon; visible: false}
        },
        State {
            name: "NOPACESETTER"
            PropertyChanges {target: paceSetterShape; visible: false}
            PropertyChanges {target: paceSetterLabel; visible: false}
            PropertyChanges {target: paceSetterLevelLabel; visible: false}
            PropertyChanges {target: paceSetterLevel; visible: false}
            PropertyChanges {target: paceSetterLevelUpButton; visible: false}
            PropertyChanges {target: paceSetterLevelDownButton; visible: false}
            PropertyChanges {target: paceSetterMeter; visible: false}
            PropertyChanges {target: paceIcon; visible: true}
        }
    ]
} // end paceSetter
