
import QtQuick 2.4

ListView {
  id: pagedListView
  //component for a pages ListView.
  //It will handle paging in either direction based on its orientation

  cacheBuffer: orientation == ListView.Horizontal ? width * 1.5 : height * 1.5

  clip: true

  interactive: false

  //preferredHighlightBegin: 0
  //preferredHighlightEnd: orientation == ListView.Horizontal ? width : height
  boundsBehavior: Flickable.StopAtBounds
  snapMode: ListView.SnapToItem

  property int visibleItems: 3
  property int totalPages: Math.ceil(count / visibleItems)
  property int currentPage: 1 + Math.floor(currentIndex / visibleItems)

  property int visibleItemsOffset: 0

  property int minContentX: 0
  property int minContentY: 0
  property int maxContentX: totalPages > 1 ? width * (totalPages - 1) : 0
  property int maxContentY: totalPages > 1 ? height * (totalPages - 1) : 0

  property bool is_animation_x_running: pagedListView.xAnimation.running
  property bool is_animation_y_running: pagedListView.yAnimation.running

  property bool x_animation_enabled: true;
  property bool y_animation_enabled: true;

  property NumberAnimation xAnimation: NumberAnimation {
    //default animation, will use Linear easing
    duration: (x_animation_enabled) ? 800 : 0;
  }

  property NumberAnimation yAnimation: NumberAnimation {
    //default animation, will use Linear easing
    duration: (y_animation_enabled) ? 800 : 0;
  }


  Behavior on contentX {
    id: contentXBehavior
    animation: pagedListView.xAnimation
  }

  Behavior on contentY {
    id: contentYBehavior
    animation: pagedListView.yAnimation
  }

  function scrollToCurrentPage() {
      var newContentX = (currentPage - 1) * width;
      if (contentX !== newContentX) { // only scroll if necessary
          contentX = newContentX
      }
  }

  function moveRight() {
    // do not move if animation already in progress
    if (is_animation_x_running) {
        return;
    }

    incrementCurrentIndex();
    //only actually move right if we're not now on the last index and we just moved the current index off-screen
    if ((currentIndex % visibleItems) === 0 && (currentPage <= totalPages))
    {
      if (contentX + width <= maxContentX)
      {
        contentX += width;
      }
      else {
        contentX = maxContentX;
      }
    }
  }

  function moveLeft() {
    // do not move if animation already in progress
    if (is_animation_x_running) {
        return;
    }

    decrementCurrentIndex();
    //only actually move left if we're not now on the last index and we just moved the current index off-screen
    if ((currentIndex % visibleItems) === (visibleItems - 1) && ( (currentPage >= 1) && currentIndex != count - 1  ) )
    {
      if (contentX - width >= minContentX) {
        contentX -= width;
      }
      else {
        contentX = minContentX;
      }

    }


  }

  function moveDown() {
    // do not move if animation already in progress
    if (is_animation_y_running) {
        return;
    }

    incrementCurrentIndex();
    //only actually move right if we're not now on the last index and we just moved the current index off-screen
    if ((currentIndex % visibleItems) === 0 && (currentPage <= totalPages)) {
      if (contentY + height <= maxContentY) {
        contentY += height;
      }
      else {
        contentY = maxContentY;
      }
    }
  }

  function moveUp() {
    // do not move if animation already in progress
    if (is_animation_y_running) {
        return;
    }

    decrementCurrentIndex();
    //only actually move up if we're not now on the last index and we just moved the current index off-screen

    if ((currentIndex % visibleItems) === (visibleItems - 1) && (currentPage >= 1 && currentIndex != count - 1)) {
      if (contentY - height >= minContentY) {
        contentY -= height;
      }
      else {
        contentY = minContentY;
      }
    }
  }

  //These functions may seem a little "backwards" but if you think about how touchscreen navigation has now evolved to work
  //on smartphones/tablets then it makes sense...
  function pageRight() {
    // do not move if animation already in progress
    if (is_animation_x_running) {
        return;
    }

    //we touched the right arrow
    if (currentPage > 1) {
      if (contentX - width >= minContentX) {
        contentX -= width;
      }
      else {
        contentX = minContentX;
      }
    }
  }

  function pageLeft() {
    // do not move if animation already in progress
    if (is_animation_x_running) {
        return;
    }

    //we touched the left arrow
    if (currentPage < totalPages) {
      if (contentX + width <= maxContentX) {
        contentX += width;
      }
      else {
        contentX = maxContentX;
      }
    }
  }

  function pageDown() {
    // do not move if animation already in progress
    if (is_animation_y_running) {
        return;
    }

    //we touched the right arrow
    if (currentPage > 1) {
      if (contentY - height >= minContentY) {
        contentY -= height;
      }
      else {
        contentY = minContentY;
      }
    }
  }

  function pageUp() {
    // do not move if animation already in progress
    if (is_animation_y_running) {
        return;
    }
    //we touched the left arrow
    if (currentPage < totalPages) {
      if (contentY + height <= maxContentY) {
        contentY += height;
      }
      else {
        contentY = maxContentY;
      }
    }
  }

  Component.onCompleted: {
    currentIndex = 0;
  }

}
