import QtQuick 2.4
import ErrorManager 1.0
import Components 1.0

Item {
    id: root
    width: parent.width
    height: parent.height

    property alias messagesCount: messages.count
    property alias currentMessage: errorPopup.message
    property bool safetyKeyOut: false
    property bool treadStopped: true
    property bool estopSpindown: false
    property bool estopShown: estopPopup.visible
    property bool hidePopup: false

    signal estopPopupPopped()
    signal estopPopupHide()
    signal estopPopupTimedout()

    function showEstop()
    {
        estopPopup.show()
        estopPopupPopped()
    }

    function hideEstop()
    {
        estopPopup.hide()
        estopPopupHide()
    }

    function reset()
    {
        messages.clear()
        errorPopup.hide()
    }

    onSafetyKeyOutChanged: {
        if(safetyKeyOut)
            showEstop()
        else {
            // wait until treadmill spins to zero to remove estop dialog
            estopTimer.start()
        }
    }

    Timer{
        id: estopTimer
        interval: 1000
        repeat: true
        running: false

        triggeredOnStart: true
        onTriggered: {
            if(treadStopped) {
                root.estopSpindown = false
                if(!safetyKeyOut){
                    hideEstop()
                    stop()
                }
            }
            else
                root.estopSpindown = true
        }
    }

    function setErrorMessage(errorcode,message,severity)
    {
        //exception for estop conditions
        if(errorcode === "CN09" || errorcode === "D105"){
            ;
        }
        else
        {
            var emessage = "Fault "+errorcode+": "+ message;
            if(severity >= ErrorManager.ERROR_PREVENTS_USE) {
                messages.clear()
                messages.append({"message": emessage})
                errorPopup.dismissable = false
                displayPopupMessage(0)
            }
            else if(errorPopup.dismissable) { // once a non-dismissable pop-up occurs, display no more pop-ups
                messages.append({"message": emessage})
                if(messages.count == 1)
                    displayPopupMessage(5)
            }
        }
    }

    function setInfoMessage(message){
        messages.append({"message": message})
        if(messages.count == 1)
            displayPopupMessage(5)
    }

    function removePopupMessage()
    {
        messages.remove(0)
        if(messages.count){
            displayPopupMessage()
        }
    }

    function displayPopupMessage(timeout)
    {
        errorPopup.message = messages.get(0).message
        if(timeout > 0)
            errorPopup.showWithTimeout(timeout)
        else
            errorPopup.show()
    }

    MessagePopup{
        id: errorPopup

        enabled: visible && opacity > 0
        opacity: root.hidePopup ? 0.0 : 1.0
        blockKeys: !root.hidePopup
        messageColor: "white"
        dismissable: true
        onTimedOut: removePopupMessage()
        onDismissed: removePopupMessage()
        isTransparent: true
    }

    MessagePopup{
        id: infoPopup

        opacity: root.hidePopup ? 0.0 : 1.0
        messageColor: "white"
        dismissable: true
        onTimedOut: removePopupMessage()
        onDismissed: removePopupMessage()
        isTransparent: true
    }

    MessagePopup{
        id: estopPopup

        opacity: root.hidePopup ? 0.0 : 1.0
        messageColor: "red"
        message: (root.estopSpindown ? qsTr("BELT STOPPING") : qsTr("INSERT SAFETY KEY")) + application.emptyString
        dismissable: false
        isTransparent: true
    }

    ListModel{
        id:messages
    }
}
