// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property variant model
    property int xPositionOffset: 0
    property int yPosition: 50
    property bool editable: false
    property bool levelIndicatorVisibility: false
    property bool profileVisible: false
    property int columnWidth: 40 // Must not be below 10
    property int segmentFill: 0 // 0 - 100%
    property alias activeSegment: segmentView.currentIndex
    property bool isWorkoutView: false
    property bool active: false
    property int editSegment
    property string segmentColorHistory: "#F38C21" // orange
    property string segmentColorFuture: "#5D87A1" // Blue
    property string segmentColorInactive: "#DCDCDC" // Light Grey Fill  - inactive bars
    property string segmentColorEditor: "#5E9732"; // Dark Green  - editor bars
    property string segmentColorEditorCurrent: "#D6DF22" // Yellow - editor bar current segment
    property string segmentColorEditorNegative: "#FFCB05" // Yellow - editor bar negative value
    property string segmentColorCurrentFill: "#BED63A" // Light Green
    property string segmentColorNegative: "yellow"
    property bool showLevel: editable  // display level instead of magnitude values
    property int currentSegmentX: segmentView.currentItem ? segmentView.x + segmentView.currentItem.x - segmentView.contentX : 0
    property bool enableHeightAnimation: true
    property bool hasNegativeValues: false
    property bool labelVisibility: false
    property int baseOffset: 0
    property int heightDifferential: 0 // "fudge factor" to add to the bar height
    property int numNegativeValues: 0
    property bool useAlternativeHeight: false
    property real alternativeHeight

    clip: true
    onActiveSegmentChanged: editSegment = activeSegment

    ListView {
        id: segmentView
        Component.onCompleted: contentX = 0
        width: root.width
        height: root.height
        anchors.left: parent.left ; anchors.leftMargin: root.xPositionOffset
        anchors.bottom: parent.bottom
        orientation: ListView.Horizontal
        model: root.model
        delegate: viewDelegate
        interactive: false
        clip: false
        highlightRangeMode: ListView.ApplyRange
        highlightFollowsCurrentItem: true
        currentIndex: activeSegment
        preferredHighlightBegin: (width/2) - 60
        preferredHighlightEnd: (width/2) + 60
    }

    Component { id: viewDelegate

        Item { id: standardSegment
            // set height of bar to draw based on the level or magnitude property of the profile segment, as appropriate
            property int maxBarHeight: segmentView.height - segmentBar.border.width - root.yPosition - levelIndicator.height + heightDifferential - baseOffset
            property int barHeight: computeBarHeight()
            function computeBarHeight() {
                if (editable) {
                    if (hasNegativeValues) {
                        if (segmentLevel <= numNegativeValues)
                            return -50
                        else if (useAlternativeHeight && index === activeSegment && active)
                            return alternativeHeight // follow slider while editing active segment
                        else
                            return baseOffset + ((segmentLevel - (numNegativeValues+1)) / (root.model.maxLevel - (numNegativeValues+1))) * maxBarHeight
                    }
                    else if (useAlternativeHeight && index === activeSegment && active) {
                        return alternativeHeight // follow slider while editing active segment
                    }
                    else if (baseOffset > 0) {
                        return baseOffset + ((segmentLevel - 1) / (root.model.maxLevel - 1)) * maxBarHeight
                    } else {
                        return (segmentLevel / root.model.maxLevel)*maxBarHeight
                    }
                } else {
                    return (segmentMagnitude *maxBarHeight) / root.model.magnitudeRangeMax
                }

            }
            width: (root.columnWidth * 2)
            height: root.height
            visible: profileVisible

            MouseArea {
                anchors.fill: parent
                anchors.topMargin: 10
                onClicked: {
                    editSegment = index;
                    //currentIndex = index;
                }
                enabled: index !== activeSegment // disable to not block slider for current item
            }

            Rectangle {
                id: negativeAnchor

                anchors.bottom: parent.bottom
                anchors.bottomMargin: root.yPosition + levelIndicator.height
                width: 50
                height: {
                    if (editable) {
                        if (useAlternativeHeight && index === activeSegment && active)
                            return alternativeHeight
                        else
                            return segmentLevel > numNegativeValues ? 0 : (50 - (50.0/numNegativeValues)*(numNegativeValues + 1 - segmentLevel))
                    } else {
                        return 0
                    }
                }
                visible: false
            }

            Rectangle { id: segmentBar

                property int border_size: 2

                function getbordercolor()
                {
                    if (isWorkoutView) {
                        if (active) {
                            return "black";
                        }
                        else {
                            return "#7D7D7D"; // Dark Grey Border
                        }
                    }
                    else { // editor bar border color
                        return "black";
                    }
                }

                anchors.left: levelIndicator.left
                width: root.columnWidth
                height: {
                    if( standardSegment.barHeight > 0) {
                        anchors.bottom = levelIndicator.top
                        anchors.top = undefined
                        return standardSegment.barHeight
                    }
                    else if( standardSegment.barHeight < 0 ) {
                        anchors.top = negativeAnchor.top
                        anchors.bottom = undefined
                        return -standardSegment.barHeight
                    }
                    else {
                        anchors.bottom = levelIndicator.top
                        anchors.top = undefined
                        return 2 // very short bar for zero
                    }
                }
                color: {
                    if (isWorkoutView) {
                        if (active) {
                            if ( activeSegment > index ) {
                                return segmentColorHistory
                            }
                            else {
                                return segmentMagnitude >= 0 ? segmentColorFuture : segmentColorNegative
                            }
                        }
                        else {
                            return segmentColorInactive
                        }
                    }
                    else { // editor
                        if (!active) {
                            return segmentColorInactive
                        } else if (activeSegment === index) {
                            return segmentColorEditorCurrent
                        } else if (standardSegment.barHeight < 0) {
                            return segmentColorEditorNegative
                        } else {
                            return segmentColorEditor
                        }
                    }
                }

                Item {
                    id: valueText
                    visible: root.labelVisibility
                    anchors {
                        top: topBorder.top
                        topMargin: 5
                        left: parent.left
                        right: parent.right
                    }

                    Text {
                        id: valueTextValue

                        font { pixelSize: 18; bold: true }
                        horizontalAlignment: Text.AlignHCenter
                        anchors.horizontalCenter: parent.horizontalCenter
                        text: {
                            if (segmentLevel) {

                                var level = parseInt(segmentLevel)
                                if (root.model.segmentType === 3) { // incline segment
                                    return (machineinfo.inclineTable[level - 1]/10.0).toFixed(1)
                                } else if (root.model.segmentType === 4) { // speed segment
                                    var val = (machineinfo.speedTable[level - 1]/10.0)
                                    val = options.metricUnits ? Globals.mileToKm(val) : val
                                    return val.toFixed(1)
                                } else {
                                    return segmentLevel
                                }
                            } else {
                                return "?"
                            }
                        }
                    }

                    Text {
                        id: valueTextLabel

                        anchors.top: valueTextValue.bottom
                        font { pixelSize: 18; bold: true }
                        horizontalAlignment: Text.AlignHCenter
                        anchors.horizontalCenter: parent.horizontalCenter
                        text: {
                            if (segmentLevel) {
                                if (root.model.segmentType === 3) { // incline segment
                                    return "%"
                                } else if (root.model.segmentType === 4) { // speed segment
                                    return options.metricUnits ? "KPH" : "MPH"
                                } else {
                                    return qsTr("LEVEL") + application.emptyString
                                }
                            } else return ""
                        }
                    }
                }

                Rectangle{
                    id: topBorder
                    anchors.bottom: segmentBar.top
                    anchors.horizontalCenter: segmentBar.horizontalCenter
                    width: segmentBar.width + (segmentBar.border_size * 2)
                    height: segmentBar.border_size
                    color: segmentBar.getbordercolor()
                }
                Rectangle{
                    id: bottomBorder
                    anchors.top: segmentBar.bottom
                    anchors.horizontalCenter: segmentBar.horizontalCenter
                    width: segmentBar.width + (segmentBar.border_size * 2)
                    height: segmentBar.border_size
                    color: segmentBar.getbordercolor()
                }
                Rectangle{
                    id: leftBorder
                    anchors.right: segmentBar.left
                    anchors.verticalCenter: segmentBar.verticalCenter
                    height: segmentBar.height + (segmentBar.border_size * 2)
                    width: segmentBar.border_size
                    color: segmentBar.getbordercolor()
                }
                Rectangle{
                    id: rightBorder
                    anchors.left: segmentBar.right
                    anchors.verticalCenter: segmentBar.verticalCenter
                    height: segmentBar.height + (segmentBar.border_size * 2)
                    width: segmentBar.border_size
                    color: segmentBar.getbordercolor()
                }

                Behavior on height {
                    PropertyAnimation{}
                    enabled: root.enableHeightAnimation
                }
            }

            Rectangle { id: currentSegmentFill
                anchors.bottom: segmentBar.bottom
                anchors.bottomMargin: 0
                anchors.left: segmentBar.left
                anchors.leftMargin: 0
                anchors.top: segmentBar.top ; anchors.topMargin: 0
                width: ((root.columnWidth - 0) * (segmentFill / 100))

                color:  segmentColorCurrentFill
                visible: {
                    if (isWorkoutView && active) {
                        if (activeSegment == index) {
                            return true;
                        }
                        else {
                            return false;
                        }
                    }
                    else {
                        return false;
                    }
                }
            }

            Rectangle { id: levelIndicator
                x: 0
                anchors.bottom: parent.bottom ; anchors.bottomMargin: yPosition
                width: root.columnWidth
                height: editable ? 16 : 0
                color: "black"
                border.color: "black"
                border.width: 2
                visible: root.levelIndicatorVisibility

                Text {
                    id: segment1bLevelText
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.verticalCenter: parent.verticalCenter
                    text: (segmentLevel != undefined) ? segmentLevel : "?"
                    color: "white"
                    horizontalAlignment: Text.AlignCenter
                    font.pointSize: 12
                    font.bold: true
                    visible: root.active
                }
            }

            states: [
                State {
                    name: "Editable1"
                    PropertyChanges { target: segmentBar; color: "white" }
                }
            ]

            transitions: [
                Transition {
                    to: "Editable1"
                    reversible: true
                }
            ]
        }
    }
}
