import QtQuick 2.4
import WorkoutManager 1.0
import "string_format.js" as Format
import Components 1.0

FocusScope {
    id: mainProgItem
    width: 1366
    height: 768

    signal startProgram()
    signal showHRChart()
    signal saveCustomProgram(string programName, int saveLocation)
    property int selectedIndex: 0
    property bool valueEntered: false
    property int fieldIndex: 1
    property string programName: ""
    property string programNameTranslated: qsTranslate("Menu", programName) + application.emptyString
    property int programIndex: workoutProgram.programIndex
    property int targetHRType: targetHRTypeEnum.invalid
    property int progSetupStep: 1
    property string profile1Title: ""
    property string profile2Title: ""
    property string profile1Units: ""
    property string profile2Units: ""
    property int workTime: 0
    property int segTime: 0
    property int numSegs: 10
    property int paceLevelForCustom: 1
    property int profile2Max: 1
    property int workloadLevelForCustom: 1
    property int profile1Max: 1
    property int ageForProgSummary: 35
    property int weightForProgSummary: 155
    property bool c360TypeProg: workoutProgram.isC360Program
    property bool isC360Custom: programIndex == WorkoutProgram.CUSTOM_C360_PROG
    property bool isSegmentTypeProg: !c360TypeProg
    property int customProgType: workoutProgram.customProgType
    property variant c360SetupModel: workoutProgram.c360Program.c360ProgramModel
    property variant setupParamList: workoutProgram.normalProgramModel
    property variant savedWorkouts: saveProgLoader.item
    property int startSpeedMinWarning: 40    // warn if starting tread > x mph
    property variant basicSetup: setupParamsLoader.item
    property bool saveHasHappened: false
    property int saveCount: 0
    signal dataItemChanged()

    QtObject{
        id: targetHRTypeEnum
        property int invalid: 0
        property int aerobic: 1
        property int target: 2
    }

    function doStart() {
            var correctionsMade = 0
            if (setupScreenManager.state === "C360Step2") {
                correctionsMade = loaderC360.item.validate()
            } else {
                correctionsMade = basicSetup.validateEntries()
            }
            // check if a setting was corrected by validation.  If so, don't start.
            if(correctionsMade)
                return
            // check if we need a starting speed confirmation for treadmill
            var firstSpeed = workoutProgram.profile2.get(0)
            if(isTreadmill && workoutProgram.profile2.isCustom && (firstSpeed > mainProgItem.startSpeedMinWarning) ) {
                customSpeedWarningConfirmation.prompt = qsTr("BEGINNING SPEED:") + "\n" + speedString(firstSpeed)
                customSpeedWarningConfirmation.show()
                if (options.workoutSetupTimeout > 0)
                    customSpeedWarningConfirmation.startTimeout(options.workoutSetupTimeout)
            } else if (workoutProgram.programIndex === WorkoutProgram.TREAD_GERKIN_TEST_PROG) {
                gerkinTestPrompt.show()
            }
            else {
                mainProgItem.startProgram();
                setupScreenManager.state = "Step1"
            }
    }

    function nextState() {
        if (setupScreenManager.state != "LoadSavedWorkouts")
            basicSetup.validateEntries()

        switch( setupScreenManager.state ) {
        case "LoadSavedWorkouts": {
            if (workoutProgram.profile1.isCustom || workoutProgram.profile2.isCustom)
                setupScreenManager.state = "Step3"
            else if (isC360Custom)
                setupScreenManager.state = "Step1"
            else
                setupScreenManager.state = "Simple"
            break;
        }
        case "Step1": {
            if(isC360Custom)
                setupScreenManager.state = "C360Step2"
            else
                setupScreenManager.state = "Step2"
            break;
        }
        case "Step2": {
            setupScreenManager.state = "Step3"
            break;
        }
        case "Step3": {   // shouldn't happen, next button hidden in step3
            setupScreenManager.state = "Step3"
            print("error, next button in Step3!")
            break;
        }
        }
    }

    function setProgramName (name) {
        mainProgItem.programName = name
//        mainProgItem.programName = application.translateText("Menu", name) //translation?
        console.log("set program name>>>", mainProgItem.programName)
    }

    function clearListView() {
        mainProgItem.selectedIndex = 0;
        mainProgItem.valueEntered = false;
        mainProgItem.fieldIndex = 1;
        mainProgItem.programName = "";
        mainProgItem.targetHRType = targetHRTypeEnum.invalid;
        mainProgItem.progSetupStep = 1;
        mainProgItem.workTime = 0;
        mainProgItem.segTime = 0;
        mainProgItem.numSegs = 1;
        mainProgItem.paceLevelForCustom =  1;
        mainProgItem.workloadLevelForCustom = 1;
        mainProgItem.profile2Max = 1;
        mainProgItem.profile1Max = 1;
        mainProgItem.ageForProgSummary = 35;
        mainProgItem.weightForProgSummary = 155;
        mainProgItem.saveHasHappened = false
        mainProgItem.saveCount = 0
    }

    function startQuickStart (element) {
        mainProgItem.startProgram();
    }

    onSetupParamListChanged: mainProgItem.init()

    function init() {
        var program = programIndex
        if(programIndex == WorkoutProgram.NO_PROG)
            return

        if(machineinfo.productTypeString == "Treadmill" ) {
            mainProgItem.profile1Title = qsTr("INCLINE") + application.emptyString
            mainProgItem.profile1Units = qsTr("%") + application.emptyString
            mainProgItem.profile2Title = qsTr("SPEED") + application.emptyString
            mainProgItem.profile2Units = (options.metricUnits ? "KPH" : "MPH")
        }
        else {
            mainProgItem.profile1Title = qsTr("WORKLOAD") + application.emptyString
            mainProgItem.profile1Units = qsTr("WATTS") + application.emptyString
            mainProgItem.profile2Title = qsTr("PACE") + application.emptyString
            mainProgItem.profile2Units = qsTr("RPM") + application.emptyString
        }
        if( workoutProgram.currentProgram == WorkoutProgram.SAVED_WORKOUT )
            setupScreenManager.state = "LoadSavedWorkouts"
        else if( isC360Custom )
            setupScreenManager.state = "Step1";
        else if( workoutProgram.profile1.isCustom || workoutProgram.profile2.isCustom ) {
            setupProfileEditor()
            setupScreenManager.state = "Step1";
        }
        else {
            setupScreenManager.state = "Simple";
        }
    }

    onWorkTimeChanged: {
        mainProgItem.segTime = workTime*60 / mainProgItem.numSegs
    }

    function showSavedWorkouts() {
        setProgramName("SAVED WORKOUTS")
        setupScreenManager.state = "LoadSavedWorkouts";
        savedWorkouts.show()
    }

    function setNumSegments(n) {
        workoutProgram.profile1.count = n
        workoutProgram.profile2.count = n
        mainProgItem.numSegs = n
        mainProgItem.segTime = workTime*60 / mainProgItem.numSegs
        basicSetup.setParameter(WorkoutProgram.SEGMENT_TYPE, n)
        basicSetup.recalcMaxSegments()
    }

    function setupProfileEditor() {
        var workoutType = mainProgItem.programIndex
        if(workoutType == WorkoutProgram.SAVED_WORKOUT) {
            workoutType = mainProgItem.customProgType
            return
        }
        else {
            setNumSegments(mainProgItem.numSegs)
        }
    }

    function computeProfileStats() {
       mainProgItem.profile1Max = workoutProgram.profile1.findMax("segmentLevel")
       mainProgItem.profile2Max = workoutProgram.profile2.findMax("segmentLevel")
    }

    // return a string with speed converted to appropriate units with units label (e.g. 103 = "10.3 MPH")
    function speedString(mphTimesTen) {
        var value, units
        if(options.metricUnits) {
            value = Globals.mileToKm(mphTimesTen / 10.0).toFixed(1)
            units = qsTr("KMH")
        }
        else {
            value = mphTimesTen / 10.0
            units = qsTr("MPH")
        }
        return value + " " + units
    }

    Connections {
        target: !main.blockKeys && main.isTft && mainProgItem.opacity > 0 && (setupScreenManager.state === "Simple" || setupScreenManager.state === "C360Step2" || setupScreenManager.state === "Step3") ? keymapper : null

        onStartPressed: {
            main.debugKeys("startPressed", "ProgSetup")
            mainProgItem.doStart()
        }
        onStartQuickStartPressed: {
            main.debugKeys("startQuickStartPressed", "ProgSetup")
            mainProgItem.doStart()
        }
    }

    Connections {
        target: !main.blockKeys && main.isTft && mainProgItem.visible && mainProgItem.opacity > 0 && !hrGuide.item ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "ProgSetup")
            if (setupScreenManager.state === "SaveWorkoutScreen")
                return
            else if (setupScreenManager.state === "Step2")
                setupScreenManager.state = "Step1"
            else if (setupScreenManager.state === "C360Step2")
                setupScreenManager.state = "Step1"
            else if (setupScreenManager.state === "Step3")
                setupScreenManager.state = "Step2"
            else
                navbar.goBack()
        }
    }

    Image {
        id: logoImage

        anchors.top: parent.top
        anchors.topMargin: 25
        anchors.left: parent.left
        anchors.leftMargin: 25

        source: "graphics/TRU_Home_Logo.png"
    } // end Image True logo

    Item { id: setupScreenManager

        anchors.fill: parent

        // Page 1 - Basic Parameters
        Loader {
            id: setupParamsLoader
            anchors.fill: parent
            sourceComponent: isTouch ? setupParamsComponent : keyedSetupParamsComponent

            Component {
                id: setupParamsComponent
                SetupParamsNew {
                    visible: true
                    model: setupParamList
                }
            }

            Component {
                id: keyedSetupParamsComponent
                KeyedSetupParams {
                    visible: true
                    model: setupParamList
                }
            }
        }

        // Page 2 - Custom C360 or Custom Profiles
        Item { id: step2
            visible: false
            anchors.fill: parent
            property variant segmentEditorRef: loaderSegmentEditor.item
            property variant c360ContentRef: loaderC360.item

            Loader {
                id: loaderSegmentEditor
                property bool editorLoaded: (main.state == "SetupState") && (setupScreenManager.state === "Step2")
                sourceComponent: editorLoaded ? segmentEditorComponent : undefined
                anchors.fill: parent

                Component {
                    id: segmentEditorComponent

                    SetupCustomProfile {
                        id: segmentEditor

                        profile1Title: mainProgItem.profile1Title
                        profile1Units: mainProgItem.profile1Units
                        profile2Title: mainProgItem.profile2Title
                        profile2Units: mainProgItem.profile2Units
                        model1: workoutProgram.profile1
                        model2: workoutProgram.profile2
                        profile1Visible: workoutProgram.profile1.isCustom
                        profile2Visible: workoutProgram.profile2.isCustom
                        workoutTime: mainProgItem.workTime
                        onWorkoutTimeChanged: {
                            if( mainProgItem.workTime != workoutTime) {
                                mainProgItem.workTime = workoutTime
                                basicSetup.setParameter(WorkoutProgram.TIME_TYPE, mainProgItem.workTime)
                            }
                        }
                        segmentTime: mainProgItem.segTime
                        visible: isSegmentTypeProg && step2.visible
                        anchors.fill: parent
                    }
                }
            }

            Loader {
                id: loaderC360
                sourceComponent: setupScreenManager.state === "C360Step2" ? c360ContentComponent : undefined
                anchors.fill: parent

                Component {
                    id: c360ContentComponent

                    SetupCustomC360 {
                        id: c360Content
                        anchors.fill: parent
                        visible: isC360Custom
                        model: c360SetupModel
                    }
                }
            }

        }

        Item { id: step3
            // Page 3
            Loader {
                id: summaryGraph
                property bool summaryLoaded: (main.state == "SetupState") && (setupScreenManager.state == "Step3")
                sourceComponent: summaryLoaded ? summaryComponent : undefined

                Component {
                    id: summaryComponent

                    SetupSummary {
                        id: summaryGraph2
                        profile1Title: mainProgItem.profile1Title
                        profile2Title: mainProgItem.profile2Title
                        profile1model: workoutProgram.profile1
                        profile2model: workoutProgram.profile2
                    }
                }
            }

            Text {
                id: program_name_header
                width: 500
                wrapMode: Text.WordWrap
                x: 790
                y: main.isTouch ? 97 : 77
                text: programNameTranslated + " " + qsTr("SUMMARY")
                color: "black"
                font.pointSize: text.length > 20 ? 20 : 26
                font.bold: true
            }

            SetupSynopsis {
                id: customWorkoutSynopsis

                distanceFromTop: main.isTft ? 140 : 172
                profile1Title: mainProgItem.profile1Title
                profile2Title: mainProgItem.profile2Title
                setupAge: ageForProgSummary
                setupWeight: weightForProgSummary
                totalTime: workTime
                numSegments: numSegs
                segmentTime: segTime
                profile1Max: mainProgItem.profile1Max
                profile2Max: mainProgItem.profile2Max
            }
        }

        Loader {
            id: saveProgLoader

            sourceComponent: main.isTft ? tftSaveProgComponent : touchSaveProgComponent

            anchors.fill: parent

            Component {
                id: touchSaveProgComponent

                SavedProgramsBrowser {
                    id: touchSavedWorkoutsBrowser
                    visible: false
                    anchors.fill: parent
                    profile1Title: mainProgItem.profile1Title
                    profile2Title: mainProgItem.profile2Title
                }
            }
            Component {
                id: tftSaveProgComponent

                KeyedSavedProgramsBrowser {
                    id: keyedSavedWorkoutsBrowser
                    visible: false
                    anchors.fill: parent
                    profile1Title: mainProgItem.profile1Title
                    profile2Title: mainProgItem.profile2Title
                }

            }
        }

        SavePrograms {
            id: saveWorkoutPopup
            x: 150
            y: 40
            visible: false
            programToSave: mainProgItem.programName
            onClosePopup: {
                hide()
            }
            onSaveProgram: {
                basicSetup.validateEntries()
                workoutProgram.setupComplete()  // update program from setup screens before saving
                saveCustomProgram(programName, saveLocation);
                mainProgItem.saveHasHappened = true
                mainProgItem.saveCount++
            }
        }

        SaveProgramScreen {
            id: saveProgramScreen
            visible: false
            anchors.fill: parent
            programToSave: mainProgItem.programName
            onSaveProgram: {
                basicSetup.validateEntries()
                workoutProgram.setupComplete()  // update program from setup screens before saving
                saveCustomProgram(programName, saveLocation);
                mainProgItem.saveHasHappened = true
                mainProgItem.saveCount++
            }
            onSaveComplete: {
                // Return to setup screen
                if (workoutProgram.profile1.isCustom || workoutProgram.profile2.isCustom)
                    setupScreenManager.state = "Step3"
                else if (isC360Custom)
                    setupScreenManager.state = "C360Step2"
                else
                    setupScreenManager.state = "Simple"
            }
        }

        states: [
            State {
                name: "Simple"
                PropertyChanges { target: setupParamsLoader; visible: true }
                PropertyChanges { target: stepButtons; visible: false }
                PropertyChanges { target: step1Button; isDown: false }
                PropertyChanges { target: step2Button; isDown: false }
                PropertyChanges { target: step3Button; isDown: false }
                PropertyChanges { target: step2; visible: false }
                PropertyChanges { target: step3; visible: false }
                PropertyChanges { target: nextButton; visible: false }
                PropertyChanges { target: startButton; visible: !main.isTft }
                PropertyChanges {
                    target: saveButton;
                    visible: (options.saveWorkoutEnabled) && main.isTouch
                }
                PropertyChanges { target: savedWorkouts; visible: false; opacity: 0 }
                PropertyChanges { target: saveProgramScreen; visible: false }
                PropertyChanges { target: logoImage; opacity: main.isTft ? 1 : 0 }
            },

            State {
                name: "SaveWorkoutScreen"
                PropertyChanges { target: setupParamsLoader; visible: false }
                PropertyChanges { target: stepButtons; visible: false }
                PropertyChanges { target: step1Button; isDown: false }
                PropertyChanges { target: step2Button; isDown: false }
                PropertyChanges { target: step3Button; isDown: false }
                PropertyChanges { target: step2; visible: false }
                PropertyChanges { target: step3; visible: false }
                PropertyChanges { target: nextButton; visible: false }
                PropertyChanges { target: startButton; visible: false }
                PropertyChanges { target: saveButton; visible: false }
                PropertyChanges { target: savedWorkouts; visible: false; opacity: 0 }
                PropertyChanges { target: saveProgramScreen; visible: true }
                PropertyChanges { target: logoImage; opacity: main.isTft ? 1 : 0 }
            },

            State {
                name: "Step1"

                PropertyChanges { target: setupParamsLoader; visible: true }
                PropertyChanges { target: stepButtons; visible: !isC360Custom && main.isTouch }
                PropertyChanges { target: step1Button; isDown: true }
                PropertyChanges { target: step2Button; isDown: false }
                PropertyChanges { target: step3Button; isDown: false }
                PropertyChanges { target: step2; visible: false }
                PropertyChanges { target: step3; visible: false }
                PropertyChanges { target: nextButton; visible: main.isTouch }
                PropertyChanges { target: startButton; visible: false }
                PropertyChanges { target: saveButton; visible: false }
                PropertyChanges { target: savedWorkouts; visible: false; opacity: 0 }
                PropertyChanges { target: saveProgramScreen; visible: false }
                PropertyChanges { target: logoImage; opacity: main.isTft ? 1 : 0 }
            },

            State {
                name: "C360Step2"

                PropertyChanges { target: setupParamsLoader; visible: false }
                PropertyChanges { target: step2; visible: true }
                PropertyChanges { target: step3; visible: false }
                PropertyChanges {
                    target: saveButton;
                    visible: (options.saveWorkoutEnabled) && main.isTouch
                }
                PropertyChanges { target: savedWorkouts; visible: false; opacity: 0 }
                PropertyChanges { target: stepButtons; visible: false }
                PropertyChanges { target: nextButton; visible: false }
                PropertyChanges { target: startButton; visible: !main.isTft }
                PropertyChanges { target: saveProgramScreen; visible: false }
                PropertyChanges { target: logoImage; opacity: 0 }
            },

            State {
                name: "Step2"

                PropertyChanges { target: setupParamsLoader; visible: false }
                PropertyChanges { target: stepButtons; visible: main.isTouch }
                PropertyChanges { target: step1Button; isDown: false }
                PropertyChanges { target: step2Button; isDown: true }
                PropertyChanges { target: step3Button; isDown: false }
                PropertyChanges { target: step2; visible: true }
                PropertyChanges { target: step3; visible: false }
                PropertyChanges { target: nextButton; visible: main.isTouch }
                PropertyChanges { target: startButton; visible: false }
                PropertyChanges { target: saveButton; visible: false }
                PropertyChanges { target: savedWorkouts; visible: false; opacity: 0 }
                StateChangeScript { script: { workoutProgram.setupComplete() ;setupProfileEditor() } }
                PropertyChanges { target: saveProgramScreen; visible: false }
                PropertyChanges { target: logoImage; opacity: 0 }
            },
            State {
                name: "Step3"
                StateChangeScript {
                    script: {
                        workoutProgram.setupComplete()
                        computeProfileStats()
                    }
                }

                PropertyChanges { target: setupParamsLoader; visible: false }
                PropertyChanges { target: stepButtons; visible: main.isTouch }
                PropertyChanges { target: step1Button; isDown: false }
                PropertyChanges { target: step2Button; isDown: false }
                PropertyChanges { target: step3Button; isDown: true }
                PropertyChanges { target: step2; visible: false }
                PropertyChanges { target: step3; visible: true }
                PropertyChanges { target: nextButton; visible: false }
                PropertyChanges { target: startButton; visible: !main.isTft }
                PropertyChanges {
                    target: saveButton;
                    visible: (options.saveWorkoutEnabled) && main.isTouch
                }
                PropertyChanges { target: savedWorkouts; visible: false; opacity: 0 }
                PropertyChanges { target: saveProgramScreen; visible: false }
                PropertyChanges { target: logoImage; opacity: 0 }
            },
            State {
                name: "LoadSavedWorkouts"

                PropertyChanges { target: setupParamsLoader; visible: false }
                PropertyChanges { target: stepButtons; visible: false }
                PropertyChanges { target: step1Button; isDown: false }
                PropertyChanges { target: step2Button; isDown: false }
                PropertyChanges { target: step3Button; isDown: true }
                PropertyChanges { target: step2; visible: false }
                PropertyChanges { target: step3; visible: false }
                PropertyChanges { target: nextButton; visible: false }
                PropertyChanges { target: startButton; visible: false }
                PropertyChanges { target: saveButton; visible: false }
                StateChangeScript { script: savedWorkouts.show() }
                PropertyChanges { target: saveProgramScreen; visible: false }
                PropertyChanges { target: logoImage; opacity: main.isTft ? 1 : 0 }
            }

        ]
    }

    Text { id: prog_setup_program_name
        anchors.top: parent.top
        anchors.topMargin: main.isTft ? 100 : 80
        anchors.right: parent.right
        anchors.rightMargin: main.isTft ? 65 : 10
        text: programNameTranslated
        visible: (main.isTouch && setupScreenManager.state != "Step3") || (main.isTft && setupScreenManager.state != "Step2" && setupScreenManager.state != "Step3" && setupScreenManager.state != "LoadSavedWorkouts")
        color: "black"
        horizontalAlignment: Text.AlignRight
        font.pointSize: main.isTft ? 26 : 34
        font.bold: true
    }

    Item { id: stepButtons
        anchors.top: parent.top
        anchors.topMargin: 140
        anchors.right: prog_setup_program_name.right
        visible: main.isTouch

       ImageButton { id: step3Button
            anchors.top: parent.top
            anchors.right: parent.right
            upimage: "graphics/setup/custom_step3_UP.png"
            downimage: "graphics/setup/custom_step3_DOWN.png"
            toggle: true
            radioGroup: [step1Button, step2Button, step3Button]

            onClicked: {
                basicSetup.validateEntries()
                setupScreenManager.state = "Step3"
            }
        }

        ImageButton { id: step2Button
            anchors.top: parent.top
            anchors.right: step3Button.left
            anchors.rightMargin: 20
            upimage: "graphics/setup/custom_step2_UP.png"
            downimage: "graphics/setup/custom_step2_DOWN.png"
            toggle: true
            radioGroup: [step1Button, step2Button, step3Button]

            onClicked: {
                basicSetup.validateEntries()
                setupScreenManager.state = "Step2"
            }
        }

        ImageButton { id: step1Button
            anchors.top: parent.top
            anchors.right: step2Button.left
            anchors.rightMargin: 20
            upimage: "graphics/setup/custom_step1_UP.png"
            downimage: "graphics/setup/custom_step1_DOWN.png"
            toggle: true
            radioGroup: [step1Button, step2Button, step3Button]

            onClicked: {
                setupScreenManager.state = "Step1"
            }
        }
    }

    ImageButton { id: startButton
        downimage: "graphics/setup/Start_Button_Down.png"
        upimage: "graphics/setup/Start_Button.png"

        label: qsTr("START") + application.emptyString
        label_color: "black"
        label_under: true
        fontsize: 18

        anchors {
            bottom: parent.bottom ; bottomMargin: 25
            right: parent.right ; rightMargin: 46
        }

        reenableDelay: 1000
        onClicked: {
            mainProgItem.doStart()
        }
        beep: machineinfo.productTypeString === "Treadmill" ? false : true
    }

    ImageButton { id: saveButton
        upimage:"./graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"./graphics/200/TRU_200_other_small_Button_Down.png"

        label: qsTr("SAVE") + application.emptyString
        label_color: "black"
        label_under: true
        fontsize: 18

        anchors {
            verticalCenter: startButton.verticalCenter
            right: startButton.left; rightMargin: 25
        }

        onClicked: {
            saveWorkoutPopup.show();
            saveWorkoutPopup.startTimeout(10);
        }
    }

    ImageButton { id: nextButton
        downimage: "graphics/setup/Start_Button_Down.png"
        upimage: "graphics/setup/Start_Button.png"

        label: qsTr("NEXT") + application.emptyString
        label_color: "black"
        label_under: true
        fontsize: 18

        anchors {
            bottom: parent.bottom ; bottomMargin: 25
            right: parent.right ; rightMargin: 46
        }

        onClicked: {
            mainProgItem.nextState()
        }
    }

    BluetoothDeviceSelectionDialog{
        id: btHRSelectionDialog
        isTop: true
        isTransparent: false
        height: mainProgItem.height * 0.42
        width: mainProgItem.width * 0.60
        anchors.horizontalCenter: mainProgItem.horizontalCenter
        anchors.verticalCenter: mainProgItem.verticalCenter

        onClosed: btHRSelectionDialog.hide()
        //onHeadsetConnected: btDeviceSelectionDialog.hide()
        //onHeadsetDisconnected: btDeviceSelectionDialog.hide()

    }

    ImageButton {
        id: bluetoothHeartrateButton

        visible: main.isTouch && targetHRType != targetHRTypeEnum.invalid
        downimage:  "graphics/Bluetooth/Bluetooth_HRicon.png"
        upimage:  "graphics/Bluetooth/Bluetooth_HRicon.png"

        icon: "graphics/Bluetooth/Bluetooth_icon_medium.png"

        anchors {
            bottom: parent.bottom ; bottomMargin: 200
            right: parent.right ; rightMargin: 300
        }

        onClicked: heartRateDeviceSelectionDialog.show()

    }

    ConfirmationPrompt {
        id: customSpeedWarningConfirmation
        blockKeys: true

        x: 300 ; y: 300
        visible: false
        prompt: qsTr("Start workout?") + application.emptyString
        yesText: qsTr("ACCEPT") + application.emptyString
        noText: qsTr("RETURN TO SETUP") + application.emptyString

        onYesClicked: {
            mainProgItem.startProgram();
            setupScreenManager.state = "Step1"
            hide()
        }

        onNoClicked: {
            setupScreenManager.state = "Step2"
            hide()
        }
        onTimedOut: hide()
    }

    ConfirmationPrompt {
        id: gerkinTestPrompt
        blockKeys: true

        borderHeight: 430
        textSize: 32
        x: 300 ; y: 200
        visible: false
        prompt: {
            var msg = qsTr("Warning - The Gerkin Fitness Test can reach high levels of speed, incline, and heart rate.")
            if (main.isTouch)
                msg += " " + qsTr("Press ACCEPT if you wish to continue.")
            else
                msg += " " + qsTr("Press START if you wish to continue.")
            return msg
        }
        yesText: qsTr("ACCEPT") + application.emptyString
        noText: qsTr("RETURN TO SETUP") + application.emptyString

        onYesClicked: {
            mainProgItem.startProgram();
            hide()
        }

        onNoClicked: {
            hide()
        }
        onTimedOut: hide()
    }

    onShowHRChart: hrGuide.show()

    Loader {
        id: hrGuide

        Connections {
            target: hrGuide.item
            onClose: hrGuide.hide()
            ignoreUnknownSignals: true
        }

        function show() {
            source = "HeartRateGuide.qml"
        }
        function hide() {
            source = ""
        }
        anchors.fill: parent
        z: 99
    }
}
