// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import WorkoutManager 1.0
import Components 1.0
import "tft_workout_menus.js" as TftMenus

Item {
    id: root

    property string programToSave
    property variant savedProgramFileList

    signal saveProgram(string programName, int saveLocation)
    signal saveComplete()

    function fileListModel() {
        var fileList = savedWorkouts.savedFileList()
        fileList.unshift("Back")
        return fileList
    }

    onVisibleChanged: {
        if (visible) {
            root.savedProgramFileList = fileListModel()
            saveButtons.currentIndex = 0
        }
    }

    Connections {
        target: !main.blockKeys && root.visible && root.opacity > 0 ? keymapper : null
        ignoreUnknownSignals: true

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "SaveProgramScreen")
            if (saveTimer.running) return

            saveButtons.decrementCurrentIndex()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "SaveProgramScreen")
            if (saveTimer.running) return

            saveButtons.incrementCurrentIndex()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "SaveProgramScreen")
            if (saveTimer.running) return

            if (saveButtons.model[saveButtons.currentIndex] == "Back") {
                root.saveComplete()
            }
            else if (saveButtons.currentIndex >= 1) {
                saveTimer.restart()
                root.saveProgram(root.programToSave, saveButtons.currentIndex)
                root.savedProgramFileList = root.fileListModel()
            }
        }

        onBackPressed: {
            main.debugKeys("backPressed", "SaveProgramScreen")
            if (saveTimer.running) return

            root.saveComplete()
        }
    }

    Rectangle{
        id:imageContainer
        anchors { top: parent.top; left: parent.left; topMargin: 95; leftMargin: 25 }
        radius: 20
        color: "#909090"
        width: 400
        height: 290
        Image {
            id: workout_image
            source: {
                if (saveButtons.currentIndex === 0) {
                    return options.modestyMode ? "WF/MaleOnly/WF_image_BACK_15inTFT.png" : "graphics/WF/WF_window_back_nav.png"
                } else {
                    return Globals.graphicsPath + TftMenus.getProgramImage(workoutProgram.programIndex)
                }
            }
        }
    }

    Text {
        id: prog_setup_desc_text
        x: 850
        y: 156
        width: 450
        text: qsTr("Do you want to save this workout setup?") + application.emptyString
        color: "black"
        wrapMode: Text.WordWrap
        horizontalAlignment: Text.AlignRight
        font.pixelSize: 28
    }

    Text {
        text: qsTr("choose one of the 5 slots to save workout setup") + application.emptyString
        font.pixelSize: 14
        anchors { bottom: saveButtons.top; bottomMargin: 15; horizontalCenter: parent.horizontalCenter }
    }

    ListView {
        id: saveButtons

        orientation: ListView.Horizontal
        model: root.savedProgramFileList
        delegate: saveDelegate
        keyNavigationWraps: true
        highlight: Component {
            Image {
                source: "graphics/tft/NAV_selector.png"
                // set highlightFollowsCurrentItem to false, and manually define the x location.
                // this technique allows a highlight item that is wider than the delegate
                x: saveButtons.currentItem ? saveButtons.currentItem.x - 40 : x
                Behavior on x {
                    SmoothedAnimation {
                        duration: 200
                    }
                }
            }
        }
        highlightFollowsCurrentItem: false
        width: 164 * 6
        height: 220
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 100
    }

    Component {
        id: saveDelegate
        Item {
            width: 164
            height: 213

            Image {
                id: imageIcon
                anchors { top: parent.top; topMargin: 24; horizontalCenter: parent.horizontalCenter }
                source: {
                    switch (modelData) {
                        case "Back":
                            return "graphics/tft/nav_icon_BACK.png"
                        case "--":
                            return "graphics/tft/dashdash.png"
                        default:
                            return "graphics/tft/nav_icon_SAVED.png"
                    }
                }
            }

            Text {
                text: {
                    switch (modelData) {
                    case "Back":
                        return qsTr("Back") + application.emptyString
                    case "--":
                        return qsTr("SAVED WORKOUT") + " " + (index) + application.emptyString
                    default:
                        return qsTr("SAVED") + " " + modelData + application.emptyString
                    }
                }
                anchors { top: imageIcon.bottom; topMargin: modelData === "--" ? 32 : 20; horizontalCenter: parent.horizontalCenter }
                font.pointSize: 16
                horizontalAlignment: Text.AlignHCenter
                width: 80
                wrapMode: Text.WordWrap
                font.bold: true
                smooth: true
            }
        }
    }

    Text {
        id: bottomHelpText

        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to select") + application.emptyString
        visible: saveButtons.currentIndex >= 1 && !savedText.visible

        anchors.top: saveButtons.bottom
        anchors.topMargin: 15
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Text {
        id: savedText

        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("workout setup saved") + application.emptyString
        visible: saveTimer.running

        anchors.top: saveButtons.bottom
        anchors.topMargin: 15
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Timer {
        id: saveTimer
        running: false
        interval: 3000
        onTriggered: {
            root.saveComplete()
        }
    }
}
