import QtQuick 2.4
import Components 1.0

ModalDialog {
    id: root
    width: 888
    height: 653

    signal saveProgram(string programName, int saveLocation)
    signal closePopup()
    property string savedProgramPath: "/data/saved_programs/"
    property variant savedProgramFileList
    property string programToSave: ""
    property int savingIndex: 0

    onTimedOut: closePopup()

    onVisibleChanged: {
        // populate the list of saved files when the dialog is shown
        if(visible) {
            // use the savedFileList() function from the SavedProgramsBrowser instantiated in ProgSetup
            root.savedProgramFileList = savedWorkouts.savedFileList()
            root.savingIndex=0
            startTimeout(10)
        }
    }

    Image {
        id: saveProgBackground
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        source: "graphics/Pop_Up_Lrg_Grey.png"
    }

    Text {
        id: instructValue
        anchors.top: saveProgBackground.top
        anchors.topMargin: 70
        anchors.left: saveProgBackground.left
        anchors.leftMargin: 50
        text: qsTr("Store workout setup information\nin one of 5 memory slots by\npressing SAVE button.") + application.emptyString
        font.pointSize: 16
        color: "black"
        visible: true
    }

    ListView {
        id: saveControls

        model: root.savedProgramFileList
        delegate: saveDelegate
        anchors.horizontalCenter: saveProgBackground.horizontalCenter
        anchors.top: saveProgBackground.top
        anchors.topMargin: 50
        anchors.bottom: saveProgBackground.bottom
        interactive: true

    }
    Component {
        id: saveDelegate

        Item {
            height: childrenRect.height

            ImageButton {
                id: saveProgButton
                downimage: "graphics/205/Lrg_Button_Down.png"
                upimage: (index+1 == root.savingIndex) ? "graphics/205/Lrg_Button_Down.png" : "graphics/205/Lrg_Button_Up.png"
                icon: (index+1 == root.savingIndex) ? "graphics/205/IPOD_Checkmark.png" : ""
                fontsize: 14
                label_color: "black"
                label_under: true
                label: qsTr("SAVE") + application.emptyString
                enabled: root.savingIndex == 0
                onClicked: {
                    root.savingIndex = index + 1
                    saveProgram(root.programToSave,index+1);
                    root.savedProgramFileList = savedWorkouts.savedFileList()
                    startTimeout(1) // close dialog 1 second after clicking a save position
                }
            }

            Text {
                id: programFileName
                anchors.verticalCenter: saveProgButton.verticalCenter
                anchors.left: saveProgButton.right
                anchors.leftMargin: 20
                text: modelData
                font.pointSize: 24
                color: "black"
                visible: true
            }
        }
    }

    ImageButton {
        id: closeButton
        anchors.right: saveProgBackground.right
        anchors.rightMargin: 70
        anchors.top: saveProgBackground.top
        anchors.topMargin: 42
        downimage: "Keypad/KeyPad_X_Large.png"
        upimage: "Keypad/KeyPad_X_Large.png"
        onClicked: {
            closePopup();
        }
    }
}
