import QtQuick 2.4
import StorageMgr 1.0
import WorkoutManager 1.0
import Components 1.0

Item {
    id: root

    property int maxFiles: 5
    property string savedProgramPath: "/data/saved_programs/"
    property string profile1Title: ""
    property string profile2Title: ""

    onVisibleChanged: {
        if (visible === false && setupScreenManager.state === "LoadSavedWorkouts")
            visible = true
    }

    function show() {
        savedProgList.model = savedFileList()
        savedProgList.currentIndex = 0
        showSynopsis(savedProgList.currentIndex)
        visible = true
    }

    function showSynopsis(index) {
        console.log("showSynopsis: loading ", index)
        savedWorkoutSynopsis.visible = false
        if (savedProgList.model[index] == "--") {
            workoutProgram.abortWorkoutLoad()
            savedWorkoutSynopsis.visible = false;
            nextButton.visible = false;
            loadingText.visible = false
            mainProgItem.setProgramName("SAVED WORKOUTS")
        }
        else {
            savedWorkoutSynopsis.visible = false;
            loadingText.visible = true;
            nextButton.visible = false;
            // the loading happens asynchronously, and is finished in the onLoadSaveProgramComplete slot
            workoutProgram.loadSaveProg(index+1)
            mainProgItem.setProgramName(savedProgList.currentItem.progName)
        }
    }

    Connections {
        target: main.isTouch && main.state === "SetupState" && setupScreenManager.state === "LoadSavedWorkouts" ? workoutProgram : null
        onLoadSaveProgramComplete: {
            loadingText.visible = false
            savedWorkoutSynopsis.visible = true
            nextButton.visible = true
        }
    }

    // populate the list of saved files from directory listing
    function savedFileList() {
        var storedFiles = storage.listFiles(savedProgramPath, "*.xml")
        var newList = [];
        var idx=0
        for(var i=0 ; i < root.maxFiles ; i++) {
            // files are prefixed with 1_, 2_, etc.  Assume list is sorted.
            if(storedFiles[idx] && (storedFiles[idx][0] == (i+1).toString()) ) {
                var progName = storedFiles[idx].split(".");
                var tempStr = progName[0];
                newList[i] = tempStr.substr(2);
                newList[i] = application.translateText("Menu", newList[i]);
                idx++
            }
            else
                newList[i] = "--"
        }
        return newList
    }

    StorageMgr {
        id: storage
    }

    SavedProgramSynopsis {
        id: savedWorkoutSynopsis
        setupAge: ageForProgSummary
        setupWeight: weightForProgSummary
        profile1Title: root.profile1Title
        profile2Title: root.profile2Title
    }

    Item {
        id: centeringRectangle
        width: 540
        height: 150
        anchors { left: parent.left; leftMargin: 785; top: parent.top; topMargin: 172 }
        visible: false
    }

    Text {
        id: loadingText
        text: qsTr("LOADING...") + application.emptyString
        anchors.centerIn: centeringRectangle
        font { pixelSize: 22; family: "arial"; bold: true }
        visible: false
    }

    Rectangle {
        id: progressBar
        color: "blue"
        height: 10
        width: (workoutProgram.parsingProgress / 100) * loadingText.implicitWidth
        anchors { left: loadingText.left; top: loadingText.bottom; topMargin: 10 }
        opacity: 0.5
        visible: loadingText.visible
    }

    Connections {
        target:workoutProgram
        onParsingProgressChanged: console.log("progress>>", workoutProgram.parsingProgress)
    }

    ListView {
        id: savedProgList
        interactive: false
        model: savedFileList()
        delegate: savedProgramDelegate
        anchors { fill: parent ; leftMargin: 50 ; topMargin: 60 }
    }

    Component { id: savedProgramDelegate
        Image { id: savedProgBackground
            anchors.left: parent.left
            anchors.leftMargin: ListView.isCurrentItem ? 40 : 0
            source: "graphics/setup/Setup_Large_Down.png"
            property string progName: savedProgFilename.text
            Text { id: savedProgTitle
                anchors.top: savedProgBackground.top
                anchors.topMargin: 16
                anchors.left: savedProgBackground.left
                anchors.leftMargin: 20
                text: qsTr("SAVED WORKOUT ") + application.emptyString + (index + 1)
                font.pointSize: 20
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }

            Text { id: savedProgFilename
                anchors.bottom: savedProgBackground.bottom
                anchors.bottomMargin: 18
                anchors.right: savedProgBackground.right
                anchors.rightMargin: 15
                text: modelData
                font.pointSize: 16
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }

            MouseArea {
                anchors.fill: parent
                onPressed: {
                    if (index != savedProgList.currentIndex) {
                        buzzer.buttonPress()
                        savedProgList.currentIndex = index
                        showSynopsis(index)
                    }
                }
            }
        }
    }
}
