// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4

Item{  // popup screen lock
    id: root

    property int timeLeft: 5
    property int lockTime: 20    // number of seconds for screen lock

    anchors.fill: parent
    visible: false
    z:99 // ensure that the screenlock is on top of everything else

    Image {
        source: "graphics/Pop_Up_Lrg_Grey.png"
        anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: parent.verticalCenter }

        Text { // display screen lock message
            id: lock_message_text
            anchors { top: parent.top ; topMargin: 50 ; horizontalCenter: parent.horizontalCenter }
            text: qsTr("SCREEN LOCKED FOR CLEANING") + application.emptyString
            color: "white"
            font.pointSize: 26
            font.bold: true
        }

        Image {
            id: lock_image

            anchors { verticalCenter: parent.verticalCenter ; left: parent.left ; leftMargin: -30 }
            source: "graphics/Screen_Lock_Pad_Lock.png"
        }

        Text { // display of remaining lock seconds
            id: lock_countdown_text
            anchors { top: lock_message_text.bottom; topMargin: 150; right: parent.right; rightMargin: 170 }
            color: "white"
            text: ((root.timeLeft > 9)? ":":":0") + screen_lock_overlay.timeLeft  // display leading zero if val > 9
            font.pointSize: 132
            font.bold: true
        }
    }

    Timer { // count down every second while screen is locked
        id: lock_timer
        interval: 1000 ; repeat: true ; running: false
        onTriggered: {
            // timeLeft is displayed above
            screen_lock_overlay.timeLeft = screen_lock_overlay.timeLeft - 1
            if(screen_lock_overlay.timeLeft <= 0 ) {
                // close the screen lock overlay
                screen_lock_overlay.visible = false
                lock_timer.stop()
                keymapper.keysEnabled = true
            }
        }
    }

    MouseArea { // overlay a mouse area to prevent activating anything underneath
        id: lock_popup
        anchors.fill: parent
    }

    function open() {
        timeLeft = lockTime
        screen_lock_overlay.visible = true
        lock_timer.start()
        keymapper.keysEnabled = false
    }
}
