import QtQuick 2.4
import WorkoutManager 1.0
import "string_format.js" as Format
import Components 1.0

Item {
    id: root

    property variant model1
    property variant model2
    property int currentIndex: 0
    property string profile1Title
    property string profile2Title
    property string profile1Units
    property string profile2Units
    property bool profile1Visible: false
    property bool profile2Visible: false
    property int workoutTime
    property int segmentTime
    property int navIndex: -1

    function firstTab() {
        switch (workoutProgram.programIndex) {
            // incline or workload first
            case WorkoutProgram.TREAD_CUSTOM_HILLS_PROG:
            case WorkoutProgram.CUSTOM_HILLS_PROG:
            case WorkoutProgram.CUSTOM_ULTRA_PROG:
                return "profile1tab"
            // speed or pace first
            case WorkoutProgram.TREAD_CUSTOM_ULTRA_PROG:
            case WorkoutProgram.TREAD_CUSTOM_SPEED_PROG:
            case WorkoutProgram.CUSTOM_PACE_PROG:
                return "profile2tab"
            default: // fallback
                return "profile2tab"
        }
    }

    state: ""

    function clear() {
        if(profile1Visible)
            state = "Profile1"
        else
            state = "Profile2"
        currentIndex = 0
        model1.clearHistory()
        model2.clearHistory()
    }

    function nextSegment() {
        if (root.currentIndex < (profileWidget1.model.count - 1)) {
            root.currentIndex++
            return true
        }
        return false
    }

    function previousSegment() {
        if (root.currentIndex > 0) {
            root.currentIndex--
            return true
        }
        return false
    }

    function alternateTab() {
        if (state === "Profile1" && workoutProgram.profile2.isCustom)
            state = "Profile2"
        else if (state === "Profile2" && workoutProgram.profile1.isCustom)
            state = "Profile1"
    }

    // Pseudo Item to adjust anchors between Touch and TFT
    Item {
        id: anchorItem
        state: main.isTft ? "TftAnchorState" : "TouchAnchorState"
        states: [
            State { name: "TftAnchorState"
            },

            State { name: "TouchAnchorState"
            }
        ]
    }

    Connections {
        target: main.isTft && setupScreenManager.state === "Step2" ? keymapper : null
        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "SetupCustomProfile")
            if (navIndex === 0) {
                setupScreenManager.state = "Step1"
                return
            } else if (navIndex === 1) {
                root.currentIndex = profileWidget1.model.count - 1
                navIndex = -1
                return
            }

            var indexDecremented = root.previousSegment()
            if (!indexDecremented) {
                root.currentIndex = -1
                navIndex = 0
            }
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "SetupCustomProfile")
            if (navIndex === 1) {
                setupScreenManager.state = "Step3"
                return
            } else if (navIndex === 0) {
                navIndex = -1
                root.currentIndex = 0
                return
            }

            var indexIncremented = root.nextSegment()
            if (!indexIncremented) {
                root.currentIndex = -1
                navIndex = 1
            }
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "SetupCustomProfile")
            if (navIndex === 0) {
                setupScreenManager.state = "Step1"
            } else if (navIndex === 1) {
                setupScreenManager.state = "Step3"
            } else if (navIndex === -1) {
                root.alternateTab()
            }
        }

        onPlusPressed: {
            main.debugKeys("plusPressed", "SetupCustomProfile")
            if (navIndex === -1) {
                profileSlider1.incrementValue()
            }
        }

        onMinusPressed: {
            main.debugKeys("minusPressed", "SetupCustomProfile")
            if (navIndex === -1) {
                profileSlider1.decrementValue()
            }
        }

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "SetupCustomProfile")
            if (navIndex === -1) {
                profileSlider1.incrementValue()
            }
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "SetupCustomProfile")
            if (navIndex === -1) {
                profileSlider1.decrementValue()
            }
        }
    }

    // change the current state when the visibility of the two profile editor tabs changes
    onProfile1VisibleChanged: {
        if (profile1Visible && profile2Visible)
            state = (firstTab() === "profile1tab" ? "Profile1" : "Profile2")
        else if (profile1Visible)
            state = "Profile1"
        else if (profile2Visible)
            state = "Profile2"
    }

    onProfile2VisibleChanged: {
        if (profile1Visible && profile2Visible)
            state = (firstTab() === "profile1tab" ? "Profile1" : "Profile2")
        else if(profile1Visible)
            state = "Profile1"
        else if(profile2Visible)
            state = "Profile2"
    }

    Text {
        id: customProfileInstructLabel
        visible: main.isTouch
        anchors.top: parent.top
        anchors.topMargin: 350
        anchors.left: parent.right
        anchors.leftMargin: -320
        width: 300
        wrapMode: Text.WordWrap
        text: qsTr("TOUCH ANY SEGMENT TO ADJUST") + application.emptyString
        font.pointSize: 12
        font.bold: true
        smooth: true
        color: "black"
    }

    Item {
        id: segTime
        visible: main.isTouch

        width: 380
        height: 134
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        anchors.left: parent.left
        anchors.leftMargin: 80

        Image {
            id: segTimeBackground
            anchors.left: parent.left
            anchors.top: parent.top
            width: 380
            height: 134
            source: "graphics/setup/Setup_Large_Up_Step1_small.png"
            z: 1
        }

        ImageButton {
            id: decrementSegTimeButton
            anchors.right: segTimeBackground.left
            anchors.rightMargin: -20
            anchors.bottom: segTimeBackground.bottom
            anchors.bottomMargin: 10
            downimage: "graphics/setup/Custom_Arrow_Left_Pressed.png"
            upimage: "graphics/setup/Custom_Arrow_Left.png"
            icon: "graphics/setup/White_Minus.png"
            icon_y_offset: -9
            onClicked: {
                if (root.workoutTime > 5) {
                    root.workoutTime--;
                    if (workoutProgram.profile1.count > root.workoutTime) {
                        mainProgItem.setNumSegments(root.workoutTime)
                    }
                }
            }
        }

        ImageButton {
            id: incrementSegTimeButton
            anchors.left: segTimeBackground.right
            anchors.leftMargin: -30
            anchors.bottom: segTimeBackground.bottom
            anchors.bottomMargin: 10
            downimage: "graphics/setup/Custom_Arrow_Right_Pressed.png"
            upimage: "graphics/setup/Custom_Arrow_Right.png"
            icon: "graphics/setup/White_Plus.png"
            icon_x_offset: -4
            icon_y_offset: -9
            onClicked: {
                if (root.workoutTime < options.workoutTimeMax) {
                    root.workoutTime++;
                }
            }
        }

        Text {
            id: segTimeItemName
            anchors.top: parent.top
            anchors.topMargin: 18
            anchors.left: parent.left
            anchors.leftMargin: 20
            text: qsTr("WORKOUT TIME") + application.emptyString
            font.pointSize: 16
            font.bold: true
            smooth: true
            color: "black"
            z: 2
        }

        Text {
            id: segTimeItemValue
            anchors.bottom: segTimeBackground.bottom
            anchors.bottomMargin: 30
            anchors.right: segTimeBackground.right
            anchors.rightMargin: 40
            text: Format.formatTimeString(root.workoutTime * 60);
            font.pointSize: 30
            font.bold: true
            smooth: true
            color: "black"
            z: 2
        }
    }

    Text {
        id: calculatedSegTime
        visible: main.isTouch
        x: 426
        y: 410
        anchors.bottom: calculatedSegTimeValue.top
        anchors.bottomMargin: 2
        anchors.horizontalCenter: calculatedSegTimeValue.horizontalCenter
        text: qsTr("SEGMENT TIME") + application.emptyString
        font.pointSize: 12
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: calculatedSegTimeValue
        visible: main.isTouch
        x: 179
        y: 431
        anchors.verticalCenter: segTime.verticalCenter
        text: Format.formatTimeString(root.segmentTime);
        anchors.horizontalCenterOffset: -120
        anchors.horizontalCenter: parent.horizontalCenter
        font.pointSize: 24
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Item {
        id: numSegs
        visible: main.isTouch
        y: 370

        width: 380
        height: 134
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        anchors.left: segTime.right
        anchors.leftMargin: 220

        Image {
            id: numSegsBackground
            anchors.left: parent.left
            anchors.top: parent.top
            width: 380
            height: 134
            source: "graphics/setup/Setup_Large_Up_Step1_small.png"
            z: 1
        }

        ImageButton {
            id: decrementSegButton
            anchors.right: numSegsBackground.left
            anchors.rightMargin: -20
            anchors.bottom: numSegsBackground.bottom
            anchors.bottomMargin: 10
            downimage: "graphics/setup/Custom_Arrow_Left_Pressed.png"
            upimage: "graphics/setup/Custom_Arrow_Left.png"
            icon: "graphics/setup/White_Minus.png"
            icon_y_offset: -9
            onClicked: {
                if (workoutProgram.profile1.count > 2) {
                    mainProgItem.setNumSegments(workoutProgram.profile1.count -1)
                }
            }
        }

        ImageButton {
            id: incrementSegButton
            anchors.left: numSegsBackground.right
            anchors.leftMargin: -30
            anchors.bottom: numSegsBackground.bottom
            anchors.bottomMargin: 10
            downimage: "graphics/setup/Custom_Arrow_Right_Pressed.png"
            upimage: "graphics/setup/Custom_Arrow_Right.png"
            icon: "graphics/setup/White_Plus.png"
            icon_x_offset: -4
            icon_y_offset: -9
            onClicked: {
                if (workoutProgram.profile1.count < 30 && workoutProgram.profile1.count < root.workoutTime) {
                    mainProgItem.setNumSegments(workoutProgram.profile1.count+1)
                    root.currentIndex = (workoutProgram.profile1.count - 1);
                }
            }
        }

        Text {
            id: numSegsItemName
            anchors.top: parent.top
            anchors.topMargin: 18
            anchors.left: parent.left
            anchors.leftMargin: 20
            text: qsTr("SEGMENTS") + application.emptyString
            font.pointSize: 16
            font.bold: true
            smooth: true
            color: "black"
            z: 2
        }

        Text {
            id: numSegsItemValue
            anchors.bottom: numSegsBackground.bottom
            anchors.bottomMargin: 30
            anchors.right: numSegsBackground.right
            anchors.rightMargin: 40
            text: workoutProgram.profile1.count
            font.pointSize: 30
            font.bold: true
            smooth: true
            color: "black"
            z: 2
        }
    }

    Image {
        source: "graphics/tft/NAV_selector.png"
        visible: main.isTft && root.navIndex >= 0
        smooth: true
        anchors.verticalCenter: navIndex === 0 ? backItem.verticalCenter : nextItem.verticalCenter
        anchors.horizontalCenter: navIndex === 0 ? backItem.horizontalCenter : nextItem.horizontalCenter
    }

    Item {
        id: backItem
        visible: main.isTft
        anchors { right: graphEditor.left; rightMargin: 130; bottom: graphEditor.bottom; bottomMargin: -40 }
        width: 140; height: 120
        Image {
            id: back_x_image
            source: "graphics/tft/nav_icon_BACK.png"
            anchors { top: parent.top; horizontalCenter: parent.horizontalCenter }
        }
        Text {
            id: back_text
            text: qsTr("BACK") + application.emptyString
            anchors { top: back_x_image.bottom; topMargin: 10; horizontalCenter: parent.horizontalCenter }
            font { pointSize: 14; bold: true }
            horizontalAlignment: Text.AlignHCenter
            width: parent.width
            smooth: true
        }
    }

    Item {
        id: nextItem
        visible: main.isTft
        anchors { left: graphEditor.right; leftMargin: 120; bottom: graphEditor.bottom; bottomMargin: -40 }
        width: 140; height: 120
        Image {
            id: next_image
            source: "graphics/tft/arrow_right.png"
            anchors { top: parent.top; topMargin: 20; horizontalCenter: parent.horizontalCenter }
        }
        Text {
            id: next_text
            text: qsTr("NEXT") + application.emptyString
            color: "gray"
            anchors { top: next_image.bottom; topMargin: 55; horizontalCenter: parent.horizontalCenter }
            font { pointSize: 14; bold: true }
            horizontalAlignment: Text.AlignHCenter
            width: parent.width
            smooth: true
        }
    }

    Item {
        id: graphEditor
        width: 737
        height: 579
        anchors.horizontalCenter: main.isTft ? parent.horizontalCenter : undefined
        anchors.left: main.isTouch ? parent.left : undefined
        anchors.leftMargin: main.isTouch ? 150 : 0
        anchors.top: parent.top
        anchors.topMargin: 25

        TabbedView{
            id: profile2Tab

            visible: profile2Visible

            index: firstTab() === "profile2tab" ? 0 : 1
            tabOffset: 15
            tabSpacing: 9
            tabWidth: 264
            tabHeight: 47
            width:parent.width
            height: parent.height - 5
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            activeTabImageSciFile: "graphics/setup/activeTabImage_new.sci"
            inactiveTabImageSciFile: "graphics/setup/inactiveTabImage_new.sci"
            backgroundImageSciFile: "graphics/setup/Profile_Edit_White_new.sci"
            label: profile2Title
            state: "INACTIVE"
            onTabSelected: {
                profile1Tab.state = "INACTIVE"
                root.state = "Profile2";
            }
        }

        ProfileWidget {
            id: profileWidget2

            onEditSegmentChanged: root.currentIndex = editSegment

            anchors {
                top: parent.top ; topMargin: 40
                bottom: parent.bottom ; bottomMargin: 13
                left: parent.left ; leftMargin: 17
                right: parent.right ; rightMargin: 17
            }
            model: workoutProgram.profile2
            yPosition: 45
            xPositionOffset: 35
            editable: true
            levelIndicatorVisibility: false
            profileVisible: profile2Visible
            columnWidth: 60 // Must not be below 10
            activeSegment: root.currentIndex
            active: profile2Tab.selected
            isWorkoutView: false
            z: active ? profileSlider1.z +2 : profileSlider1.z -1
            enableHeightAnimation: false
            labelVisibility: editable && active
            baseOffset: 50
            segmentColorEditor: "#F38D21"
            heightDifferential: -70 // lower the bar to not cover the slider "plus" button
            useAlternativeHeight: true
            alternativeHeight: profileSlider1.knobOffset
        }

        TabbedView{
            id: profile1Tab

            visible: profile1Visible

            index: firstTab() === "profile1tab" ? 0 : 1
            tabOffset: 15
            tabWidth: 264
            tabHeight: 47
            width:parent.width
            height: parent.height - 5
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            activeTabImageSciFile: "graphics/setup/activeTabImage_new.sci"
            inactiveTabImageSciFile: "graphics/setup/inactiveTabImage_new.sci"
            backgroundImageSciFile: "graphics/setup/Profile_Edit_White_new.sci"
            label: profile1Title
            state: "INACTIVE"
            onTabSelected: {
                profile2Tab.state = "INACTIVE"
                root.state = "Profile1";
            }
        }

        Image {
            id: workloadTabGradientFill
            anchors.left: profile1Tab.left
            anchors.leftMargin: 10
            anchors.right: profile1Tab.right
            anchors.rightMargin: 10
            anchors.verticalCenter: profile1Tab.verticalCenter
            anchors.verticalCenterOffset: 70
            source: "graphics/setup/BKGR_WALK_RUN_fade.png"
            visible: root.state == "Profile2"
            z: 3
        }

        Image {
            id: speedTabLines
            anchors.left: profile1Tab.left
            anchors.leftMargin: 10
            anchors.verticalCenter: profile1Tab.verticalCenter
            anchors.verticalCenterOffset: 70
            source: "graphics/setup/RUN_JOG_WALK_dashed.png"
            visible: root.state == "Profile2" && workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL
            z: 4
        }

        ProfileWidget {
            id: profileWidget1

            onEditSegmentChanged: root.currentIndex = editSegment

            anchors {
                top: parent.top ; topMargin: 40
                bottom: parent.bottom ; bottomMargin: 13
                left: parent.left ; leftMargin: 17
                right: parent.right ; rightMargin: 17
            }
            model: workoutProgram.profile1
            yPosition: 45  // position zero value on zero line
            xPositionOffset: 10
            editable: true
            levelIndicatorVisibility: false
            profileVisible: profile1Visible
            columnWidth: 60 // Must not be below 10
            active: profile1Tab.selected
            activeSegment: root.currentIndex
            isWorkoutView: false
            z: active ? profileSlider1.z +2 : profileSlider1.z -1
            enableHeightAnimation: false
            hasNegativeValues: machineinfo.treadmillInclineMinPercentGrade < 0.0
            numNegativeValues: {
                if (!hasNegativeValues) return 0

                var index = machineinfo.inclineTable.indexOf(0.0)
                return index
            }
            labelVisibility: editable && active
            baseOffset: 50
            segmentColorEditorCurrent: "#BED63A"
            heightDifferential: -70 // lower the bar to not cover the slider "plus" button
            useAlternativeHeight: true
            alternativeHeight: profileSlider1.knobOffset
        }

        // Profile editor slider
        ProfileSliderControl {
            id: profileSlider1
            property int index: root.currentIndex
            property variant model: root.state == "Profile1" ? profileWidget1.model : profileWidget2.model
            property variant profileWidget: root.state == "Profile1" ? profileWidget1 : profileWidget2

            x: profileWidget.x + profileWidget.currentSegmentX
            z: profile1Tab.z + 2
            visible: profileWidget.active && ( (x > 0) && (x < parent.width-width) ) && root.currentIndex >= 0
            width: profileWidget.columnWidth
            anchors.top: profileWidget.top
            anchors.topMargin: 60
            anchors.bottom: profileWidget.bottom ; anchors.bottomMargin: profileWidget.yPosition + 5

            Connections {
                target: profileSlider1.model
                onDataChanged: {
                    // reset saved flag whenever the user edits a profile segment
                    mainProgItem.saveHasHappened = false

                    var segValue = profileSlider1.model.getProperty(profileSlider1.index, "segmentLevel")
                    if (segValue)
                        profileSlider1.value = segValue
                }
            }
            onModelChanged: indexChanged(root.currentIndex)
            onIndexChanged: {
                if(model) {
                    var segValue = model.getProperty(index, "segmentLevel")
                    if(segValue)
                        value  = segValue
                }
            }

            onValueChanged: model.setSegmentLevel(root.currentIndex, value);
            showValue: false
            maxValue: model.maxLevel
            minValue: 1
            buttonOffsetX: 0
            buttonMargin: -5
            orientation: Qt.Vertical
            thumbImage: "graphics/setup/custom_segment_slider.png"
            incrementButtonImage: main.isTouch ? "graphics/setup/custom_segment_plus_UP.png" : "graphics/setup/custom_segment_plus_UP_tft.png"
            decrementButtonImage: main.isTouch ? "graphics/setup/custom_segment_minus_UP.png" : "graphics/setup/custom_segment_minus_UP_tft.png"
            trackImage: "graphics/setup/custom_segment_line.png"
            baseOffset: 50.0
            baseIndex: minValue + profileWidget.numNegativeValues
            buttonAreaScale: 1.0
            dragAreaMargin: -30
        }
        // segment number displayed under each bar
        ListView {
            id: segNumberList

            Component.onCompleted: contentX = 0

            height: 42
            width:parent.width - x
            x: profileWidget1.x  + profileWidget1.columnWidth/2 + profileWidget1.xPositionOffset
            anchors { right: parent.right ; rightMargin: 0 ; top: parent.bottom ; topMargin: 0 }
            interactive: false //root.editable
            orientation: ListView.Horizontal
            highlightRangeMode: ListView.ApplyRange
            highlightFollowsCurrentItem: true
            currentIndex: root.currentIndex
            preferredHighlightBegin: (width/2) - 60
            preferredHighlightEnd: (width/2) + 60
            clip: true
            model: profileWidget1.model.count
            delegate: Text {
                width: profileWidget1.columnWidth*2
                text: index + 1
                color: "black"
                horizontalAlignment: Text.AlignCenter
                font.pointSize: 14
                font.bold: true
            }
        }

        ImageButton {
            id: previousSegButton
            anchors.right: parent.left
            anchors.rightMargin: 40
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            downimage: "graphics/setup/Custom_Arrow_Left_Pressed.png"
            upimage: "graphics/setup/Custom_Arrow_Left.png"
            disabledimage: main.isTft ? upimage : "graphics/setup/Custom_Arrow_Left_Pressed.png"
            icon: ""
            onClicked: {
                root.previousSegment()
            }
            enabled: root.currentIndex > 0
        }

        ImageButton {
            id: nextSegTimeButton
            anchors.left: parent.right
            anchors.leftMargin: 8
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            downimage: "graphics/setup/Custom_Arrow_Right_Pressed.png"
            upimage: "graphics/setup/Custom_Arrow_Right.png"
            disabledimage: main.isTft ? upimage : "graphics/setup/Custom_Arrow_Right_Pressed.png"
            icon: ""
            onClicked: {
                root.nextSegment()
            }
            enabled: root.currentIndex < profileWidget1.model.count-1

        }

        Component {
            id: hatchMarkComponent

            Rectangle {
                id: mark
                width: 20
                height: 4
                color: "black"
                anchors.right: parent.right
                Text {
                    id: markLabel
                    anchors.right: mark.left
                    anchors.rightMargin: 10
                    anchors.verticalCenter: mark.verticalCenter
                    text: modelData
                    color: "black"
                    horizontalAlignment: Text.AlignRight
                    font.pointSize: 12
                    font.bold: true
                }
            }
        }

        Text {
            id: hatchMark1Title

            visible: profile1HatchMarks.visible
            anchors { top: profile1HatchMarks.top ; topMargin: -12 ; right: profile1HatchMarks.left }
            text: root.profile1Units
            color: "black"
            horizontalAlignment: Text.AlignRight
            font.pointSize: 14
            font.bold: true
        }

        Column {
            id: profile1HatchMarks
            function chooseModel() {
                if (workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL) {
                    if (machineinfo.treadmillInclineMinPercentGrade >= 0.0) {
                        if (machineinfo.treadmillInclineMaxPercentGrade <= 150.0) {
                            return ["15.0", "11.5", "7.5", "3.5", "0.0"]
                        } else {
                            return ["18.0", "13.5", "9.0", "4.5", "0.0"]
                        }
                    } else {
                        if (machineinfo.treadmillInclineMaxPercentGrade <= 150.0) {
                            return ["15.0", "11.5", "7.5", "3.5", "0.0", "-3.0"]
                        } else {
                            return ["18.0", "13.5", "9.0", "4.5", "0.0", "-3.0"]
                        }
                    }
                } else {
                    return ["600", "350", "200", "120", "40"]
                }
            }
            property variant model: chooseModel()
            x: -71
//            y: 40
            width: 77
            anchors.top: profileWidget1.top
//            anchors.topMargin: workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL ? 200 : 40
            anchors.topMargin: 60
            anchors.bottom: profileWidget1.bottom ; //anchors.bottomMargin: profileWidget1.yPosition
            anchors.bottomMargin: profileWidget1.hasNegativeValues ? -50 : profileWidget1.baseOffset
            anchors.right: profile1Tab.left ; anchors.rightMargin: -5
            spacing: height / model.length

            Repeater {
                model: profile1HatchMarks.model
                delegate: hatchMarkComponent
            }
        }

        Text {
            id: hatchMark2Title

            visible: profile2HatchMarks.visible
            anchors { top: profile2HatchMarks.top; topMargin: -12; right: profile2HatchMarks.left }
            text: root.profile2Units
            color: "black"
            horizontalAlignment: Text.AlignRight
            font.pointSize: 14
            font.bold: true
        }

        Column {
            id: profile2HatchMarks
            function chooseModel() {
                if (workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL) {
                    if (machineinfo.treadmillSpeedMaxMph <= 120) {
                        return options.metricUnits ?  ["19.3", "16.5", "11.0", "6.0", "0.8"] : ["12.0", "9.0", "6.0", "3.0", "0.5"]
                    } else {
                        return options.metricUnits ? ["24.1", "20.5", "14.0", "7.5", "0.8"] : ["15.0", "11.5", "8.0", "4.5", "0.5"]
                    }
                } else {
                    return ["115", "100", "85", "70", "50"]
                }
            }
            property variant model: chooseModel()
            x: -71
            y: 40
            width: 77
            anchors.top: profileWidget2.top
            anchors.topMargin: 60
            anchors.bottom: profileWidget2.bottom
            anchors.bottomMargin: profileWidget2.baseOffset
            anchors.right: profile2Tab.left ; anchors.rightMargin: -5
            spacing: height / model.length

            Repeater {
                model: profile2HatchMarks.model
                delegate: hatchMarkComponent
            }
        }

        Text {
            id: segmentsTitleLabel
            anchors.right: profile1Tab.left
            anchors.bottom: profile1Tab.bottom ; anchors.bottomMargin: -35
            text: qsTr("SEGMENTS") + application.emptyString
            color: "black"
            horizontalAlignment: Text.AlignRight
            font.pointSize: 12
            font.bold: true
        }
    }

    Text {
        id: pressEnterText
        visible: main.isTft && (root.profile2Visible || navIndex >= 0)
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#000000"
        text: (navIndex === -1 ? qsTr("press ENTER to change tab") : qsTr("press ENTER to select")) + application.emptyString
        anchors {
            bottom: parent.bottom
            bottomMargin: 70
            horizontalCenter: parent.horizontalCenter
        }
    }
    Text {
        id: bottomHelpText
        visible: main.isTft
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("step 2 of 3") + application.emptyString
        anchors {
            bottom: parent.bottom
            bottomMargin: 25
            horizontalCenter: parent.horizontalCenter
        }
    }

    states: [
        State {
            name: "Profile2"
            PropertyChanges {target: profile2Tab; z: 2}
            PropertyChanges {target: profile1Tab; z: 1}
            PropertyChanges {target: profile2Tab; state: "ACTIVE"}
            PropertyChanges {target: profile1Tab; state: "INACTIVE"}
            PropertyChanges {target: profile1HatchMarks; visible: false}
            PropertyChanges {target: profile2HatchMarks; visible: true}
        },
        State {
            name: "Profile1"
            PropertyChanges {target: profile2Tab; z: 1}
            PropertyChanges {target: profile1Tab; z: 2}
            PropertyChanges {target: profile2Tab; state: "INACTIVE"}
            PropertyChanges {target: profile1Tab; state: "ACTIVE"}
            PropertyChanges {target: profile1HatchMarks; visible: true}
            PropertyChanges {target: profile2HatchMarks; visible: false}
        }
    ]
}
