import QtQuick 2.4
import WorkoutManager 1.0
import "string_format.js" as Format
import Components 1.0

Item {
    id: root

    property string profile1Title
    property string profile2Title
    property int setupAge
    property int setupWeight
    property int totalTime
    property int numSegments
    property int segmentTime
    property int profile1Max
    property int profile2Max
    property int distanceFromTop: 172
    property int distanceFromRight: 1140
    property string profile1MaxComputed
    property string profile2MaxComputed

    function computeValueOfMax1(value) {
        var incline = workoutProgram.inclineTable[value - 1]/10.0
        return incline.toFixed(1)
    }

    function computeValueOfMax2(value) {
        var speed = workoutProgram.speedTable[value - 1]/10.0
        return speed.toFixed(1)
    }

    Image {
        id: summaryBackground
        x: root.distanceFromRight
        y: root.distanceFromTop
        source: "graphics/setup/Workout_Summary_Bluebox.png"
    }

    Text {
        id: step3AgeText
        anchors.top: summaryBackground.top
        anchors.topMargin: 30
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: setupAge
        font.pointSize: 24
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: step3AgePromptText
        anchors.left: summaryBackground.left
        anchors.leftMargin: -350
        anchors.verticalCenter: step3AgeText.verticalCenter
        text: qsTr("AGE") + application.emptyString
        font.pointSize: 16
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Rectangle {
        id: segementTextDivider1
        anchors.right: summaryBackground.right
        anchors.rightMargin: 5
        anchors.top: step3AgePromptText.top
        anchors.topMargin: 40
        width: 537
        height: 3
        color: "black"
    }

    Text {
        id: step3WeightText
        anchors.top: summaryBackground.top
        anchors.topMargin: 90
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: setupWeight
        font.pointSize: 24
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: step3WeightPromptText
        anchors.left: step3AgePromptText.left
        anchors.verticalCenter: step3WeightText.verticalCenter
        text: qsTr("WEIGHT") + application.emptyString
        font.pointSize: 16
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Rectangle {
        id: segementTextDivider2
        anchors.right: summaryBackground.right
        anchors.rightMargin: 5
        anchors.top: step3WeightPromptText.top
        anchors.topMargin: 40
        width: 537
        height: 3
        color: "black"
    }

    Text {
        id: step3TimeText
        anchors.top: summaryBackground.top
        anchors.topMargin: 150
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: Format.formatTimeString(totalTime * 60);
        font.pointSize: 24
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: step3TimePromptText
        anchors.left: step3AgePromptText.left
        anchors.verticalCenter: step3TimeText.verticalCenter
        text: qsTr("WORKOUT TIME") + application.emptyString
        font.pointSize: 16
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: step3NumSegsText
        anchors.top: summaryBackground.top
        anchors.topMargin: 190
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: numSegments
        font.pointSize: 24
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: step3NumSegsPromptText
        anchors.left: step3AgePromptText.left
        anchors.verticalCenter: step3NumSegsText.verticalCenter
        text: qsTr("NUMBER OF SEGMENTS") + application.emptyString
        font.pointSize: 16
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: step3SegTimeText
        anchors.top: summaryBackground.top
        anchors.topMargin: 230
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: Format.formatTimeString(segmentTime);
        font.pointSize: 24
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: step3SegTimePromptText
        anchors.left: step3AgePromptText.left
        anchors.verticalCenter: step3SegTimeText.verticalCenter
        text: qsTr("SEGMENT TIME") + application.emptyString
        font.pointSize: 16
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Rectangle {
        id: segementTextDivider3
        anchors.right: summaryBackground.right
        anchors.rightMargin: 5
        anchors.top: step3SegTimePromptText.top
        anchors.topMargin: 40
        width: 537
        height: 3
        color: "black"
    }

    Text {
        id: profile2MaxText
        anchors.top: summaryBackground.top
        anchors.topMargin: 290
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: {
            if (workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL) {
                var maxVal = computeValueOfMax2(profile2Max)
                return options.metricUnits ? Globals.mileToKm(maxVal).toFixed(1) : maxVal
            } else {
                return profile2Max
            }
        }
        font.pointSize: 24
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: profile2MaxLabel
        anchors.left: step3AgePromptText.left
        anchors.verticalCenter: profile2MaxText.verticalCenter
        text: qsTr("MAX") + " " + root.profile2Title + application.emptyString
        font.pointSize: 16
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Rectangle {
        id: segementTextDivider4
        anchors.right: summaryBackground.right
        anchors.rightMargin: 5
        anchors.top: profile2MaxLabel.top
        anchors.topMargin: 40
        width: 537
        height: 3
        color: "black"
    }

    Text {
        id: profile1MaxText
        anchors.top: summaryBackground.top
        anchors.topMargin: 350
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL ? computeValueOfMax1(profile1Max) : profile1Max
        font.pointSize: 24
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }

    Text {
        id: profile1MaxLabel
        anchors.left: step3AgePromptText.left
        anchors.verticalCenter: profile1MaxText.verticalCenter
        text: qsTr("MAX") + " " + root.profile1Title + application.emptyString
        font.pointSize: 16
        font.bold: true
        smooth: true
        color: "black"
        z: 2
    }
}
