import QtQuick 2.4
import Components 1.0

ModalDialog {
    id: root

    property real oldStride
    property real newStride
    property bool banner: false

    function show() {
        if(!banner) {
            main._dialogShowing = true
            dialogManager.alertShown(root)
        }
        visible = true
    }

    function hide() {
        root.stopTimer()
        visible = false
        main._dialogShowing = false
        dialogManager.alertHidden(root)
    }

    state: banner ?  "banner" : "dialog"

    states: [
        State {
            name: "dialog"
            AnchorChanges {
                target: root
                anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: parent.verticalCenter }
            }
            PropertyChanges { target: root ; width: dialogBorder.width ; height: dialogBorder.height }
            PropertyChanges { target: bannerBackground ; visible: false }
            PropertyChanges { target: dialogBorder ; visible: true }
            PropertyChanges { target: strideChangeValue ; font.pixelSize: 64 }
            PropertyChanges { target: strideChangeIndicator ; anchors.verticalCenterOffset: 50 ; anchors.leftMargin: 50 ; arrowScale: 1.0 }
            ParentChange { target: strideChangeIndicator ; parent: dialogBorder }
            ParentChange { target: strideChangeText ; parent: dialogBorder }
            AnchorChanges {
                target: strideChangeText
                anchors { top: parent.top ;  verticalCenter: undefined }
            }
            AnchorChanges {
                target: strideChangeRangeText
                anchors { top: parent.top; verticalCenter: undefined }
            }
            PropertyChanges { target: strideChangeRangeText; anchors.topMargin: 100 }

        },
        State {
            name: "banner"
            AnchorChanges {
                target: root
                anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: undefined }
            }
            PropertyChanges { target: root ; width: bannerBackground.width ; height: bannerBackground.height ; y:0 }
            PropertyChanges { target: bannerBackground ; visible: true }
            PropertyChanges { target: dialogBorder ; visible: false }
            PropertyChanges { target: strideChangeValue ; font.pixelSize: 33; anchors.verticalCenterOffset: 0 }

            PropertyChanges { target: strideChangeIndicator ; anchors.verticalCenterOffset: 0 ; anchors.leftMargin: 30 ; arrowScale: 0.7}
            ParentChange { target: strideChangeIndicator ; parent: bannerBackground }
            ParentChange { target: strideChangeText ; parent: bannerBackground }
            PropertyChanges { target: strideChangeRangeText; visible: false }
            AnchorChanges {
                target: strideChangeIndicator
                anchors { right: parent.right; horizontalCenter: undefined }
            }
            AnchorChanges {
                target: strideChangeText
                anchors { top: undefined; verticalCenter: parent.verticalCenter
                          left: parent.left; horizontalCenter: undefined
                }
            }
            PropertyChanges { target: strideChangeText; anchors.topMargin: 10; anchors.leftMargin: 10 }
            PropertyChanges { target: strideChangeRangeText; anchors.topMargin: 10 }
            PropertyChanges { target: strideChangeIndicator; anchors.topMargin: 10; anchors.rightMargin: 75 }
        }

    ]

    BorderImage {   // pop-up dialog background
        id: dialogBorder

        visible: !root.banner
        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        width: 800
        height: 350
        source: "graphics/Pop_Up_Lrg_Grey.png"
        border { top: 152; bottom: 165; left: 145; right: 144 }

    }

    // Stride change banner
    BorderImage {   // pop-up dialog background
        id: bannerBackground

        visible: root.banner
        width: 931
        height: 86

        source: "graphics/Pop_Up_Narrow_Grey.png"
        border { top: 10; bottom: 10; left: 10; right: 10}
    }

    Text {
        id: strideChangeText

        color: "#ffffff"
        text: qsTr("STRIDE LENGTH") + application.emptyString
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.topMargin: 35
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.WordWrap
        width: implicitWidth
        font.bold: true
        font.pixelSize: 64
    }
    Text {
        id: strideChangeRangeText

        color: "#ffffff"
        text: options.metricUnits ? "(33-76)" : "(13-30)"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: 100
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.WordWrap
        font.pixelSize: 60
    }

    Row {
        id: strideChangeIndicator

        property real arrowScale: 1.0

        spacing: 75
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter

        Text {
            id: strideChangeValue

            color: "#ffffff"

            text: options.metricUnits ? Math.round(Globals.inchToCm(newStride)) : newStride
            font.bold: true
            font.pointSize: 72
            scale: 140.0/72.0 // max font size is 72, so scale up

            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 20
        }
    }
}
