// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4

Item {
    id: root
    width: 1000
    height: 450
    property bool selected: state == "ACTIVE"
    property string activeTabImageSciFile: ""
    property string inactiveTabImageSciFile: ""
    property string backgroundImageSciFile: ""

    property string label: ""
    property string labelColor: "black"

    property int tabHeight: 40
    property int tabWidth: 260

    property int panelSideMargin: 6
    property int tabOffset: 150
    property int tabSpacing: 10
    property int borderPixelSize: 4
    property string contentAreaColor: "transparent"
    property int tabXOffset: index == 0 ? tabOffset : tabOffset + (tabWidth + tabSpacing) * index

    property int index

    state: "INACTIVE"

    signal tabSelected()

    Item{
        id:tab

        //state: "ACTIVE"

        anchors.top: root.top
        height: tabHeight
        width: tabWidth
        anchors.left: panel.left
        anchors.leftMargin: root.tabXOffset

        z: (root.state == "ACTIVE") ? panel.z + 1 : panel.z - 1

        BorderImage{
            id: tabImageBackground
            source:
            {
                if(root.state == "ACTIVE")
                    return activeTabImageSciFile
                else
                    return inactiveTabImageSciFile
            }
            height: parent.height
            width: parent.width

            MouseArea{
                anchors.fill: parent

                onClicked: {
                    if(root.state == "INACTIVE")
                    {
                        root.state="ACTIVE"
                        tabSelected()
                        buzzer.buttonPress()

                    }
                }
            }
        }

        Item{
            id:tabLabelContainer
            height: parent.height * 0.65
            anchors.left: parent.left
            anchors.leftMargin: parent.width * 0.075
            anchors.right: parent.right

            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 0

            Text{
                color: root.labelColor
                anchors.verticalCenter: parent.verticalCenter
                text: root.label
                font.bold: true
            }
        }
        states:[
            State{
                name:"ACTIVE"
                PropertyChanges{target:tabImageBackground; source: activeTabImageSciFile}
                PropertyChanges{target: tab; z: panel.z + 1 }
            },
            State{
                name:"INACTIVE"
                PropertyChanges{target:tabImageBackground; source: inactiveTabImageSciFile}
                PropertyChanges{target: tab; z: panel.z - 1 }
            }
        ]
    }

    Item{
        id: panel
        anchors.bottom: root.bottom
        anchors.left: root.left
        anchors.leftMargin: root.panelSideMargin
        anchors.right: root.right
        anchors.rightMargin: root.panelSideMargin
        anchors.top: tab.bottom
        anchors.topMargin: borderPixelSize * -1

        z: 0

        BorderImage {
            id: panelBackground
            source: backgroundImageSciFile
            height: parent.height
            width:parent.width
        }

        Rectangle{
            id: panelContentArea
            color: contentAreaColor
            anchors.fill: parent
            anchors.margins: borderPixelSize
            opacity: 0.3
        }
    }
}

