import QtQuick 2.4
import Components 1.0

import "views.js" as TheViews

FocusScope{

    id: root

    property variant workoutScreen
    property alias contentAreaHeight: contentArea.height
    property alias contentAreaWidth: contentArea.width

    property variant viewGroup
    property string defaultView: "SIMPLE_VIEW"

    property string currentViewName: ""

    //property alias isMoving: contentArea.moving
    property bool isMoving: contentArea.moving || _clickedButtonMoving

    property int _clickedButtonIndex
    property bool _clickedButtonMoving: false
    property int _oldIndex: -1
    property int _viewCreationIndex: 0
    property int _creating: viewCreateTimer.running

    width: 1045
    height: 552
    anchors.horizontalCenter: parent.horizontalCenter
    anchors.verticalCenter: parent.verticalCenter
    anchors.verticalCenterOffset: 40

    z: 99

    // Handle key events for swiping between views
    focus: true
    Keys.onRightPressed: {
        if (currentViewName === "WEB_VIEW" || currentViewName === "ENTERTAINMENT_VIEW")
            return
        if(root.opacity <= 0)
            return
        contentAreaTransitionTimer.start()
        _clickedButtonMoving = true
        contentArea.decrementCurrentIndex()
    }

    Keys.onLeftPressed: {
        if (currentViewName === "WEB_VIEW" || currentViewName === "ENTERTAINMENT_VIEW")
            return
        if(root.opacity <= 0)
            return
        contentAreaTransitionTimer.start()
        _clickedButtonMoving = true
        contentArea.incrementCurrentIndex()
    }

    signal currentViewChanged(string view, bool isRunState)
    signal viewsCompleted()
    signal viewsDeinit()

    //onViewGroupChanged: setViews(viewGroup)

    function setDefaultView(viewname)
    {
        var i;
        for(i = 0; i < viewListModel.count; i++) {
            var thing = viewListModel.get(i).thebuttons.name

            if(thing === viewname){
                contentArea.highlightMoveDuration = 1;
                contentArea.currentIndex = i;
                buttonBar.currentIndex = i;
                _oldIndex = i // set to allow calling hidden() method for this view when changed
                contentArea.highlightMoveDuration = 1000;
                // call the shown() method for new view, if defined
                var obj = contentArea.currentItem.loadedItem
                if(obj && obj.hasOwnProperty("shown")) {
                    obj.shown()
                }
                break;
            }
        }
    }

    function destroyViews() {
        for(var i=1 ; i <= viewListModel.count; i++) {
            var item = viewListModel.get(i)
            var obj = contentArea.children[i].children[0]
            if( obj ) {
                console.log("Destroying", obj)
                if (obj.hasOwnProperty("viewdestruct")) {
                    obj.viewdestruct()
                }

                obj.destroy()
                delete obj
            }

        }
        viewListModel.clear()
        root._oldIndex = -1
    }

    function setViews(viewgroup)
    {
        var i

        // signal to the views that they are about to be destroyed
        root.viewsDeinit()

        destroyViews()
        root.viewGroup = viewgroup

        // Create a dummy set of all views with only the button, EXCEPT the default view
        // This allows us to create the default view before the others
        for (var i = 0; i < viewgroup.views.length; i++) {
            var qml = root.viewGroup.views[i].theqml
            var button = root.viewGroup.views[i].thebuttons
            if (button.name === root.defaultView) {
                viewListModel.append({"theqml": qml, "thebuttons": button})
            } else {
                viewListModel.append({"theqml": "", "thebuttons": button})
            }
        }

        // begin the creation of views on at a time in a timer, to avoid blocking for a long period of time
        root._viewCreationIndex = 0
        viewCreateTimer.start()
    }

    // create and display a single view from the viewGroup model
    function createView(index) {
        var qml = root.viewGroup.views[index].theqml
        var button = root.viewGroup.views[index].thebuttons
        viewListModel.setProperty(index, "theqml", qml)
    }

    function findViewIndex(viewName) {
        for (var i = 0; i < viewListModel.count; i++) {
            if (viewListModel.get(i).thebuttons.name === viewName)
                return i
        }
        return -1
    }

    // viewCreateTimer loads one qml view from the viewGrop upon each timer expiration, until reaching end of array
    Timer {
        id: viewCreateTimer

        interval: 1
        repeat: true
        onTriggered: {
          createView(root._viewCreationIndex++)
          if( root._viewCreationIndex >= viewGroup.views.length) {
            stop()
            root.viewsCompleted() // signal that the views have been constructed
          }
        }
    }

    Timer{
        id: contentAreaTransitionTimer
        interval: contentArea.highlightMoveDuration
        running: false
        repeat: false

        onTriggered:
        {
            contentAreaTransitionTimer.stop()
            _clickedButtonMoving  = false
        }
    }

    Image {
        id: workoutViewContainerBackground
        anchors.fill: parent
        source: "graphics/netpulse/Center_Gray_Box.png"
    }

    Connections {
        target: keymapper
        onChangeDisplayPressed: {
            if (main.state === "RunState") {
                contentArea.incrementCurrentIndex();
            }
        }
    }

    Connections {
        target: root.opacity > 0 && !tv.player.fullscreen ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "ViewContainer")
            contentAreaTransitionTimer.start()
            _clickedButtonMoving = true
            contentArea.decrementCurrentIndex()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "ViewContainer")
            console.log("right pressed!")
            contentAreaTransitionTimer.start()
            _clickedButtonMoving = true
            contentArea.incrementCurrentIndex()
        }

    }

    Connections {
        target: !main.blockKeys && root.opacity > 0 ? keymapper : null

        onTvPressed: {
            main.debugKeys("tvPressed", "ViewContainer")

            if (currentViewName === "TV_VIEW") {
                return
            }

            var viewIndex = root.findViewIndex('TV_VIEW')
            if (viewIndex >= 0) {
                contentAreaTransitionTimer.start()
                _clickedButtonMoving = true
                contentArea.currentIndex = viewIndex
            }
        }
    }

    onCurrentViewNameChanged: {
        if (main.isTft) {
            // Re-request primary audio source when landing on an inactive square
            if (currentViewName !== "TV_VIEW" && currentViewName !== "IPOD_VIEW") {
                if (audioManager.ipodPlaying) {
                    audioManager.ipodRequest()
                } else if (audioManager.ipodPlayingVideo) {
                    audioManager.ipodVideoRequest()
                } else if (audioManager.btconnected) {
                    audioManager.btRequest()
                } else if (audioManager.tvPlaying) {
                    audioManager.tvRequest()
                }
            }
        }
    }

    Rectangle{
        color: "grey"
        anchors.fill: buttonBar
        anchors.topMargin: -buttonBar.spacing
        anchors.bottomMargin: -buttonBar.spacing
        anchors.leftMargin: -buttonBar.spacing
        anchors.rightMargin: -buttonBar.spacing + (buttonBar.spacing * 2)
    }
    ListView{
        id: buttonBar

        property int buttonWidth:0

        width: (buttonWidth) * count + (spacing * (count - 1)) + spacing * 2
        height: 0
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 35
        anchors.horizontalCenter: parent.horizontalCenter
        model:viewListModel
        delegate: buttonBarDelegate
        orientation: ListView.Horizontal
        interactive: false
        spacing: 4

    }

    Component{
        id: buttonBarDelegate

        ImageButton{
            id:button

            upimage: button.ListView.isCurrentItem ? thebuttons.button_down_image:thebuttons.button_up_image
            downimage: button.ListView.isCurrentItem ? thebuttons.button_down_image:thebuttons.button_up_image
            icon:thebuttons.icon_image

            label: thebuttons.button_label
            label_color: "#808184"
            fontsize: 15
            onClicked: {
                if(index == buttonBar.currentIndex)
                    return
                contentAreaTransitionTimer.start()
                _clickedButtonMoving = true
                _clickedButtonIndex = index
                buttonBar.currentIndex = _clickedButtonIndex
                contentArea.currentIndex = _clickedButtonIndex

            }
            Component.onCompleted:
            {
                buttonBar.height = button.height
                buttonBar.buttonWidth = button.width
            }
        }
    }


    ListModel{
        id: viewListModel
    }

    Component {
        id:viewDelegate
        Item {
            id: wrapper
            width:childrenRect.width
            height: childrenRect.height
            property alias loadedItem: loader.item
            Loader {
                id: loader
                source: theqml
                onStatusChanged: {
                    if (loader.status === Loader.Ready) {
                        // If this is the default view, scroll to it
                        if (thebuttons.name === root.defaultView) {
                            contentArea.highlightMoveDuration = 0
                            contentArea.currentIndex = index
                            buttonBar.currentIndex = index
                            _oldIndex = index // set to allow calling hidden() method for this view when changed
                            contentArea.highlightMoveDuration = 1000
                            // call the shown() method for new view, if defined
                            if(item && item.hasOwnProperty("shown")) {
                                item.shown()
                            }
                        }

                    }
                }
            }
        }
    }
    // call the hidden() method for current view when the opacity of the viewContainer is less than 1
    onOpacityChanged: {
        if(opacity == 0){
            if (!contentArea.model)
                return
            var item = contentArea.model.get(contentArea.currentIndex)
            var obj
            if(item)
                obj = contentArea.currentItem.loadedItem
            if(obj && obj.hasOwnProperty("hidden")) {
                obj.hidden()
            }
        }
    }

    onIsMovingChanged: {
        if(!isMoving) {
            var view_name = contentArea.model.get(contentArea.currentIndex).thebuttons.name
            root.currentViewChanged(view_name, (main.state == "RunState") )
            root.currentViewName = view_name

            // call the shown() method for new view, if defined
            var obj = contentArea.currentItem.loadedItem
            if(obj && obj.hasOwnProperty("shown")) {
                obj.shown()
            }
            if(obj && obj.hasOwnProperty("noSwipe") && obj.noSwipe)
                contentArea.interactive = false
            else
                contentArea.interactive = true
        }
        else {
            root.currentViewChanged("", (main.state == "RunState") )
        }
    }

    PathView{
        id: contentArea
        width: 1000
        height: 406
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 123
        anchors.horizontalCenter: parent.horizontalCenter
        model:viewListModel
        delegate: viewDelegate
        highlightRangeMode: PathView.StrictlyEnforceRange
        highlightMoveDuration: 1000
        clip: true

        onCurrentIndexChanged: {

            if(model.count < 1)
                return
            var view_name = model.get(currentIndex).thebuttons.name
            buttonBar.currentIndex = currentIndex
            root.currentViewName = view_name
            print("View changed: " + view_name)
            // call the hiden() method for old view, if defined
            if(root._oldIndex >=0 && root._oldIndex < model.count) {
                var oldobj = contentArea.children[root._oldIndex + 1].loadedItem
                if(oldobj && oldobj.hasOwnProperty("hidden"))
                    oldobj.hidden()
            }

            root._oldIndex = currentIndex

        }

        preferredHighlightBegin: 0.5
        preferredHighlightEnd: 0.5
        path: Path {
            startX: contentArea.width * (1 - contentArea.model.count) / 2
            startY: contentArea.height / 2
            PathLine {
                x: contentArea.width * (1 + contentArea.model.count) / 2
                y: contentArea.height / 2
            }
        }
    }
}
