// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import Process 0.1
import Components 1.0

Item {
    id: root

    property int volume: vol_setting
    property int percent: 100 * (volume / (vol_max - vol_min))
    property int vol_setting: 5

    property int vol_max: 20
    property int vol_min: 0
    property alias muted: mute_button.isDown

    property string muteButtonDownimage: "graphics/224/224_Data_ToolBar_Round_Down.png"
    property string muteButtonUpimage: "graphics/224/224_Data_ToolBar_Round.png"
    property bool showSourceButton: false
    property string sourceIcon: ""
    property bool showHeadsetButton: true

    signal sourceButtonClicked()
    signal bluetoothHeadsetButtonClicked()

    width: 104
    height: childrenRect.height

    Component.onCompleted: paVolControl.setVolume(root.vol_setting)

    Connections{
        target: bluetoothAdapter
        onConnectedHeadsetChanged: {
            if(bluetoothAdapter.connectedHeadset){
                if(muted)
                    paVolControl.setVolume(0)
                else
                    paVolControl.setVolume(vol_setting)
            }
        }
    }

    onVol_settingChanged: {
        console.log("vol>>", vol_setting)
        paVolControl.setVolume(vol_setting)
    }

    onMutedChanged: {
        if(muted){
            paVolControl.setVolume(vol_min)
        } else {
            paVolControl.setVolume(vol_setting)
        }
    }

    Process {
        id: paVolControl
        program: "scripts/true-pa-volume-control.sh"
        property bool isMute

        function setVolume(vol_setting){
            var vol = (6554 * vol_setting) + 6550
            var volStr = vol.toString();
            paVolControl.arguments = ["vol", volStr]
            paVolControl.start()
        }

        function mute() {
            paVolControl.arguments = ["mute"]
            paVolControl.start()
        }

        function info() {
            paVolControl.arguments = ["info"]
            paVolControl.start()
        }

        function parseOutput(str){
            var strList = str.split(" ")
            if(strList[0] === "info"){
                var volumeInt = parseInt(strList[2])
                var isMuteStr = strList[3]

                if(isMuteStr === "yes") {
                    isMute = true
                } else if(isMuteStr === "no") {
                    isMute = false
                }

                console.debug(volumeInt + " " + isMuteStr)
            }
        }

        onReadyReadStandardOutput: {
            var data = String(readAllStandardOutput()).trim()
            console.log("output from paVolControl:",data)
            parseOutput(data)
        }
    }

    function volumeUp() {
        if(mute_button.isDown){
            mute_button.isDown = false
        }
        else{
            if(root.volume < root.vol_max)
                root.vol_setting++
        }
    }

    function volumeDown() {
        if(mute_button.isDown)
            mute_button.isDown = false
        else{
            if(root.volume > root.vol_min)
                root.vol_setting--
        }
    }

    ImageButton {
        id: volume_up_button

        repeat: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        icon: "graphics/netpulse/PLUS_icon_BLACK.png"
        upimage: "graphics/netpulse/UpArrow_gray.png"
        downimage: "graphics/netpulse/UpArrow_PRESSED.png"
        onClicked: {
            volumeUp();
        }
        mouseAreaScale: 1.25
    }

    // volume numeric display
    Text {
        id: volume_value


        text: root.volume
        font.bold: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: volume_up_button.bottom
        anchors.topMargin: 0
        font.pixelSize: 30
    }

    ImageButton {
        id: volume_down_button

        repeat: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: volume_value.bottom
        upimage: "graphics/netpulse/DownArrow_gray.png"
        downimage: "graphics/netpulse/DownArrow_PRESSED.png"
        icon: "graphics/netpulse/MINUS_icon_BLACK.png"
        icon_y_offset: -5

        onClicked: {
          volumeDown();
        }
        mouseAreaScale: 1.25
    }
    Text {
        id: volume_text
        text: qsTr("VOLUME") + application.emptyString
        font.bold: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: volume_down_button.bottom
        font.pixelSize: 14
    }
    ImageButton {
        id: mute_button
        property int y_offset: 0
        property int x_offset: 0

        anchors.top: volume_text.bottom
        anchors.topMargin: 15
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: x_offset
        downimage: muteButtonDownimage
        upimage: muteButtonUpimage
        icon: "graphics/Media_Mute_Up.png"
        icon_x_offset: -x_offset
        icon_y_offset: -y_offset
        toggle: true
        mouseAreaScale: 1.25
    }

    ImageButton {
        id: btHeadset_button
        property int y_offset: 0
        property int x_offset: 0

        visible: !bluetoothAdapter.connected && root.showHeadsetButton
        anchors.top: mute_button.bottom
        anchors.topMargin: 15
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: x_offset
        downimage: muteButtonDownimage
        upimage: muteButtonUpimage
        icon: "graphics/Bluetooth/Bluetooth_EAR-BTicon.png"
        icon_x_offset: -x_offset
        icon_y_offset: -y_offset
        toggle: false
        mouseAreaScale: 1.25
        enabled: !bluetoothAdapter.connected &&
                 !bluetoothAdapter.discovering &&
                 !bluetoothAdapter.pairing &&
                 !bluetoothLEAdapter.scanning &&
                 !bluetoothLEAdapter.connecting &&
                 !bluetoothAdapter.temporarilyDisconnected
        onClicked:{
                root.bluetoothHeadsetButtonClicked()
        }

        Image{
            visible: bluetoothAdapter.connectedHeadset
            source: "graphics/Bluetooth/small_red_X.png"
            width: 18
            height: 17
            x: 8
            y: 10
            fillMode: "PreserveAspectFit"
            smooth: true
        }
    }

    ImageButton {
        id: source_button
        anchors.top: btHeadset_button.visible ? btHeadset_button.bottom : mute_button.bottom
        anchors.topMargin: 15
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 0
        downimage: muteButtonDownimage
        upimage: muteButtonUpimage
        icon: root.sourceIcon
        onClicked: {
            root.sourceButtonClicked()
        }

        reenableDelay: 200
        mouseAreaScale: 1.25
        visible: root.showSourceButton
    }

    Text {
        id: change_source_text
        text: qsTr("CHANGE AUDIO") + application.emptyString
        font.bold: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: source_button.bottom
        font.pixelSize: 12
        visible: source_button.visible
    }

}
