import QtQuick 2.4
import Components 1.0

Image {
    id: root
    width: 1366
    height: 768
    source: "graphics/Background.png"

    function warningTextCol1(treadmill) {

        var generalWarnings = "<ul>" + "<li>" +
        qsTr("Read and understand all the instructions and warnings prior to use.") + "</li><p>" +
        "<li>" + qsTr("Obtain proper instruction prior to use.") + "</li><p>" +
        "<li>" +qsTr("Obtain a medical exam before beginning any exercise program.  If at any time during exercise you feel faint, dizzy, or experience pain, " +
            "stop and consult your physician.") + "</li><p>" +
        "<li>" +qsTr("Keep children away.") + "</li><p>" +
        "<li>" +qsTr("Do not wear loose or dangling clothing while using the machine.") + "</li><p>" +
        "<li>" +qsTr("Care should be used when mounting or dismounting the machine.") + "</li><p>" +
        "</ul>" + application.emptyString

        return generalWarnings
    }

    function warningTextCol2(treadmill) {
        var treadWarnings = "<li>" + qsTr("Read, understand and test the emergency stop procedures before use.") +
                            "<b> " + qsTr("ALWAYS ATTACH THE EMERGENCY STOP SAFETY CLIP TO CLOTHING PRIOR TO USE!") + "</b></li><p>" +
                            "<li>" + qsTr("Prior to use, inspect safety clip cord to ensure it is free of tangles or knots, " +
                                "and that red magnetic key will easiliy disengage from machine.") + "</li><p>" + application.emptyString

        var generalWarnings = "<ul>" + (treadmill ? treadWarnings : "") +
        "<li>" + qsTr("Inspect the machine for incorrect, worn, or loose components and do not use until corrected, " +
            "replaced, or tightened prior to use.") + "</li><p>" +
        "<li>" + qsTr("Disconnect all power before servicing the machine.") + "</li><p>" +
        "<li>" + qsTr("Do not operate electrically powered machines in damp or wet locations.") + "</li><p>" +
        "<li>" + qsTr("All exercise equipment is potentially hazardous.  If attention is not paid to the conditions " +
            "of the equipment usage, death or serious injury could occur.") + "</li><p>" +
        "</ul>" + application.emptyString

        return generalWarnings
    }

    // mask any underlying mouse areas
    MouseArea {
        anchors.fill: parent
    }

    // back button
    Row {
        id: row1
        x: 1183
        y: 16
        anchors.top: parent.top
        anchors.topMargin: 16
        anchors.right: parent.right
        anchors.rightMargin: 56

        ImageButton {
            id: back_button
            upimage: "graphics/navbar/Navigation_Arrow_Disabled.png"
            downimage: "graphics/navbar/Navigation_Arrow_Down.png"
            onClicked: root.visible = false
            labelClickable: true
            mouseAreaScale: 1.5
            label: qsTr("BACK") + application.emptyString
            font.bold: true
            label_color: "#A0A0A0"
            label_x_offset: 50
        }

    }

    BorderImage { id: border
        anchors.fill: parent
        anchors { leftMargin: 80 ; rightMargin: 50 }
        anchors { topMargin: 80 ; bottomMargin: 50 }

        source: "graphics/Pop_Up_Warning.png"
        border { top: 152; bottom: 165; left: 145; right: 144 }

        Row { id: row_warning_icon
            // column with warning /!\ and info button
            anchors {
                top: parent.top; topMargin: 20
                left: parent.left; leftMargin: main.rightToLeft ? 60 : 30
            }
            spacing: 0
            LayoutMirroring.enabled: main.rightToLeft

            Image {
                sourceSize.height: 59;
                source: "graphics/Icon_Warning.png";
            }

            Text {
                height: 50; text: qsTr("WARNING:") + application.emptyString
                anchors.top: parent.top
                anchors.topMargin: 12
                font.pixelSize: 35; font.bold: true
            }
        }

        Row { id: row
            anchors.fill: parent
            anchors.margins: 25
            anchors.topMargin: 100
            property int contentWidth: width - anchors.leftMargin - anchors.rightMargin
            spacing: 20
            LayoutMirroring.enabled: main.rightToLeft
            LayoutMirroring.childrenInherit: true

            Text{ id: col1text
                width: parent.contentWidth / 2
                text: warningTextCol1(machineinfo.productTypeString == "Treadmill") + application.emptyString
                visible: true
                font.family: "Liberation Sans Narrow"
                font.pixelSize: col1text.text.length > 600 || col2text.text.length > 600 ? 20 : 23
                wrapMode: Text.Wrap

                onLinkActivated: console.log("warning click.")
            } // col1Text end

            Text{ id: col2text
                width: parent.contentWidth / 2
                text: warningTextCol2(machineinfo.productTypeString == "Treadmill") + application.emptyString
                visible: true
                font.family: "Liberation Sans Narrow"
                font.pixelSize: col1text.text.length > 600 || col2text.text.length > 600 ? 20 : 23
                wrapMode: Text.Wrap

                onLinkActivated: console.log("warning click.")
            } // col2Text end
        }
    } // end image
}
