import QtQuick 2.4
import Components 1.0

FocusScope {
    id: root

    // menu property is a menu dictionary from workout_menus.js to be displayed in the list
    property variant menu

    signal workoutSelected( variant item, variant menu )
    signal menuSelected( variant menu ) // signal emitted when a sub-menu is selected. menu parameter is a javascript menu dictionary from workout_menus.js

    function changeMenu( menu ) {
        workout_menu_model.changeMenu(menu)
        popsicle.model = undefined
        popsicle.model = workout_menu_model
        browser.reset()
        description_flip_timer.interval = 6000
        description_flip_timer.restart()
    }

    // re-translate the menu strings when the language changes
    Connections {
        target: application
        onLanguageChanged: { workout_menu_model.updateStrings() }
    }

    ProgramBrowser {
        id: browser

        Keys.onLeftPressed: { decrementCurrentIndex() ; description_flip_timer.restartWithDelay() }
        Keys.onRightPressed: { incrementCurrentIndex() ; description_flip_timer.restartWithDelay() }

        opacity: root.opacity
        focus: main.state == "MenuState"

        // wait a full timer period after user flips before flipping again
        onMovingChanged: { console.log("program browser movingChanged; restarting timer"); description_flip_timer.restartWithDelay() }

        model: workout_menu_model
    }

    MenuModel {
        id: workout_menu_model

        onChangeMenuCallback: {
            // remove the SAVED WORKOUTS menu item if the feature is disabled
            if (options.saveWorkoutEnabled === false) {
                var removeIndex = findItemIndex(function(item) { return item.program === "SAVED_WORKOUTS" })
                if (removeIndex >= 0)
                    remove(removeIndex)
            }

        }

        onMenu_currentChanged: {
            root.menu = menu_current // keep top level property in sync with model
            description_flip_timer.interval = 6000
            description_flip_timer.restart()
        }

        Component.onCompleted: {  // set the top level menu at startup
            changeMenu(root.menu)
        }

        // calling selectItem() causes either the menuSelected or optionSelected signals handled below
        onMenuSelected: {  // a sub-menu was selected
            root.menuSelected(workout_menu_model.menu_current)
        }

        // a workout program was selected
        onOptionSelected: {
            if( item.program )  // don't launch if program not implemented
            {
                workoutSelected(item, workout_menu_model.menu_current)
            }
        }

    }
    Connections {
        target: workout_menu_model
        onMenu_currentChanged: {
            popsicle.model = undefined
            popsicle.model = workout_menu_model
            browser.reset()
        }
    }

    PopsicleMenu {  // circular arrangement of workout buttons
        id: popsicle

        property int _indexDestination:0
        property variant model
        property variant _menuCurrent
        property variant _menuDestination

        buttonsEnabled: !menu_switch_animation.running && main.state == "MenuState"

        onModelChanged: {
            _menuDestination = model
            menu_switch_animation.start()
        }

        // press and hold to see the description
        onItemPushed: {
            browser.currentIndex = index
            description_flip_timer.restartWithDelay()
        }
        onItemClicked: {
            workout_menu_model.selectIndex(index)
        }

        menu: _menuCurrent //workout_menu_model
        highlight: browser.currentIndex

        anchors {
            right: parent.right ; rightMargin: 50
            left: parent.left ; leftMargin: 100
            bottom: parent.bottom
            top: parent.top ; topMargin: 120
        }

        ParallelAnimation {
            id: menu_switch_animation

            // rotates the buttons around the X-axis (3D-like effect) then changes the menu when the buttons are fully rotated edge-on
            SequentialAnimation {
                running: false
                //NumberAnimation { target: popsicle; property: "currentIndex"; to: menu.length ; duration: 800; easing.type: Easing.Linear }
                //NumberAnimation { target: popsicle; property: "currentIndex"; to: 0 ; duration: 800; easing.type: Easing.Linear }
                //NumberAnimation { target: popsicle; property: "scale"; to: 0; duration: 200; easing.type: Easing.Linear }
                //NumberAnimation { target: popsicle; property: "scale"; to: 1 ; duration: 200; easing.type: Easing.Linear }
                NumberAnimation { target: popsicle; property: "buttonrot"; to: 90; duration: 300; easing.type: Easing.Linear }
                ScriptAction {
                    script: {
                        //workout_menu_model.selectItem(popsicle._indexDestination)
                        //workout_menu_model.selectItem(popsicle._menuDestination)
                        popsicle._menuCurrent = popsicle._menuDestination
                    }
                }
                NumberAnimation { target: popsicle; property: "buttonrot"; to: -90 ; duration: 0; easing.type: Easing.Linear }
                NumberAnimation { target: popsicle; property: "buttonrot"; to: 0 ; duration: 300; easing.type: Easing.Linear }
            }
            SequentialAnimation {
                //NumberAnimation { target: popsicle; property: "scale"; to: 0; duration: 500; easing.type: Easing.Linear }
                //NumberAnimation { target: popsicle; property: "scale"; to: 1 ; duration: 500; easing.type: Easing.Linear }
            }
        }
    }

    Timer {
        id: description_flip_timer
        function restartWithDelay() {
            interval = 15000
            restart()
        }
        interval: 6000; running: true ; repeat: true
        onTriggered: { browser.incrementCurrentIndex(); interval = 6000 }
    }

}
