import QtQuick 2.4
import QtQuick.LocalStorage 2.0

Item {
    id: root

    function getDatabase() {
        return LocalStorage.openDatabaseSync("Touch", "1.0", "WorkoutStats", 4096 );

    }

    function initialize() {
        var db = getDatabase();
        console.log("get database")
        db.transaction (
                    function(tx) {
                        tx.executeSql('CREATE TABLE IF NOT EXISTS workoutcount(name TEXT UNIQUE, count INT)');
                    }
                    );
    }

    function incrementUsage(name) {
        var db = getDatabase();
        var res = "";
        var count = 0;
        db.transaction(
                    function(tx) {
                        var rs = tx.executeSql('SELECT count FROM workoutcount WHERE name=?;', [name]);

                        if( rs.rows.length > 0) {
                            count = rs.rows.item(0).count;
                        }
                    }
                    )
        count++;
        if (count > 0) {
            db.transaction(
                        function(tx) {
                            var rs = tx.executeSql('INSERT OR REPLACE INTO workoutcount VALUES (?,?);', [name, count]);
                            if(rs.rowsAffected > 0) {
                                res = "OK";
                            } else {
                                res = "Error";
                            }
                        }

                        )
        }
    }

    function getUsage(name) {
        var db = getDatabase();
        var newcount=-1;

        db.transaction(
                    function(tx) {
                        var rs = tx.executeSql('SELECT count FROM workoutcount WHERE name=?;', [name]);
                        if(rs.rows.length > 0) {
                            newcount = rs.rows.item(0).count
                        }
                    }
                    )
        if(newcount > 0)
            return newcount;
        else
            return 0;
    }

    function getUsageAll() {
        var db = getDatabase()
        var rows

        db.readTransaction(
                    function(tx) {
                        var rs = tx.executeSql('SELECT * FROM workoutcount ORDER BY count DESC;')
                        if(rs.rows.length > 0) {
                            rows = rs.rows
                        }
                    }
                    )
        return rows
    }

    function clearAll() {
        var db = getDatabase()
        var rs

        db.transaction(
                    function(tx) {
                        rs = tx.executeSql('DELETE FROM workoutcount')
                    }
                    )
        return rs.rowsAffected
    }

    Component.onCompleted: initialize()
}

