import QtQuick 2.4
import WorkoutRunData 1.0
import WorkoutManager 1.0
import Components 1.0

import "string_format.js" as StrFormat

FocusScope {
    id: root

    property string workoutName: qsTr("WORKOUT") + application.emptyString
    property string workoutElapsed: "00:00"
    property bool warmUpValues: false
    property bool isBikeFitnessTest: false
    property real fitTestScore: 0
    property bool isMilitaryTest: false
    property bool isGerkinTest: false
    property real militaryTestScore: 0
    property int productType: workoutManager.workoutProgram.productType
    property bool isUsbDeviceLoaded: storageMgr.usbDeviceLoaded
    property int timeLeft: 0
    property variant listViewMenu: listViewLoader.item
    property bool saveHasHappened: false
    property int advertiseTimeOout: 60
    property bool dialogVisible: false

    signal close()
    signal save()
    signal advertise()
    signal connected()
    signal disconnect()


    Connections{
        target: root
        onConnected: {
            bleDialog.show()}
        onAdvertise: {
            bleDialog.show()
            ble.startAdvertiseing()
        }
        onDisconnect:{
            console.log("disconnect sig received in WorkouSummary")
            ble.stopAdvertising()
            bleDialog.hide()
        }
    }

    onClose: disconnect()

    function doSave() {
        if(isUsbDeviceLoaded){
            save()
        } else {
            advertise()
            ble.advertising=true
        }
    }

    function convertUnits(speedMiles) {
        return workoutScreen.unitState === "METRIC" ? Globals.mileToKm(speedMiles) : speedMiles
    }

    function setData(workoutData) {

        root.workoutName = qsTranslate("Menu", workoutData.programName)

        clearCol1Model();
        clearCol2Model();
        clearCol3Model();
        clearCol4Model();

        root.isBikeFitnessTest = workoutData.isBikeFitnessTest();
        if (root.isBikeFitnessTest) {
            root.fitTestScore = workoutData.getBikeFitTestScore();
        }

        root.isGerkinTest = workoutData.isGerkinTest();
        if (root.isGerkinTest) {
            root.fitTestScore = workoutData.getGerkinTestScore();
        }

        root.isMilitaryTest = workoutData.isMilitaryTest();
        if (root.isMilitaryTest) {
            if (workoutManager.workoutProgram.programIndex == WorkoutProgram.TREAD_AIR_FORCE_MILITARY_FITNESS_TEST_PROG) {
                root.militaryTestScore = (workoutData.getAirForceScore() / 10.0);
            }
            else if (workoutManager.workoutProgram.programIndex == WorkoutProgram.TREAD_ARMY_MILITARY_FITNESS_TEST_PROG)
            {
                root.militaryTestScore = workoutData.getArmyScore();
            }
            else if (workoutManager.workoutProgram.programIndex == WorkoutProgram.TREAD_MARINES_MILITARY_FITNESS_TEST_PROG)
            {
                root.militaryTestScore = workoutData.getMarinesScore();
            }
            else if (workoutManager.workoutProgram.programIndex == WorkoutProgram.TREAD_NAVY_MILITARY_FITNESS_TEST_PROG)
            {
                root.militaryTestScore = workoutData.getNavyScore();
            }
            else
            {
                root.militaryTestScore = 0;
            }
        }

        if (workoutData.isHRProgram()) {
            addWorkoutSummaryDataToCol1(workoutData.warmUpTime,2); // Elapsed Time
            addWorkoutSummaryDataToCol1(workoutData.warmUpAverageHeartRate || "-",0); // Average Heart Rate
            addWorkoutSummaryDataToCol1(workoutData.maximumWarmUpHeartRate || "-",0); // Max Heart Rate
            if (root.productType == WorkoutProgram.TREADMILL) {
                addWorkoutSummaryDataToCol1(convertUnits(workoutData.warmUpAverageSpeed),1); // Average Speed
                addWorkoutSummaryDataToCol1(convertUnits(workoutData.maximumWarmUpSpeed),1); // Max Speed
            }
            else {
                addWorkoutSummaryDataToCol1(workoutData.warmUpAveragePace,0); // Average Pace
                addWorkoutSummaryDataToCol1(workoutData.maximumWarmUpPace,0); // Max Pace
            }
            addWorkoutSummaryDataToCol1(convertUnits(workoutData.warmUpDistance),2); // Distance
            addWorkoutSummaryDataToCol1(workoutData.warmUpCalories,0); // Calories
        }
        addWorkoutSummaryDataToCol2(workoutData.workoutTime,2); // Elapsed Time
        addWorkoutSummaryDataToCol2(workoutData.averageHeartRate || "-",0); // Average Heart Rate
        addWorkoutSummaryDataToCol2(workoutData.maximumHeartRate || "-",0); // Max Heart Rate
        if (root.productType == WorkoutProgram.TREADMILL) {
            addWorkoutSummaryDataToCol2(convertUnits(workoutData.averageSpeed),1); // Average Speed
            addWorkoutSummaryDataToCol2(convertUnits(workoutData.maximumSpeed),1); // Max Speed
        }
        else {
            addWorkoutSummaryDataToCol2(workoutData.averagePace,0); // Average Pace
            addWorkoutSummaryDataToCol2(workoutData.maximumPace,0); // Max Pace
        }
        if (root.isBikeFitnessTest || root.isGerkinTest || root.isMilitaryTest) {
            addWorkoutSummaryDataToCol2(" ",2); // Blank
            addWorkoutSummaryDataToCol2(" ",2); // Blank
            addWorkoutSummaryDataToCol2(" ",2); // Blank
        }
        else {
            addWorkoutSummaryDataToCol2(convertUnits(workoutData.workoutDistance),2); // Distance
            addWorkoutSummaryDataToCol2(workoutData.workoutCalories,0); // Calories
        }

        addWorkoutSummaryDataToCol3(workoutData.coolDownTime,2); // Elapsed Time
        addWorkoutSummaryDataToCol3(workoutData.coolDownAverageHeartRate || "-",0); // Average Heart Rate
        addWorkoutSummaryDataToCol3(workoutData.maximumCoolDownHeartRate || "-",0); // Max Heart Rate
        if (root.productType == WorkoutProgram.TREADMILL) {
            addWorkoutSummaryDataToCol3(convertUnits(workoutData.coolDownAverageSpeed),1); // Average Speed
            addWorkoutSummaryDataToCol3(convertUnits(workoutData.maximumCoolDownSpeed),1); // Max Speed
        }
        else {
            addWorkoutSummaryDataToCol3(workoutData.coolDownAveragePace,0); // Average Pace
            addWorkoutSummaryDataToCol3(workoutData.maximumCoolDownPace,0); // Max Pace
        }
        if (root.isBikeFitnessTest || root.isGerkinTest || root.isMilitaryTest) {
            addWorkoutSummaryDataToCol3(" ",2); // Blank
            addWorkoutSummaryDataToCol3(" ",2); // Blank
            addWorkoutSummaryDataToCol3(" ",2); // Blank
        }
        else {
            addWorkoutSummaryDataToCol3(convertUnits(workoutData.coolDownDistance),2); // Distance
            addWorkoutSummaryDataToCol3(workoutData.coolDownCalories,0); // Calories
        }

        addWorkoutSummaryDataToCol4(workoutData.totalTime,2); // Elapsed Time
        addWorkoutSummaryDataToCol4(workoutData.totalAverageHeartRate || "-",0); // Average Heart Rate
        addWorkoutSummaryDataToCol4(workoutData.totalMaximumHeartRate || "-",0); // Max Heart Rate
        if (root.productType == WorkoutProgram.TREADMILL) {
            addWorkoutSummaryDataToCol4(convertUnits(workoutData.totalAverageSpeed),1); // Average Speed
            addWorkoutSummaryDataToCol4(convertUnits(workoutData.totalMaximumSpeed),1); // Max Speed
        }
        else {
            addWorkoutSummaryDataToCol4(workoutData.totalAveragePace,0); // Average Pace
            addWorkoutSummaryDataToCol4(workoutData.totalMaximumPace,0); // Max Pace
        }
        if (root.isBikeFitnessTest || root.isGerkinTest) {
            addWorkoutSummaryDataToCol4(workoutData.userProgAge,2); // Age
            addWorkoutSummaryDataToCol4(workoutData.userGender,2); // Gender
            addWorkoutSummaryDataToCol4(workoutData.estVO2,2); // Estimated VO2
        }
        else if (root.isMilitaryTest) {
            if(workoutProgram.userAgeRequired)
                addWorkoutSummaryDataToCol4(workoutData.userProgAge,2); // Age
            else
                addWorkoutSummaryDataToCol4(" ",2); // Blank
            addWorkoutSummaryDataToCol4(workoutData.userGender,2); // Gender
            addWorkoutSummaryDataToCol4(root.militaryTestScore,2); // Military Test Score
        }
        else {
            addWorkoutSummaryDataToCol4(convertUnits(workoutData.totalDistance),2); // Distance
            addWorkoutSummaryDataToCol4(workoutData.totalCalories,0); // Calories
        }

        // prepare data for bluetooth advertisement
        root.workoutElapsed=workoutData.totalTime
    }

    function addWorkoutSummaryDataToCol1 (value,precision) {
        var newValue = "";
        if (col1Model.count == 0) {
            newValue = StrFormat.formatTimeString(value)
        } else if (value === "-") {
            newValue = "-"
        } else {
            newValue = parseFloat(value).toFixed(precision)
        }

        col1Model.append({"label": ""+newValue});
        root.warmUpValues = true;
    }

    function clearCol1Model() {
        col1Model.clear();
        root.warmUpValues = false;
    }

    function addWorkoutSummaryDataToCol2 (value,precision) {
        var newValue = "";
        if (value === "-") {
            newValue = "-"
        } else  if (col2Model.count >= 5 && value != " ") {
            if (root.isBikeFitnessTest || root.isGerkinTest) {
                newValue = value;
            } else {
                newValue = value.toFixed(precision)
            }
        }
        else if (col2Model.count == 0) {
            newValue = StrFormat.formatTimeString(value);
        }
        else if ((col2Model.count == 3 || col2Model.count == 4) && root.productType == WorkoutProgram.TREADMILL) {
            newValue = value.toFixed(1)
        } else {
            newValue = value;
        }

        col2Model.append({"label": ""+newValue});
    }

    function clearCol2Model() {
        col2Model.clear();
    }

    function addWorkoutSummaryDataToCol3 (value,precision) {
        var newValue = "";
        if (col3Model.count >= 5 && value != " ") {
            if (root.isBikeFitnessTest || root.isGerkinTest) {
                newValue = value;
            } else {
                newValue = value.toFixed(precision)
            }
        } else if (col3Model.count == 0) {
            newValue = StrFormat.formatTimeString(value);
        } else if (value === "-") {
            newValue = "-"
        }
        else if ((col3Model.count == 3 || col3Model.count == 4) && root.productType == WorkoutProgram.TREADMILL) {
            newValue = value.toFixed(1)
        } else {
            newValue = value;
        }

        col3Model.append({"label": ""+newValue});
    }

    function clearCol3Model() {
        col3Model.clear();
    }

    function addWorkoutSummaryDataToCol4 (value,precision) {
        var newValue = "";
        if (value === "-") {
            newValue = "-"
        } else  if (col4Model.count >= 5 ) {
            if ((root.isBikeFitnessTest || root.isGerkinTest || root.isMilitaryTest) && (col4Model.count == 5 || col4Model.count == 6)) {
                if (col4Model.count == 6) { // sixth entry of fit test table is gender: TODO: simplify this esoterism
                    if (value == 1) {
                        newValue = "F";
                    }
                    else {
                        newValue = "M";
                    }
                }
                else {
                    newValue = value;
                }
            }
            else {
                newValue = value.toFixed(precision)
            }
        }
        else if (col4Model.count == 0) {
            newValue = StrFormat.formatTimeString(value);
        }
        else if ((col4Model.count == 3 || col4Model.count == 4) && root.productType == WorkoutProgram.TREADMILL) {
            newValue = value.toFixed(1)
        }
        else
        {
            newValue = value;
        }

        col4Model.append({"label": ""+newValue});
    }

    function clearCol4Model() {
        col4Model.clear();
    }

    onOpacityChanged: if (!opacity && main.isTft) listViewMenu.currentIndex = 2
    width: 1366
    height: 760

    //    onWorkoutDataChanged: {
    //        // TODO: build column list models, and QR code string from WorkoutRunData object
    //        console.log("Workout Data Changed!");
    //    }

    // In the original planned design these lists were to be constructed dynamically by onWorkoutDataChanged above.
    // They are models for data to place in the table columns

    ListModel { // row headers
        id: rowLablesModel
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE PACE (RPM)") }
        ListElement { label: QT_TR_NOOP("MAX PACE (RPM)") }
        ListElement { label: QT_TR_NOOP("DISTANCE"); metricLabel: QT_TR_NOOP("KM"); usLabel: QT_TR_NOOP("MI") }
        ListElement { label: QT_TR_NOOP("CALORIES") }
    }

    ListModel { // row headers
        id: rowLablesTreadModel
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("MAX SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("DISTANCE"); metricLabel: QT_TR_NOOP("KM"); usLabel: QT_TR_NOOP("MI") }
        ListElement { label: QT_TR_NOOP("CALORIES") }
    }

    ListModel { // row headers
        id: rowFTLabelsModel
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE PACE (RPM)") }
        ListElement { label: QT_TR_NOOP("MAX PACE (RPM)") }
        ListElement { label: QT_TR_NOOP("AGE") }
        ListElement { label: QT_TR_NOOP("GENDER") }
        ListElement { label: QT_TR_NOOP("ESTIMATED VO2") }
    }

    ListModel { // row headers
        id: rowFTLabelsTreadModel
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("MAX SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("AGE") }
        ListElement { label: QT_TR_NOOP("GENDER") }
        ListElement { label: QT_TR_NOOP("ESTIMATED VO2") }
    }

    ListModel { // row headers
        id: rowMTLabelsModel
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("MAX SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("AGE") }
        ListElement { label: QT_TR_NOOP("GENDER") }
        ListElement { label: QT_TR_NOOP("SCORE (45-100)") }
    }
    ListModel { // row headers
        id: rowMTLabelsModelAirForce
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("MAX SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("AGE") }
        ListElement { label: QT_TR_NOOP("GENDER") }
        ListElement { label: QT_TR_NOOP("SCORE (0-50)") }
    }
    ListModel { // row headers
        id: rowMTLabelsModelArmy
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("MAX SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("AGE") }
        ListElement { label: QT_TR_NOOP("GENDER") }
        ListElement { label: QT_TR_NOOP("SCORE (0-100)") }
    }
    ListModel { // row headers
        id: rowMTLabelsModelMarines
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("MAX SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("AGE") }
        ListElement { label: QT_TR_NOOP("GENDER") }
        ListElement { label: QT_TR_NOOP("SCORE (0-100)") }
    }
    ListModel { // row headers
        id: rowMTLabelsModelNavy
        property string heading: ""
        property int hAlign: Text.AlignLeft
        property int width: 395

        ListElement { label: QT_TR_NOOP("ELAPSED TIME") }
        ListElement { label: QT_TR_NOOP("AVG HEART RATE") }
        ListElement { label: QT_TR_NOOP("MAX HEART RATE") }
        ListElement { label: QT_TR_NOOP("AVERAGE SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("MAX SPEED"); metricLabel: QT_TR_NOOP("KPH"); usLabel: QT_TR_NOOP("MPH") }
        ListElement { label: QT_TR_NOOP("AGE") }
        ListElement { label: QT_TR_NOOP("GENDER") }
        ListElement { label: QT_TR_NOOP("SCORE (45-100)") }
    }

    ListModel { // WARM UP column
        id: col1Model

        property string heading: qsTr("WARMUP") + application.emptyString
        property int headingPointSize: ["fr", "es", "pt", "it"].indexOf(application.currentLanguage) >= 0 ? (application.currentLanguage === "it" ? 13 : 15) : 20
        property int hAlign: Text.AlignHCenter
        property url bgimage: "graphics/summary/Work_Summary_Column1.png"
        //property int width: 370
    }

    ListModel { // WORKOUT column
        id: col2Model

        property string heading: qsTr("WORKOUT") + application.emptyString
        property int headingPointSize: ["fr", "es", "pt", "it"].indexOf(application.currentLanguage) >= 0 ? (application.currentLanguage === "it" ? 13 : 15) : 20
        property int hAlign: Text.AlignHCenter
        property url bgimage: "graphics/summary/Work_Summary_Column2.png"
        //property int pointSize: 20
    }

    ListModel { // COOLDOWN column
        id: col3Model

        property string heading: qsTr("COOLDOWN") + application.emptyString
        property int headingPointSize: ["fr", "es", "pt", "it"].indexOf(application.currentLanguage) >= 0 ? (application.currentLanguage === "it" ? 13 : 15) : 20
        property int hAlign: Text.AlignHCenter
        property url bgimage: "graphics/summary/Work_Summary_Column3.png"
    }

    ListModel { // TOTAL column
        id: col4Model

        property string heading: qsTr("TOTAL") + application.emptyString
        property int headingPointSize: ["fr", "es", "pt", "it"].indexOf(application.currentLanguage) >= 0 ? (application.currentLanguage === "it" ? 13 : 15) : 20
        property int hAlign: Text.AlignHCenter
        property url bgimage: "graphics/summary/Work_Summary_Column4.png"

        /*        ListElement { label: "34:32" }
        ListElement { label: "137" }
        ListElement { label: "152" }
        ListElement { label: "5.3" }
        ListElement { label: "8.2" }
        ListElement { label: "6.53" }
        ListElement { label: "311" }*/
    }

    // QR Code display
    //    Rectangle {
    //        id: qr_outline
    //        color: "#00000000"
    //        border.color: "#000000"
    //        anchors { top: parent.top ; topMargin: 25 ; left: parent.left ; leftMargin: 30 }
    //        width: 160
    //        height: 160

    //        QRCode {
    //            id: qrcode
    //            property string dataString: "http://www.truefitness.com"

    //            // the size of the QR code element is tricky, since all code cells inside need to be the same pixel size
    //            // Resizing it tends to cause jumps in size, since it has to resize in increments of the cell size divided over the overall size
    //            anchors { fill: parent ; margins: 5 }
    //            string: dataString
    //        }
    //    }

    //    Text {
    //        id: appaddtext

    //        text: qsTr("DOWNLOAD YOUR TRUE FITNESS APP") + application.emptyString
    //        font.pointSize: 10.5
    //        anchors { top: qr_outline.top; topMargin: 20 ; left: qr_outline.right ; leftMargin: 10 }
    //    }

    Item {
        state: main.isTouch ? "touchState" : "tftState"

        states: [
            State {
                name: "touchState"
                AnchorChanges {
                    target: summaryTitle
                    anchors.bottom: dataTable.top
                    anchors.right: parent.right
                }
                PropertyChanges {
                    target: summaryTitle
                    anchors.bottomMargin: 0
                    anchors.rightMargin: 48
                }
                AnchorChanges {
                    target: dataTable
                    anchors.top: parent.top
                    anchors.left: parent.left
                }
                PropertyChanges {
                    target: dataTable
                    anchors.topMargin: 145
                    anchors.leftMargin: 0
                }
                AnchorChanges {
                    target: fitTestSummaryItem
                    anchors.right: parent.right
                    anchors.top: parent.top
                }
                PropertyChanges {
                    target: fitTestSummaryItem
                    anchors.rightMargin: 42
                    anchors.topMargin: 200
                }
            },
            State {
                name: "tftState"
                AnchorChanges {
                    target: summaryTitle
                    anchors.bottom: dataTable.top
                    anchors.right: parent.right
                }
                PropertyChanges {
                    target: summaryTitle
                    anchors.bottomMargin: 0
                    anchors.rightMargin: 48
                }
                AnchorChanges {
                    target: dataTable
                    anchors.top: parent.top
                    anchors.left: parent.left
                }
                PropertyChanges {
                    target: dataTable
                    anchors.topMargin: 70
                    anchors.leftMargin: 0
                }
                AnchorChanges {
                    target: fitTestSummaryItem
                    anchors.right: parent.right
                    anchors.top: parent.top
                }
                PropertyChanges {
                    target: fitTestSummaryItem
                    anchors.rightMargin: 42
                    anchors.topMargin: 95
                }
            }
        ]
    }

    Text {
        id: summaryTitle

        text: root.workoutName + qsTr(" SUMMARY") + application.emptyString
        font.bold: true
        font.pixelSize: 35
        font.capitalization: Font.AllUppercase
    }

    DataTable {
        id: dataTable
        sourceFile: "WorkoutSummary" // needed for translation

        colWidth: 345
        height: 500
        models: {
            if (root.isBikeFitnessTest) {
                return [ rowFTLabelsModel, col2Model, col3Model, col4Model ];
            }
            else if (root.isGerkinTest) {
                return [ rowFTLabelsTreadModel, col2Model, col3Model, col4Model ];
            }
            else if (root.isMilitaryTest) {
                if (workoutManager.workoutProgram.programIndex == WorkoutProgram.TREAD_AIR_FORCE_MILITARY_FITNESS_TEST_PROG) {
                    return [ rowMTLabelsModelAirForce, col2Model, col3Model, col4Model ];
                }
                else if (workoutManager.workoutProgram.programIndex == WorkoutProgram.TREAD_ARMY_MILITARY_FITNESS_TEST_PROG)
                {
                    return [ rowMTLabelsModelArmy, col2Model, col3Model, col4Model ];
                }
                else if (workoutManager.workoutProgram.programIndex == WorkoutProgram.TREAD_MARINES_MILITARY_FITNESS_TEST_PROG)
                {
                    return [ rowMTLabelsModelMarines, col2Model, col3Model, col4Model ];
                }
                else if (workoutManager.workoutProgram.programIndex == WorkoutProgram.TREAD_NAVY_MILITARY_FITNESS_TEST_PROG)
                {
                    return [ rowMTLabelsModelNavy, col2Model, col3Model, col4Model ];
                }
            }
            else {
                if (root.productType == WorkoutProgram.TREADMILL) {
                    if (warmUpValues) {
                        return [ rowLablesTreadModel, col1Model, col2Model, col3Model, col4Model ];
                    }
                    else {
                        return [ rowLablesTreadModel, col2Model, col3Model, col4Model ];
                    }
                }
                else {
                    if (warmUpValues) {
                        return [ rowLablesModel, col1Model, col2Model, col3Model, col4Model ];
                    }
                    else {
                        return [ rowLablesModel, col2Model, col3Model, col4Model ];
                    }
                }
            }
        }
    }

    ImageButton {
        id: homeButton
        visible: main.isTouch

        anchors.right: parent.right
        anchors.rightMargin: 42
        anchors.top: parent.top
        anchors.topMargin: 12
        upimage: "graphics/navbar/Navigation_Home_Disabled.png"
        downimage: "graphics/navbar/Navigation_Home_Down.png"
        mouseAreaScale: 1.8
        onClicked: close()
    }

    Item {
        id: fitTestSummaryItem

        visible: root.isBikeFitnessTest || root.isGerkinTest

        Image {
            id: fitTestSummaryImage1
            anchors.top: parent.top
            anchors.right: parent.right
            anchors.rightMargin: -42
            source: "graphics/summary/summary_fit-test_1.png"

            Text {
                id: fitTestSummaryText1
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 15
                text: qsTr("EXCELLENT") + application.emptyString
                font.pointSize: 12
                font.bold: true
                smooth: true
                color: "black"
            }
        }

        Image {
            id: fitTestSummaryImage2
            anchors.top: fitTestSummaryImage1.bottom
            anchors.topMargin: 10
            anchors.right: fitTestSummaryImage1.right
            source: "graphics/summary/summary_fit-test_2.png"

            Text {
                id: fitTestSummaryText2
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
                anchors.left: parent.left
                anchors.leftMargin: 15
                text: qsTr("GOOD") + application.emptyString
                font.pointSize: 12
                font.bold: true
                smooth: true
                color: "black"
            }
        }

        Image {
            id: fitTestSummaryImage3
            anchors.top: fitTestSummaryImage2.bottom
            anchors.topMargin: 10
            anchors.right: fitTestSummaryImage2.right
            source: "graphics/summary/summary_fit-test_3.png"

            Text {
                id: fitTestSummaryText3
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
                anchors.left: parent.left
                anchors.leftMargin: 15
                text: qsTr("ABOVE AVG") + application.emptyString
                font.pointSize: 12
                font.bold: true
                smooth: true
                color: "black"
            }
        }

        Image {
            id: fitTestSummaryImage4
            anchors.top: fitTestSummaryImage3.bottom
            anchors.topMargin: 10
            anchors.right: fitTestSummaryImage3.right
            source: "graphics/summary/summary_fit-test_4.png"

            Text {
                id: fitTestSummaryText4
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
                anchors.left: parent.left
                anchors.leftMargin: 15
                text: qsTr("AVERAGE") + application.emptyString
                font.pointSize: 12
                font.bold: true
                smooth: true
                color: "black"
            }
        }

        Image {
            id: fitTestSummaryImage5
            anchors.top: fitTestSummaryImage4.bottom
            anchors.topMargin: 10
            anchors.right: fitTestSummaryImage4.right
            source: "graphics/summary/summary_fit-test_5.png"

            Text {
                id: fitTestSummaryText5
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
                anchors.left: parent.left
                anchors.leftMargin: 15
                text: qsTr("BELOW AVG") + application.emptyString
                font.pointSize: 12
                font.bold: true
                smooth: true
                color: "black"
            }
        }

        Image {
            id: fitTestSummaryImage6
            anchors.top: fitTestSummaryImage5.bottom
            anchors.topMargin: 10
            anchors.right: fitTestSummaryImage5.right
            source: "graphics/summary/summary_fit-test_6.png"

            Text {
                id: fitTestSummaryText6
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
                anchors.left: parent.left
                anchors.leftMargin: 15
                text: qsTr("POOR") + application.emptyString
                font.pointSize: 12
                font.bold: true
                smooth: true
                color: "black"
            }
        }

        Image {
            id: fitTestSummaryImage7
            anchors.top: fitTestSummaryImage6.bottom
            anchors.topMargin: 10
            anchors.right: fitTestSummaryImage6.right
            source: "graphics/summary/summary_fit-test_7.png"

            Text {
                id: fitTestSummaryText7
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
                anchors.left: parent.left
                anchors.leftMargin: 15
                text: qsTr("VERY POOR") + application.emptyString
                font.pointSize: 12
                font.bold: true
                smooth: true
                color: "black"
            }
        }

        Image {
            id: fitTestSummaryMarker
            anchors.verticalCenter: fitTestSummaryImage1.verticalCenter
            anchors.verticalCenterOffset: 361 *( 1.0 - root.fitTestScore) // 0 - 361
            anchors.right: fitTestSummaryImage1.left
            anchors.rightMargin: -25
            source: "graphics/summary/summary_fit-test_arrow.png"
        }
    }


    BlueToothLowEnergy {
        id: ble
        Component.onCompleted: {
            console.log("ble." +ble.dummy)
        }
    }

    ImageButton {
        id: saveButton
        visible: main.isTouch

        fontsize: 18
        label_color: "#000000"
        label_under: true
        label: qsTr("SAVE") + application.emptyString
        anchors.right: parent.right
        anchors.rightMargin: 36
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 32
        upimage: "graphics/205/Lrg_Button_Up.png"
        downimage: "graphics/205/Lrg_Button_Down.png"
        enabled: true


        onClicked: {

            root.doSave()
        }
    }

    BluetoothTransmitPopup {
        id: bleDialog
    }


    Text {
        id: exportArea

        visible: main.isTouch
        anchors.right: saveButton.left
        anchors.rightMargin: 15
        anchors.top: saveButton.top
        anchors.topMargin: 25
        width: Math.max(saveTitle.paintedWidth, saveInstructions.paintedWidth)

        Text {
            id: saveTitle

            text: qsTr("EXPORT WORKOUT DATA") + application.emptyString
            anchors {
                top: parent.top
                horizontalCenter: parent.horizontalCenter
            }
            font.bold: true
            font.pixelSize: 23
        }

        Text {
            id: saveInstructions

            color: "#008efb"
            text: qsTr("(Open TRUE App on your device or insert USB drive)") + application.emptyString
            anchors.horizontalCenter: saveTitle.horizontalCenter
            anchors.top: saveTitle.bottom
            anchors.topMargin: 2
            font.pixelSize: 14
        }
    }

    Image{
        id: _TrueAppIcon
        visible: main.isTouch
        x: 36
        y: 652
        source: "graphics/Bluetooth/TRUE_app_icon1.png"
        anchors.left: parent.left
        anchors.leftMargin: 36
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 32
    }

    Image {
        id: _QRImage

        visible: main.isTouch
        source: "graphics/Bluetooth/TRUE_Portal_QR.png"
        anchors.top: _TrueAppIcon.top
        anchors.topMargin: 0
        anchors.leftMargin: 0

        anchors.left: _TrueAppIcon.right
    }

    Text {
        id:bluetoothText
        visible: main.isTouch
        x: 200
        y: 675
        width: 321
        height: 53
        anchors.left: _QRImage.right
        text: qsTr("Download the TRUE Fitness app to track your workouts!")
        wrapMode: Text.WordWrap
        anchors.top: _QRImage.top
        anchors.bottomMargin: 12
        anchors.leftMargin: 12
        font.pixelSize: 23
    }

    Item {
        id: countDown
        x: 46
        y: 44
        visible: main.isTouch

        anchors { top: parent.top ; topMargin: 10; left: parent.left; leftMargin: 20 }
        width: 340
        height: 155

        BorderImage {
            id: rectoval
            x: -24
            y: -20
            width: 448
            height: 244
            anchors.fill: parent

            source: "graphics/setup/Setup_Large_Up_Step3.png"
            border { top: 65; bottom: 65; left: 65; right: 76 }

            Text {
                id: counterDigits
                color: "#808080"
                text: StrFormat.formatTimeString(root.timeLeft)
                font.pointSize: 30
                horizontalAlignment: Text.AlignHCenter
                anchors { horizontalCenter: parent.horizontalCenter ; horizontalCenterOffset: -6
                    top: parent.top ;  topMargin: 13
                }
            }

            Text {
                id: counterMsg
                x: 9
                y: 65
                width: parent.width - 100
                height: 40
                color: "#808080"
                text: qsTr("TOUCH FOR MORE TIME") + application.emptyString
                anchors { horizontalCenter: parent.horizontalCenter ; horizontalCenterOffset: -6
                    bottom: parent.bottom  ; bottomMargin: 50
                }
                wrapMode: Text.WordWrap
                font.pointSize: 17
                horizontalAlignment: Text.AlignHCenter
            }

        }
    }

    Connections {
        target: main.isTft && root.visible && root.opacity > 0 ? keymapper : null
        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "WorkoutSummary")
            listViewMenu.prevItem()
        }
        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "WorkoutSummary")
            listViewMenu.nextItem()
        }
        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "WorkoutSummary")
            if (listViewMenu.currentItem.state == "saveState") {
                if (listViewMenu.currentItem.currentButton.enabled) {
                    root.doSave()
                }
            } else if (listViewMenu.currentItem.state == "timerState") {
                idle_timer.restart()

            } else if (listViewMenu.currentItem.state == "homeState") {
                root.close()
            }
        }
    }

    Text {
        id: instrText
        visible: main.isTft
        anchors { left: parent.left; leftMargin: 25; verticalCenter: main.isTft ? listViewLoader.verticalCenter : undefined }
        wrapMode: Text.WordWrap
        horizontalAlignment: Text.AlignHCenter
        width: 600
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: {
            if (!listViewMenu || listViewMenu.currentIndex < 0)
                return ""
            switch (listViewMenu.currentItem.state) {
                case "saveState":
                    return qsTr("open TRUE app or insert USB to save workout data") + application.emptyString
                case "timerState":
                case "homeState":
                    return qsTr("press ENTER to select") + application.emptyString
                default:
                    return ""
            }
        }
    }

    Loader {
        id: listViewLoader
        sourceComponent: main.isTft ? listViewMenuComponent : undefined
        anchors { top: dataTable.bottom; topMargin: -13; right: parent.right; rightMargin: 20 }
        width: 720
        height: 190
        visible: main.isTft

        Component {
            id: listViewMenuComponent
            ListView {
                id: listViewMenu

                function nextItem() {
                    if (currentIndex === count-1) {
                        var tmp = highlightMoveVelocity
                        console.log("tmp>>",tmp)
                        highlightMoveVelocity = 2500
                        currentIndex = 0
                        highlightMoveVelocity  = tmp
                    } else {
                        currentIndex += 1
                    }
                }
                function prevItem() {
                    if (currentIndex === 0) {
                        var tmp = highlightMoveVelocity
                        highlightMoveVelocity = 2500
                        currentIndex = count - 1
                        highlightMoveVelocity  = tmp
                    } else {
                        currentIndex -= 1
                    }
                }

                orientation: ListView.Horizontal
                currentIndex: 2
                width: 720
                height: 174
                highlight: Image {
                    source: "graphics/tft/NAV_selector_2.png"
                    width: 244
                    height: 174
                }
                model: ListModel {
                    ListElement { name: "save"; label: QT_TR_NOOP("SAVE?"); icon: "tft/nav_icon_SAVED.png" }
                    ListElement { name: "timer"; label: QT_TR_NOOP("MORE TIME?"); icon: "" }
                    ListElement { name: "home"; label: QT_TR_NOOP("HOME"); icon: "tft/nav_icon_HOME.png" }
                }
                delegate: Component {
                    Item {
                        id: menuItem

                        property variant currentButton

                        width: 240
                        height: 174
                        state: {
                            if (model.name == "save")
                                return "saveState"
                            else if (model.name == "timer")
                                return "timerState"
                            else if (model.name == "home")
                                return "homeState"
                            else
                                return ""
                        }

                        Item {
                            id: saveItem
                            anchors.fill: parent
                            visible: false
                            ImageButton {
                                id: saveButton
                                width: 126
                                height: 76
                                fontsize: 16

                                label: qsTr(model.label) + application.emptyString
                                label_under: true
                                label_y_offset: 50
                                label_color: "black"
                                wrapWidth: 80

                                disabledOpacity: root.saveHasHappened ? 1.0 : 0.5
                                enabled: true
                                anchors.top: parent.top
                                anchors.topMargin: 30
                                anchors.horizontalCenter: parent.horizontalCenter
                                upimage: root.saveHasHappened ? Globals.graphicsPath + "tft/nav_icon_SAVED-green.png" : Globals.graphicsPath+model.icon
                                downimage: Globals.graphicsPath+model.icon
                                beep: false
                                mouseAreaScale: 0.7

                            }
                        }
                        Item {
                            id: timerItem
                            anchors.fill: parent
                            opacity: root.timeLeft === 0 ? 0.5 : 1.0
                            visible: false
                            Text {
                                id: timerText
                                width: 126
                                height: 76
                                anchors.top: parent.top
                                anchors.topMargin: 30
                                anchors.horizontalCenter: parent.horizontalCenter
                                font.pixelSize: 40
                                font.bold: true
                                text: ":" + (root.timeLeft<10 ? "0"+root.timeLeft : root.timeLeft)
                                horizontalAlignment: Text.AlignHCenter
                                // :56 text
                            }
                            Text {
                                text: qsTr(model.label) + application.emptyString
                                width: 80
                                height: 76
                                anchors.top: parent.top
                                anchors.topMargin: 130
                                anchors.horizontalCenter: parent.horizontalCenter
                                font.pixelSize: 16
                                font.bold: true
                                horizontalAlignment: Text.AlignHCenter
                                wrapMode: Text.WordWrap
                            }
                        }
                        Item {
                            id: homeItem
                            anchors.fill: parent
                            visible: false
                            ImageButton {
                                id: homeButton
                                width: 126
                                height: 76
                                fontsize: 16

                                label: qsTr(model.label) + application.emptyString
                                label_under: true
                                label_y_offset: 50
                                label_color: "black"
                                wrapWidth: 80

                                anchors.top: parent.top
                                anchors.topMargin: 30
                                anchors.horizontalCenter: parent.horizontalCenter
                                upimage: Globals.graphicsPath+model.icon
                                downimage: Globals.graphicsPath+model.icon
                                beep: false
                                mouseAreaScale: 0.7

                            }
                        }

                        states: [
                            State {
                                name: "saveState"
                                PropertyChanges { target: saveItem; visible: true }
                                PropertyChanges { target: timerItem; visible: false }
                                PropertyChanges { target: homeItem; visible: false }
                                StateChangeScript { script: menuItem.currentButton = saveButton }
                            },
                            State {
                                name: "timerState"
                                PropertyChanges { target: saveItem; visible: false }
                                PropertyChanges { target: timerItem; visible: true }
                                PropertyChanges { target: homeItem; visible: false }
                                StateChangeScript { script: menuItem.currentButton = timerItem }
                            },
                            State {
                                name: "homeState"
                                PropertyChanges { target: saveItem; visible: false }
                                PropertyChanges { target: timerItem; visible: false }
                                PropertyChanges { target: homeItem; visible: true }
                                StateChangeScript { script: menuItem.currentButton = homeButton }
                            }
                        ]
                    }
                }
            }
        }
    }


    /*
    Item {
        id: npsummary
        width: 1000
        height: 200
        anchors.bottom: parent.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        //x: 1
        //y: 1

        Rectangle{
            id: rect
            width: 1000
            height: 200
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            color: "grey"

            onOpacityChanged: {
                if (opacity > 0.9) {
                    errorManager.debugMessage("rect - show summary bar");
                    netpulse.showPage("login");
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    errorManager.debugMessage("click - show summary bar");
                    netpulse.showPage("summaryBar");
                }
            }
        }

        //NetpulseWindow: {
            //page: "info"
            //absx: 1
            //absy: 1
        //}
        onVisibleChanged: {
            if (visible) {
                errorManager.debugMessage("show summary bar");
                netpulse.showPage("login");
            }
        }
    }
   */
}
