import QtQuick 2.4
import VLCVideo 1.0
import ".."

Item{
    id:root

    property bool viewShowing: false
    property string channelID: ""
    property bool isSelected: currentViewName === "TV_VIEW"
    property bool tunedToCabChannel: tv.tunedToCab()

    width:workoutViewContainer.contentAreaWidth
    height: workoutViewContainer.contentAreaHeight
    objectName: "TV_VIEW_CONTAINER"
    LayoutMirroring.enabled: Qt.application.layoutDirection === Qt.RightToLeft
    LayoutMirroring.childrenInherit: true

    signal stopped()
    signal menuButtonPressed()

    function viewdestruct() {
        tv.stop()
        if(netpulseAvailable)
            netpulse.hide()
    }

    // Full-screen TV controls
    Connections {
        target: main.isTft && !main.blockKeys && root.isSelected && root.opacity > 0 && tv.player.fullscreen && !tvList.onTop ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "TvViewContainer")
            fullscreenVideoFrame.endFullscreen()
        }

        onTvPressed: {
            main.debugKeys("tvPressed", "TvViewContainer")
            // pressing TV while in fullscreen toggles TV menu
            tvList.visible = true
            tvList.onTop = true
        }

        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "TvViewContainer")
            tvControls.channelDownClicked()
        }

        onDoubleRightPressed: {
            main.debugKeys("doubleRightPressed", "TvViewContainer")
            tvControls.channelUpClicked()
        }
    }

    Connections {
        target: main.isTft && tvList.onTop ? keymapper : null
        onTvPressed: {
            main.debugKeys("tvPressed", "TvViewContainer", "(with tv list on top)")
            tvList.onTop = false
            tvList.visible = false
        }
    }

    Connections {
        target: main.isTft && tvList.onTop ? tv.player : null
        onFullscreenChanged: {
            // it is important to reparent tvList back or it will stay
            // stuck on top of all other elements
            if (!tv.player.fullscreen)
                tvList.onTop = false
        }
    }

    Connections {
        target: root.isSelected && !tvList.visible ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "TvViewContainer")
            volume_controls.volumeUp();
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "TvViewContainer")
            volume_controls.volumeDown();
        }

    }

    function shown() {
        root.viewShowing = true
        // request to play audio when switching to this view
        if(!tvList.visible) {
            if (tv.isIpodInput) {
                tv.restoreChannel()
            }
            tv.muted = !audioManager.tvAllowed
            audioManager.tvRequest()
        }
    }

    function hidden() {
        root.viewShowing = false
    }

    function stop() {
        root.stopped()
        tv.stop()
    }

    Component.onCompleted: {
        if (tv.currentChannel >= 0) {
            var chanid = tv.channelList.channels.get(tv.currentChannel).id
            tvList.channelSelected(chanid)
        }
        else
            tvList.visible = !netpulseAvailable
    }

    Connections{
        target: workoutScreen
        onWorkoutStopped: root.stop()
    }

    Connections {
        target: currentViewName === "TV_VIEW" && !tv.player.fullscreen ? keymapper : null

        onTvPressed: {
            main.debugKeys("tvPressed", "TvViewContainer")
            tvList.visible = !tvList.visible
        }
    }

    Connections {
        target: root.isSelected && !tvList.visible ? keymapper : null

        onStartPressed: {
            main.debugKeys("startPressed", "TvViewContainer", "(tv list not visible)")
            if (tv.player.fullscreen && tvControls.ccOptions > 0)
                tvControls.ccClicked()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "TvViewContainer", "(tv list not visible)")
            if (tv.player.fullscreen) {
                fullscreenVideoFrame.endFullscreen()
            } else {
                fullscreenVideoFrame.showFullscreen(tv.player)
            }
        }

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "TvViewContainer", "(tv list not visible)")
            fullscreenVideoFrame.endFullscreen()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "TvViewContainer", "(tv list not visible)")
            fullscreenVideoFrame.endFullscreen()
        }
    }

    Rectangle{
        id:tvContainer
        opacity: main.isTft && !root.isSelected && tvList.visible ? 0.0 : 1.0
        width: 1000
        height: 406
        anchors.bottom: parent.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        color: "grey"

        MouseArea {
            anchors.fill: parent
            onClicked: fullscreenVideoFrame.showFullscreen(tv.player)
        }

        VLCSurface {
            id: tvView

            player: tv.player
            playing: !player.fullscreen && root.viewShowing && (tv.playing || tv.tuning)
            aspect: tv.aspect

            width: 720
            height: 405

            anchors.bottom: parent.bottom
            anchors.left: parent.left

            Text {
                anchors.centerIn: parent
                color: "white"
                visible: tv.tuningTimedOut && !tv.playing
                text: qsTr("The current channel may be temporarily unavailable.") + application.emptyString
            }
        }

        Text {
            id: channelName

            anchors { top: parent.top ; topMargin: 10 ; left: tvView.right ; leftMargin: 10 }
            width: 260
            height: 60
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            color: "white"
            text: root.tunedToCabChannel ? "" : tv.getTVChannelName()
        }

        TelevisionControls {
            id: tvControls

            acceptKeys: root.visible && !tv.player.fullscreen && root.isSelected && !tvList.acceptKeys
            showTftButtonHelp: root.isSelected
            showChannelNumber: !root.tunedToCabChannel
            showMenuHelp: true
            allowTftCc: !options.cabEnabled
            onStop: { root.stop() ; tvList.visible = !netpulseAvailable }

            onOpenMenu: {
                root.menuButtonPressed()
                if (netpulseAvailable)
                    netpulse.showPage("tv")
                else
                    tvList.visible = (tvList.visible ? false : true)
            }
            ccOptions: tv.numCaptionTracks
            ccTrack: tv.captionTrack
            onCcClicked: {
                console.log("cc clicked")

                if(tv.captionTrack < tv.numCaptionTracks)
                    tv.captionTrack++
                else
                    tv.captionTrack=0
            }
            Connections {
                target: tv.player
                onCaptionTrackChanged: {
                    if (!main.isTft)
                        return

                    if (track === 0)
                        tv.player.setOverlayText(qsTr("Closed Caption Off"))
                    else
                        tv.player.setOverlayText(qsTr("Closed Caption") + " " + track)
                }
            }
            onSizeButtonClicked: fullscreenVideoFrame.showFullscreen(tv.player)
            onChannelUpClicked: {
                if(root.tunedToCabChannel && options.cabEnabled)
                    brainboard.cabChannelUp()
                else {
                    audioManager.tvRequest()
                    tv.channelUp()
                }
            }
            onChannelDownClicked: {
                if(root.tunedToCabChannel && options.cabEnabled)
                    brainboard.cabChannelDown()
                else {
                    audioManager.tvRequest()
                    tv.channelDown()
                }
            }
            currentChannelName: tv.getTVChannelNumber()
            showSizeButton: main.isTouch
            allowFullscreen: true
            tuning: tv.tuning
            anchors {   top: channelName.bottom ; topMargin: 0
                        bottom: parent.bottom ; bottomMargin: -5
                        left: tvView.right ; leftMargin: 20
                        right: parent.right
            }
        }
    }

    Binding {
        target: workoutScreen
        when: true
        property: "tvMenuShowing"
        value: tvList.visible
    }

    Binding {
        target: videoOverlay
        when: root.isSelected
        property: "showHelpText"
        value: !tvList.onTop
    }

    ChannelListView {
        id: tvList
        visible: (tv.currentChannel < 0) || !netpulseAvailable
        opacity: main.isTouch || root.isSelected ? 1.0 : 0.5
        acceptKeys: tvList.visible && (!tv.player.fullscreen || onTop) && root.isSelected
        z: 100000
        width: 1000
        height: onTop ? 460 : 410
        x: onTop ? 180 : 0
        y: onTop ? 170 : 0
        clip: true

        property bool onTop: false
        onOnTopChanged: {
            if (onTop)
                reparentToRoot()
            else
                parent = root
        }

        function getRootItem(child) {
            var top
            top = child

            if( !child )
                return child

            while( top.parent ) {
                top = top.parent
            }
            return top
        }

        function reparentToRoot() {
            // reparent to the root of the application so that tvList will
            // be visible above the fullscreen video frame
            tvList.parent = getRootItem(tvList)
        }

        model: tv.channelList.channels
        onChannelSelected: {
            tvList.onTop = false
            tv.on = true
            print("TV channel selected id:" + id)
            if(id) {
                audioManager.tvRequest()
                root.channelID = id
                tv.tuneChannelID(id)
            }
            visible = false
        }
    }

    Text {
        id: helpText
        visible: tvList.onTop
        parent: tvList.parent
        z: tvList.z
        text: qsTr("press ENTER to select, TV to close menu") + application.emptyString
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "white"
        x: tvList.x + (tvList.width - helpText.width) / 2
        y: tvList.y + tvList.height + 20
    }
}
