/* @file workout_menus.js
    @brief Definitions of the workout program menu for all machine types.
*
*   Each menu_xxx array definition is a menu.  Each entry may be
*    either another menu by defining the "nextmenu" property, or
*   a workout program by definining the "program" property to the corresponding xml filename.
*/

// ====== Top Level Menu Descriptions ======
var desc_menu_weightloss = QT_TRANSLATE_NOOP("Menu", "If weight loss is your primary goal, this button will quickly get you to an ideal workout.")
var desc_menu_hrc = QT_TRANSLATE_NOOP("Menu", "Let your heart guide you to your workout goal while the machine does all the adjusting for you.")
var desc_menu_performance = QT_TRANSLATE_NOOP("Menu", "Challenging workout options for those that are already cardio-fit." )
var desc_menu_custom = QT_TRANSLATE_NOOP("Menu", "Allows you to set up your own interval workout or create a totally custom workout." )

// ====== Common Workout Descriptions ======
var desc_prog_manual = QT_TRANSLATE_NOOP("Menu", "Set up your own workout to a TIME or DISTANCE limit.")
var desc_prog_distance = QT_TRANSLATE_NOOP("Menu", "Choose any one of our 4 common distance workouts - 5k, 10k, 2 mile or 4 mile.")
var desc_prog_stride_5k = QT_TRANSLATE_NOOP("Menu", "Challenge yourself to a 5k distance workout! Choose your intensity level and the workout ends when you reach 5 kilometers (3.1 miles).")
var saved_workouts_desc = QT_TRANSLATE_NOOP("Menu", "Access to previously saved workouts.")
var prog_saved = { label: QT_TRANSLATE_NOOP("Menu", "SAVED WORKOUTS"),   desc: saved_workouts_desc, program: "SAVED_WORKOUTS",  icon: "WF/WF_Button_Saved_Workouts.png", image: "WF/WF_325_Saved_Workouts.png", modestyImage: "WF/MaleOnly/WF_325_Saved_Workouts.png" }

// empty placeholder to allow positioning of items in a short menu
var prog_shim = { shim: true, image:""}

// ====== Treadmill Menus ======
// ----- Treadmill Fitness Tests -----
var tread_fitness_test_gerkin_desc = QT_TRANSLATE_NOOP("Menu", "A fitness test used to estimate your VO2 max.  The test increases speed and incline gradually every minute and ends at the point where your heart rate reaches 85% of the maximum for your age.")
var tread_fitness_test_army_desc = QT_TRANSLATE_NOOP("Menu", "A 2-mile running test measured against age and gender calculations.")
var tread_fitness_test_navy_desc = QT_TRANSLATE_NOOP("Menu", "A 2-mile running test measured against age and gender calculations.")
var tread_fitness_test_airforce_desc = QT_TRANSLATE_NOOP("Menu", "A 1.5-mile running test measured against age and gender calculations.")
var tread_fitness_test_marines_desc = QT_TRANSLATE_NOOP("Menu", "A 3-mile running test measured against age and gender calculations.")

var prog_tread_fitness_test_gerkin = { label: QT_TRANSLATE_NOOP("Menu", "Gerkin Fitness Test"), program: "Tread_Gerkin_Test.xml", desc: tread_fitness_test_gerkin_desc, icon: "WF/WF_Button_Gerkin_Fitness.png", image: "WF/WF_419_Fitness_Test_Gerkin.png", modestyImage: "WF/MaleOnly/WF_419_Fitness_Test_Gerkin.png" }
var prog_tread_fitness_test_army = { label: QT_TRANSLATE_NOOP("Menu", "Army Fitness Test"), program: "Tread_Army_Military_Fitness_Test.xml", desc: tread_fitness_test_army_desc, icon: "WF/WF_Button_Army_Fitness.png", image: "WF/WF_420_Fitness_Test_Army.png", modestyImage: "WF/MaleOnly/WF_420_Fitness_Test_Army.png" }
var prog_tread_fitness_test_navy = { label: QT_TRANSLATE_NOOP("Menu", "Navy Fitness Test"), program: "Tread_Navy_Military_Fitness_Test.xml", desc: tread_fitness_test_navy_desc, icon: "WF/WF_Button_Navy_Fitness.png", image: "WF/WF_421_Fitness_Test_Navy.png", modestyImage: "WF/MaleOnly/WF_421_Fitness_Test_Navy.png" }
var prog_tread_fitness_test_airforce = { label: QT_TRANSLATE_NOOP("Menu", "Air Force Fitness Test"), program: "Tread_Air_Force_Military_Fitness_Test.xml", desc: tread_fitness_test_airforce_desc, icon: "WF/WF_Button_AirForce_Fitness.png", image: "WF/WF_422_Fitness_Test_Air_Force.png", modestyImage: "WF/MaleOnly/WF_422_Fitness_Test_Air_Force.png" }
var prog_tread_fitness_test_marines = { label: QT_TRANSLATE_NOOP("Menu", "Marines Fitness Test"), program: "Tread_Marines_Military_Fitness_Test.xml", desc: tread_fitness_test_marines_desc, icon: "WF/WF_Button_Marines_Fitness.png", image: "WF/WF_423_Fitness_Test_Marines.png", modestyImage: "WF/MaleOnly/WF_423_Fitness_Test_Marines.png" }

var tread_fitness_tests_menu_desc = QT_TRANSLATE_NOOP("Menu", "Choose one of 5 different workouts to assess your cardio fitness.  The Gerkin Fitness Test measures approximate VO2 MAX.  All 4 U.S. military tests are also available.")
var menu_tread_fitness_tests = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "FITNESS TESTS"), desc: tread_fitness_tests_menu_desc,
        icon: "WF/WF_Button_Fitness_Test.png", navicon: "navbar/Navigation_Fitness_Test", image: "WF/WF_315_Fitness_Test.png", modestyImage: "WF/MaleOnly/WF_315_Fitness_Test.png",
        children: [
            prog_tread_fitness_test_gerkin,
            prog_tread_fitness_test_army,
            prog_tread_fitness_test_navy,
            prog_tread_fitness_test_airforce,
            prog_tread_fitness_test_marines
        ]
    }
}

// ------ Treadmill Speed Workouts ------
var tread_walkrun_desc = QT_TRANSLATE_NOOP("Menu", "Zero-incline WALKING or RUNNING intervals are in varying 1-minute segments.  Incline changes are permanent; speed changes affect the current 1-minute segment only.")
var tread_speed_ramp_desc = QT_TRANSLATE_NOOP("Menu", "Speed increases to a maximum at the mid-point of the workout, then decreases to the finish.  Speed changes affect the current segment only.  Incline changes are permanent.")
var tread_speed_intervals_desc = QT_TRANSLATE_NOOP("Menu", "Zero-incline walking or running intervals are in 1-minute segments.  Incline changes are permanent; speed changes affect the current 1-minute segment only.")

var prog_tread_walkrun  = { label: QT_TRANSLATE_NOOP("Menu", "Walk & Run Intervals"), program: "Tread_Walk_And_Run.xml", desc: tread_walkrun_desc, icon: "WF/WF_Button_Walk_Run.png", image: "WF/WF_411_Walk_Run_Treadmill.png", modestyImage: "WF/MaleOnly/WF_411_Walk_Run_Treadmill.png" }
var prog_tread_speed_ramp = { label: QT_TRANSLATE_NOOP("Menu", "Speed Ramp"), program: "Tread_Speed_Ramp.xml", desc: tread_speed_ramp_desc, icon: "WF/WF_Button_Speed_Workouts.png", image: "WF/WF_412_Speed_Ramp.png",  modestyImage: "WF/MaleOnly/WF_412_Speed_Ramp.png" }
var prog_tread_speed_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Speed Intervals"), program: "Tread_Speed_Intervals.xml", desc: tread_speed_intervals_desc, icon: "WF/WF_Button_Speed_Workouts.png", image: "WF/WF_413_Speed_Intervals.png",  modestyImage: "WF/MaleOnly/WF_413_Speed_Intervals.png" }

var desc_menu_tread_speed_workouts = QT_TRANSLATE_NOOP("Menu", "These workout choices use speed adjustments to add variety to your cardio fitness routine.");
var menu_tread_speed = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "SPEED WORKOUTS"), desc: desc_menu_tread_speed_workouts,
        icon: "WF/WF_Button_Speed_Workouts.png", navicon: "navbar/Navigation_Speed_Workout", image: "WF/WF_312_Speed_Workout.png", modestyImage: "WF/MaleOnly/WF_312_Speed_Workout.png",
        children: [
            prog_tread_walkrun,
            prog_tread_speed_ramp,
            prog_tread_speed_intervals,
            prog_shim,
            prog_shim
        ]
    }
}

// ------ Treadmill Weightloss ------
var tread_calorie_goal_desc = QT_TRANSLATE_NOOP("Menu", "This workout allows you to choose a SPEED, INCLINE and WORKOUT TIME combination that will achieve your calorie goal.")
var tread_weightloss_hills_desc = QT_TRANSLATE_NOOP("Menu", "2-minute WALKING interval segments with incline alternating between hills and a nearly flat landscape. SPEED changes are permanent; INCLINE changes affect the current 2-minute segment only.")
var tread_glute_buster_desc = QT_TRANSLATE_NOOP("Menu", "A changing incline profile focuses on intense glute muscle use.")
var tread_leg_shaper_desc = QT_TRANSLATE_NOOP("Menu", "A workout with speed changes to work the leg muscles with added intensity.")
var tread_weightloss_hrc_desc = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 65% of your maximum heart rate. This creates efficient fat burning without overtraining. The treadmill begins in MANUAL control - gradually increase your work level until heart rate is within 10 bpm of the target. At this point, the treadmill takes over to control speed and incline to maintain your HR within a few beats of the target.")

var prog_tread_calorie_goal = { label: QT_TRANSLATE_NOOP("Menu", "Calorie Goal"),   desc: tread_calorie_goal_desc,  program: "Tread_Calorie_Goal.xml",  icon: "WF/WF_Button_Calorie_Goal.png", image: "WF/WF_301_Calorie_Goal.png",  modestyImage: "WF/MaleOnly/WF_301_Calorie_Goal.png" }
var prog_tread_weightloss_hills = { label: QT_TRANSLATE_NOOP("Menu", "Weight Loss Hills"),   desc: tread_weightloss_hills_desc,  program: "Tread_Weight_Loss_Hills.xml",  icon: "WF/WF_Button_Hill_Workout.png", image: "WF/WF_302_Weight_Loss_Hills.png",  modestyImage: "WF/MaleOnly/WF_302_Weight_Loss_Hills.png" }
var prog_tread_glute_buster = { label: QT_TRANSLATE_NOOP("Menu", "Glute Buster"),   desc: tread_glute_buster_desc,  program: "Tread_Glute_Buster.xml",  icon: "WF/WF_Button_Glute_Buster.png", image: "WF/WF_303_Glute_Buster.png",  modestyImage: "WF/MaleOnly/WF_303_Glute_Buster.png" }
var prog_tread_leg_shaper = { label: QT_TRANSLATE_NOOP("Menu", "Leg Shaper"),   desc: tread_leg_shaper_desc,  program: "Tread_Leg_Shaper.xml",  icon: "WF/WF_Button_Leg_Shaper.png", image: "WF/WF_304_Leg_Shaper.png", modestyImage: "WF/MaleOnly/WF_304_Leg_Shaper.png" }
var prog_tread_weightloss_hrc = { label: QT_TRANSLATE_NOOP("Menu", "Weight Loss HRC"),   desc: tread_weightloss_hrc_desc,  program: "Tread_HRC_Weight_Loss.xml",  icon: "WF/WF_Button_HRC.png", image: "WF/WF_305_307_Weight_Loss_Hrc.png",  modestyImage: "WF/MaleOnly/WF_305_307_Weight_Loss_Hrc.png" }

var menu_tread_weightloss = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "WEIGHT LOSS"), desc: desc_menu_weightloss,
        icon: "WF/WF_Button_Weight_Loss.png", navicon: "navbar/Navigation_WL", image: "WF/WF_203_Weight_Loss_Workout.png", modestyImage: "WF/MaleOnly/WF_203_Weight_Loss_Workout.png",
        children: [
            prog_tread_calorie_goal,
            prog_tread_weightloss_hills,
            prog_tread_glute_buster,
            prog_tread_leg_shaper,
            prog_tread_weightloss_hrc
        ]
    }
}

// ----- Tread Hill Workouts -----
var tread_rolling_hills_desc = QT_TRANSLATE_NOOP("Menu", "A series of gradual increasing and decreasing INCLINE changes that simulate rolling hills. Adjust your LEVEL at any time during the workout to increase or decrease intensity of the hills.")
var tread_single_hill_desc = QT_TRANSLATE_NOOP("Menu",  "INCLINE increases to a maximum at the midpoint of the workout, then decreases to the finish.  INCLINE changes affect the current segment only.  Speed changes are permanent.")
var tread_hill_intervals_desc = QT_TRANSLATE_NOOP("Menu",  "Hill Intervals are in 2-minute segments with the speed remaining constant.  Speed changes are permanent; incline changes affect the current 2-minute segment only.")
var tread_random_hills_desc = QT_TRANSLATE_NOOP("Menu", "A random profile of INCLINE changes that simulate random hills.  Adjust your LEVEL at any time during the workout to increase or decrease intensity of the hills.")

var prog_tread_rolling_hills = { label: QT_TRANSLATE_NOOP("Menu", "Rolling Hills"),  desc: tread_rolling_hills_desc, icon: "WF/WF_Button_Rolling_Hills.png", program: "Tread_Rolling_Hills.xml", image: "WF/WF_414_Rolling_Hills.png" }
var prog_tread_single_hill = { label: QT_TRANSLATE_NOOP("Menu", "Single Hill"), desc: tread_single_hill_desc,  icon: "WF/WF_Button_One_Big_Hill.png", program: "Tread_Single_Hill.xml", image: "WF/WF_415_Single_Hill.png",  modestyImage: "WF/MaleOnly/WF_415_Single_Hill.png" }
var prog_tread_hill_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Hill Intervals"), desc: tread_hill_intervals_desc, icon: "WF/WF_Button_Intervals.png", program: "Tread_Hill_Intervals.xml", image: "WF/WF_429_Hill_Intervals.png" }
var prog_tread_random_hills = { label: QT_TRANSLATE_NOOP("Menu", "Random Hills"), desc: tread_random_hills_desc, icon: "WF/WF_Button_Random_Hills.png", program: "Tread_Random_Hills.xml", image: "WF/WF_416_Random_Hills.png" }

var tread_hill_workouts_menu_desc = QT_TRANSLATE_NOOP("Menu", "A choice of workouts that use WORKLOAD changes to simulate hills. A great way to change up your cardio workout.")
var menu_tread_hills = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "HILL WORKOUTS"), desc: tread_hill_workouts_menu_desc,
        icon: "WF/WF_Button_Hill_Workout.png", navicon: "navbar/Navigation_Hill", image: "WF/WF_318_Hill_Workouts.png", modestyImage: "WF/MaleOnly/WF_318_Hill_Workouts.png",
        children: [
            prog_tread_rolling_hills,
            prog_tread_single_hill,
            prog_tread_hill_intervals,
            prog_shim,
            prog_shim
        ]
    }
}

// ----- Tread PERFORMANCE Programs -----
var desc_prog_tread_cardio_challenge = QT_TRANSLATE_NOOP("Menu", "Speed and incline increase to a maximum at the mid-point of the workout, then decrease to the finish.  Incline and speed changes affect the current segment only.")

var prog_tread_cardio_challange = { label: QT_TRANSLATE_NOOP("Menu", "Cardio Challenge"), desc: desc_prog_tread_cardio_challenge,  program: "Tread_Cardio_Challenge.xml", icon: "WF/WF_Button_Cardio_Challenge.png", image: "WF/WF_316_Cardio_Challenge.png", modestyImage: "WF/MaleOnly/WF_316_Cardio_Challenge.png" }
var prog_tread_distance = { label: QT_TRANSLATE_NOOP("Menu", "Distance"), desc: desc_prog_distance, program: "Tread_Distance.xml", icon: "WF/WF_Button_Distance_Workouts.png", image: "WF/WF_327_Distance_Workout.png" }
var prog_tread_distance_2mile = { label: QT_TRANSLATE_NOOP("Menu", "Distance 2 Mile"), desc: desc_prog_distance, program: "Tread_Distance2mi.xml", icon: "WF/WF_Button_Distance_Workouts.png", image: "WF/WF_327_Distance_Workout.png" }
var prog_tread_distance_4mile = { label: QT_TRANSLATE_NOOP("Menu", "Distance 4 Mile"), desc: desc_prog_distance, program: "Tread_Distance4mi.xml", icon: "WF/WF_Button_Distance_Workouts.png", image: "WF/WF_327_Distance_Workout.png" }
var prog_tread_distance_5k = { label: QT_TRANSLATE_NOOP("Menu", "Distance 5K"), desc: desc_prog_distance, program: "Tread_Distance5k.xml", icon: "WF/WF_Button_Distance_Workouts.png", image: "WF/WF_327_Distance_Workout.png" }
var prog_tread_distance_10k = { label: QT_TRANSLATE_NOOP("Menu", "Distance 10K"), desc: desc_prog_distance, program: "Tread_Distance10k.xml", icon: "WF/WF_Button_Distance_Workouts.png", image: "WF/WF_327_Distance_Workout.png" }

var menu_tread_performance = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "PERFORMANCE"), desc: desc_menu_performance,
        icon: "WF/WF_Button_Performance.png", navicon: "navbar/Navigation_Performance", image: "WF/WF_205_Performance.png",
        children: [
            prog_tread_cardio_challange,
            menu_tread_speed(),
            menu_tread_hills(),
            prog_tread_distance,
            menu_tread_fitness_tests()
        ]
    }
};

// ----- Tread CUSTOM Programs
var desc_prog_tread_custom_speed= QT_TRANSLATE_NOOP("Menu", "Set up your own speed intervals.  Up to 30 easy to adjust segments allow you to customize any speed profile.")
var desc_prog_tread_custom_hill = QT_TRANSLATE_NOOP("Menu", "Build your own HILL profile using up to 30 segments.  User friendly setup screens allow you to create any hill or incline profile.")
var desc_prog_tread_custom_ultra = QT_TRANSLATE_NOOP("Menu", "Do you have trouble finding a workout that fits your specific needs?  Try setting up your own!  This completely customizable workout setup allows both SPEED and INCLINE control of up to 30 segments.")
var desc_prog_tread_custom_hrc = QT_TRANSLATE_NOOP("Menu", "Set up your own heart rate intervals.  Specify WORK and REST targets and let the machine make all the adjustments." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var prog_tread_custom_speed = { label: QT_TRANSLATE_NOOP("Menu", "Custom Speed"),   desc: desc_prog_tread_custom_speed, program: "Tread_Custom_Speed.xml",  icon: "WF/WF_Button_Pace_Workout.png", image: "WF/WF_321_Custom_Pace.png", modestyImage: "WF/MaleOnly/WF_321_Custom_Pace.png" }
var prog_tread_custom_hill = { label: QT_TRANSLATE_NOOP("Menu", "Custom Hill"),   desc: desc_prog_tread_custom_hill, program: "Tread_Custom_Hills.xml",  icon: "WF/WF_Button_Hill_Workout.png", image: "WF/WF_322_Custom_Hills.png", modestyImage: "WF/MaleOnly/WF_322_Custom_Hills.png" }
var prog_tread_custom_ultra = { label: QT_TRANSLATE_NOOP("Menu", "Custom Ultra"),   desc: desc_prog_tread_custom_ultra, program: "Tread_Custom_Ultra.xml",  icon: "WF/WF_Button_Custom.png", image: "WF/WF_323_Custom_Ultra.png", modestyImage: "WF/MaleOnly/WF_323_Custom_Ultra.png" }
var prog_tread_custom_hrc = { label: QT_TRANSLATE_NOOP("Menu", "Custom HRC Intervals"),   desc: desc_prog_tread_custom_hrc, program: "Tread_Custom_HRC_Intervals.xml",  icon: "WF/WF_Button_HRC.png", image: "WF/WF_324_Custom_Hrc.png" }

var prog_tread_manual = { label: QT_TRANSLATE_NOOP("Menu", "Manual Workout"),   desc: desc_prog_manual, program: "Tread_Manual.xml", icon: "WF/WF_Button_Manual.png", image: "WF/WF_207_Manual_Workout.png", modestyImage: "WF/MaleOnly/WF_207_Manual_Workout.png" }

var menu_tread_custom = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "CUSTOM"), desc: desc_menu_custom,
        icon: "WF/WF_Button_Custom.png", navicon: "navbar/Navigation_Custom", image: "WF/WF_206_Custom_Workouts.png",  modestyImage: "WF/MaleOnly/WF_206_Custom_Workouts.png",
        children: [
            prog_tread_custom_speed,
            prog_tread_custom_hill,
            prog_tread_custom_ultra,
            prog_tread_custom_hrc,
            prog_saved
        ]
    }
}

// ----- Tread HRC Programs -----
var desc_prog_tread_hrc_target = QT_TRANSLATE_NOOP("Menu", "Choose your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_weightloss = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 65% of your maximum heart rate.  This creates efficient fat burning without overtraining." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_aerobic = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 80% of your maximum heart rate. This keeps you in the optimum aerobic training range to improve cardio fitness." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_distance = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")

var desc_prog_tread_hrc_distance_5k = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_distance_10k = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_distance_2mile = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_distance_4mile = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")

var desc_prog_tread_hrc_intervals = QT_TRANSLATE_NOOP("Menu","Intervals of WORK and REST determined by target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target." + "  " + "The rest segment will reduce to 65% intensity of work segment.")

var prog_tread_hrc_target = { label: QT_TRANSLATE_NOOP("Menu", "HRC Target"),  desc: desc_prog_tread_hrc_target, program: "Tread_HRC_Target.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_311_Target_Hrc.png" }
var prog_tread_hrc_weightloss = { label: QT_TRANSLATE_NOOP("Menu", "HRC Weight Loss"), desc: desc_prog_tread_hrc_weightloss, program: "Tread_HRC_Weight_Loss.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_310_Weight_Loss_Hrc.png", modestyImage: "WF/MaleOnly/WF_310_Weight_Loss_Hrc.png" }
var prog_tread_hrc_aerobic = { label: QT_TRANSLATE_NOOP("Menu", "HRC Aerobic"),  desc: desc_prog_tread_hrc_aerobic, program: "Tread_HRC_Aerobic.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_313_Aerobic_Hrc.png", modestyImage: "WF/MaleOnly/WF_313_Aerobic_Hrc.png" }
var prog_tread_hrc_distance = { label: QT_TRANSLATE_NOOP("Menu", "HRC Distance"), desc: desc_prog_tread_hrc_distance, program: "Tread_HRC_Distance.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png" }

var prog_tread_hrc_5k = {label: QT_TRANSLATE_NOOP("Menu", "HRC 5k"), desc: desc_prog_tread_hrc_distance_5k, program: "Tread_HRC_Distance5k.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png"}
var prog_tread_hrc_10k = {label: QT_TRANSLATE_NOOP("Menu", "HRC 10k"), desc: desc_prog_tread_hrc_distance_10k, program: "Tread_HRC_Distance10k.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png"}
var prog_tread_hrc_2mile = {label: QT_TRANSLATE_NOOP("Menu", "HRC 2 Mile"), desc: desc_prog_tread_hrc_distance_2mile, program: "Tread_HRC_Distance2mi.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png"}
var prog_tread_hrc_4mile = {label: QT_TRANSLATE_NOOP("Menu", "HRC 4 Mile"), desc: desc_prog_tread_hrc_distance_4mile, program: "Tread_HRC_Distance4mi.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png"}

var prog_tread_hrc_intervals = { label: QT_TRANSLATE_NOOP("Menu", "HRC Intervals"), desc: desc_prog_tread_hrc_intervals, program: "Tread_HRC_Intervals.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_315_Intervals_Hrc.png", modestyImage: "WF/MaleOnly/WF_315_Intervals_Hrc.png" }

var menu_tread_HRC = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "HEART RATE"), desc: desc_menu_hrc,
        icon: "WF/WF_Button_HRC.png", navicon: "navbar/Navigation_HRC", image: "WF/WF_204_Hrc_Workouts.png", modestyImage: "WF/MaleOnly/WF_204_Hrc_Workouts.png",
        children: [
            prog_tread_hrc_target,
            prog_tread_hrc_weightloss,
            prog_tread_hrc_aerobic,
            prog_tread_hrc_distance,
            prog_tread_hrc_intervals
        ]
    }
}

var menu_tread_top  = function() {
    return {
        desc: "workout finder", navicon: "navbar/Navigation_WF",
        children: [
            menu_tread_weightloss(),
            menu_tread_HRC(),
            menu_tread_performance(),
            menu_tread_custom(),
            prog_tread_manual
        ]
    }
};

var menu_tread_all = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "All Programs"),
        navicon: "navbar/Navigation_All_Presets",
        children: [
            prog_tread_manual,
            prog_tread_hrc_target,
            prog_tread_hrc_weightloss,
            prog_tread_hrc_aerobic,
            prog_tread_hrc_5k,
            prog_tread_hrc_10k,
            prog_tread_hrc_2mile,
            prog_tread_hrc_4mile,
            prog_tread_hrc_intervals,
            //prog_hrc_rx,
            prog_tread_calorie_goal,
            prog_tread_weightloss_hills,
            prog_tread_glute_buster,
            prog_tread_leg_shaper,
            //prog_tread_random_hills,
            prog_tread_rolling_hills,
            prog_tread_single_hill,
            prog_tread_hill_intervals,
            prog_tread_walkrun,
            prog_tread_speed_intervals,
            prog_tread_speed_ramp,
            prog_tread_cardio_challange,
            prog_tread_distance,
            prog_tread_distance_5k,
            prog_tread_distance_10k,
            prog_tread_distance_2mile,
            prog_tread_distance_4mile,
            prog_tread_fitness_test_gerkin,
            prog_tread_fitness_test_army,
            prog_tread_fitness_test_navy,
            prog_tread_fitness_test_airforce,
            prog_tread_fitness_test_marines,
            prog_tread_custom_speed,
            prog_tread_custom_hill,
            prog_tread_custom_ultra
        ]
    }
}

// ===== HILL Programs =====
var hill_workouts_desc = QT_TRANSLATE_NOOP("Menu", "A choice of workouts that use WORKLOAD changes to simulate hills. A great way to change up your cardio workout.")

var hill_intervals_desc = QT_TRANSLATE_NOOP("Menu",  "Hill intervals are in 2-minute segments with increased WORKLOAD to simulate hills.")
var single_hill_desc = QT_TRANSLATE_NOOP("Menu",  "WORKLOAD increases to a maximum at the midpoint of the workout, then decreases to the finish to simulate one big hill.")
var rolling_hills_desc = QT_TRANSLATE_NOOP("Menu", "A series of increasing and decreasing WORKLOAD changes that simulate rolling hills. Adjust your LEVEL at any time during the workout to increase or decrease intensity of the hills.")
var random_hills_desc = QT_TRANSLATE_NOOP("Menu", "A random profile of WORKLOAD changes that simulate random hills.  Adjust your LEVEL at any time during the workout to increase or decrease intensity of the hills.")

var prog_hill_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Hill Intervals"), program: "Hill_Intervals.xml", desc: hill_intervals_desc, icon: "WF/WF_Button_Intervals.png", image: "WF/WF_429_Hill_Intervals.png" }
var prog_single_hill = { label: QT_TRANSLATE_NOOP("Menu", "Single Hill"), desc: single_hill_desc,  icon: "WF/WF_Button_One_Big_Hill.png", program: "Single_Hill.xml", image: "WF/WF_415_Single_Hill.png", modestyImage: "WF/MaleOnly/WF_415_Single_Hill.png" }
var prog_rolling_hills = { label: QT_TRANSLATE_NOOP("Menu", "Rolling Hills"),  desc: rolling_hills_desc, icon: "WF/WF_Button_Rolling_Hills.png", program: "Rolling_Hills.xml", image: "WF/WF_414_Rolling_Hills.png" }
var prog_random_hills = { label: QT_TRANSLATE_NOOP("Menu", "Random Hills"), program: "Random_Hills.xml",  desc: random_hills_desc, icon: "WF/WF_Button_Random_Hills.png", image: "WF/WF_416_Random_Hills.png" }

// ===== PACE Programs =====
var pace_ramp_desc = QT_TRANSLATE_NOOP("Menu", "This workout suggests PACE (RPM) increases to a maximum at the mid-point of the workout, then decreases to the finish. The PACE SETTER shows your target pace throughout the workout.")
var pace_intervals_desc = QT_TRANSLATE_NOOP("Menu", "This workout suggests PACE (RPM) intervals in 1-minute segments. The PACE SETTER shows the target pace along with your actual pace (RPM) throughout the workout.")
var walkrun_desc = QT_TRANSLATE_NOOP("Menu", "This workout uses PACE SETTER to suggest walking then running intervals in 1-minute segments.  WORKLOAD can be adjusted throughout the workout.")

var prog_pace_ramp = { label: QT_TRANSLATE_NOOP("Menu", "Pace Ramp"),  desc:pace_ramp_desc, icon: "WF/WF_Button_Pace_Workout.png", program: "Pace_Ramp.xml", image: "WF/WF_412_Pace_Ramp.png", modestyImage: "WF/MaleOnly/WF_412_Pace_Ramp.png"}
var prog_pace_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Pace Intervals"), desc: pace_intervals_desc,  icon: "WF/WF_Button_Pace_Workout.png", program: "Pace_Intervals.xml", image: "WF/WF_413_Pace_Intervals.png",  modestyImage: "WF/MaleOnly/WF_413_Pace_Intervals.png"}
var prog_walkrun_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Walk&Run Intervals"), desc:walkrun_desc, icon: "WF/WF_Button_Walk_Run.png", program: "Walk_And_Run.xml", image: "WF/WF_411_Walk_Run.png", modestyImage: "WF/MaleOnly/WF_411_Walk_Run.png" }

// ====== PERFORMANCE Programs =======
var cardio_challenge_desc = QT_TRANSLATE_NOOP("Menu", "WORKLOAD and suggested PACE (RPM) increase to a maximum at the mid-point of the workout, then decrease to the finish.")
var pace_workouts_desc = QT_TRANSLATE_NOOP("Menu", "A choice of workouts that use PACE (RPM) suggestions to add variety to your cardio session.")
//var upper_body_desc = QT_TRANSLATE_NOOP("Menu", "An intense 10 minute workout that focuses on the upper body.")
var fitness_test_desc = QT_TRANSLATE_NOOP("Menu", "A fitness test used to estimate your VO2 max.")
var desc_prog_stride_intervals = QT_TRANSLATE_NOOP("Menu", "Set your own alternating WORK and REST stride length segments. Choose from short stepping to long striding motion, or anything in between. Intervals are 1 minute.")

var prog_cardio_challange = { label: QT_TRANSLATE_NOOP("Menu", "Cardio Challenge"), desc: cardio_challenge_desc,  program: "Cardio_Challenge.xml", icon: "WF/WF_Button_Cardio_Challenge.png", image: "WF/WF_316_Cardio_Challenge.png",  modestyImage: "WF/MaleOnly/WF_316_Cardio_Challenge.png" }
//var prog_upper_body = { label: QT_TRANSLATE_NOOP("Menu", "Upper Body"),   desc: upper_body_desc, icon: "WF/WF_Button_Performance.png" }
var prog_fitness_test = { label: QT_TRANSLATE_NOOP("Menu", "Fitness Test"), desc: fitness_test_desc,  program: "Fitness_Test.xml", icon: "WF/WF_Button_Fitness_Test.png", image: "WF/WF_320_Fitness_Test.png", modestyImage: "WF/MaleOnly/WF_320_Fitness_Test.png" }
var prog_stride_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Stride Intervals"), desc: desc_prog_stride_intervals, program: "Stride_Intervals.xml", icon: "WF/WF_Button_Walk_Run.png", image: "WF/WF_340_Stride_Intervals.png", modestyImage: "WF/WF_340_Stride_Intervals.png" }
var prog_distance_2mile = { label: QT_TRANSLATE_NOOP("Menu", "Distance 2 Mile"), desc: desc_prog_distance, program: "Distance2mi.xml", icon: "WF/WF_Button_Performance.png", image: "WF/WF_327_Distance_Workout.png" }
var prog_distance_4mile = { label: QT_TRANSLATE_NOOP("Menu", "Distance 4 Mile"), desc: desc_prog_distance, program: "Distance4mi.xml", icon: "WF/WF_Button_Performance.png", image: "WF/WF_327_Distance_Workout.png" }
var prog_distance_5k = { label: QT_TRANSLATE_NOOP("Menu", "Distance 5K"), desc: desc_prog_distance, program: "Distance5k.xml", icon: "WF/WF_Button_Performance.png", image: "WF/WF_327_Distance_Workout.png" }
var prog_distance_10k = { label: QT_TRANSLATE_NOOP("Menu", "Distance 10K"), desc: desc_prog_distance, program: "Distance10k.xml", icon: "WF/WF_Button_Performance.png", image: "WF/WF_327_Distance_Workout.png" }
var prog_stride_5k = { label: QT_TRANSLATE_NOOP("Menu", "Distance 5K"), desc: desc_prog_stride_5k, program: "Stride_Distance5k.xml", icon: "WF/WF_Button_Performance.png", image: "WF/WF_327_Distance_Workout.png" }


// ====== HRC Programs ======
var hrc_target_desc = QT_TRANSLATE_NOOP("Menu", "Choose your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_weightloss_desc = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 65% of your maximum heart rate.  This creates efficient fat burning without overtraining." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_aerobic_desc = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 80% of your maximum heart rate. This keeps you in the optimum aerobic training range to improve cardio fitness." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_distance_desc = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var hrc_distance_5k_desc = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_distance_10k_desc = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_distance_2mile_desc = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_distance_4mile_desc = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var hrc_intervals_desc = QT_TRANSLATE_NOOP("Menu","Intervals of WORK and REST determined by target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target." + "  " + "The rest segment will reduce to 65% intensity of work segment.")

var prog_hrc_target = { label: QT_TRANSLATE_NOOP("Menu", "HRC Target"),  desc: hrc_target_desc, program: "HRC_Target.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_311_Target_Hrc.png" }
var prog_hrc_weightloss = { label: QT_TRANSLATE_NOOP("Menu", "HRC Weight Loss"), desc: hrc_weightloss_desc, program: "HRC_Weight_Loss.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_310_Weight_Loss_Hrc.png",  modestyImage: "WF/MaleOnly/WF_310_Weight_Loss_Hrc.png" }
var prog_hrc_aerobic = { label: QT_TRANSLATE_NOOP("Menu", "HRC Aerobic"),  desc: hrc_aerobic_desc, program: "HRC_Aerobic.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_313_Aerobic_Hrc.png", modestyImage: "WF/MaleOnly/WF_313_Aerobic_Hrc.png" }
var prog_hrc_distance = { label: QT_TRANSLATE_NOOP("Menu", "HRC Distance"), desc: hrc_distance_desc, program: "HRC_Distance.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png" }

var prog_hrc_5k = {label: QT_TRANSLATE_NOOP("Menu", "HRC 5k"), desc: hrc_distance_5k_desc, program: "HRC_Distance5k.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png"}
var prog_hrc_10k = {label: QT_TRANSLATE_NOOP("Menu", "HRC 10k"), desc: hrc_distance_10k_desc, program: "HRC_Distance10k.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png"}
var prog_hrc_2mile = {label: QT_TRANSLATE_NOOP("Menu", "HRC 2 Mile"), desc: hrc_distance_2mile_desc, program: "HRC_Distance2mi.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png"}
var prog_hrc_4mile = {label: QT_TRANSLATE_NOOP("Menu", "HRC 4 Mile"), desc: hrc_distance_4mile_desc, program: "HRC_Distance4mi.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_314_Distance_Hrc.png"}

var prog_hrc_intervals = { label: QT_TRANSLATE_NOOP("Menu", "HRC Intervals"), desc: hrc_intervals_desc, program: "HRC_Intervals.xml", icon: "WF/WF_Button_HRC.png", image: "WF/WF_315_Intervals_Hrc.png", modestyImage: "WF/MaleOnly/WF_315_Intervals_Hrc.png" }

// ====== WEIGHTLOSS Programs ======

var calgoal_desc = QT_TRANSLATE_NOOP("Menu", "This workout allows you to choose the number of calories you wish to burn within a specified workout time.  The WORKLOAD will adjust automatically to attain this goal.")
var glutebuster_desc = QT_TRANSLATE_NOOP("Menu", "Changing workload focuses on intense glute muscle use.  For an added challenge, reverse the stride motion periodically.")
var legshaper_desc = QT_TRANSLATE_NOOP("Menu", "A workout that suggests pace changes to work the leg muscles with added intensity.  Reverse stride occasionally for an added challenge.")

var prog_calorie_goal = { label: QT_TRANSLATE_NOOP("Menu", "Calorie Goal"),   desc: calgoal_desc,  program: "Calorie_Goal.xml", icon: "WF/WF_Button_Calorie_Goal.png", image: "WF/WF_306_Calorie_Goal.png", modestyImage: "WF/MaleOnly/WF_306_Calorie_Goal.png" }
var prog_glutebuster = { label: QT_TRANSLATE_NOOP("Menu", "Glute Buster"),   desc: glutebuster_desc,  program: "Glute_Buster.xml",  icon: "WF/WF_Button_Glute_Buster.png", image: "WF/WF_308_Glute_Buster.png", modestyImage: "WF/MaleOnly/WF_308_Glute_Buster.png" }
var prog_legshaper = { label: QT_TRANSLATE_NOOP("Menu", "Leg Shaper"),   desc: legshaper_desc,  program: "Leg_Shaper.xml",  icon: "WF/WF_Button_Leg_Shaper.png", image: "WF/WF_309_Leg_Shaper.png", modestyImage: "WF/MaleOnly/WF_309_Leg_Shaper.png" }



// ====== Cardio360 Programs ======
var cardio360menu_desc = QT_TRANSLATE_NOOP("Menu", "Cardio360 coaches you through a dynamic total-body workout!")
var cardio360_desc = QT_TRANSLATE_NOOP("Menu", "If you're looking for variety to make your cardio workout fly, try this random cycle of Cardio360 exercises for a great total-body workout.")
var cardio360QS_desc = QT_TRANSLATE_NOOP("Menu", "Get right into a pre-set 20-minute workout designed to shape and tone every major muscle group.")
var cardio360video_desc = QT_TRANSLATE_NOOP("Menu", "Workout with an on-screen coach in real-time.  Cardio360 Video immerses you in a 20-minute full-body routine while allowing you to modify intensity.")
var cardio360arms_desc = QT_TRANSLATE_NOOP("Menu", "Challenge your upper body and core to this 10-minute, 3-motion program, following along at your own intensity.")
var cardio360legs_desc = QT_TRANSLATE_NOOP("Menu", "Tighten and tone your legs and glutes, changing resistance on the fly.")
var cardio360custom_desc = QT_TRANSLATE_NOOP("Menu", "Modify and maximize your workout to its fullest potential.  Cardio360 Custom lets you build a personalized routine, choosing your favorite Cardio360 motions and lengths of time.  Then save your set-up for next time.")

var prog_cardio360 = { label: QT_TRANSLATE_NOOP("Menu", "Cardio360"), desc: cardio360_desc, program: "Cardio_360.xml", icon: "WF/WF_Button_Cardio_360.png", image: "WF/WF_319_Cardio_360.png", modestyImage: "WF/MaleOnly/WF_319_Cardio_360.png" }
var prog_cardio360QS = { label: QT_TRANSLATE_NOOP("Menu", "Cardio360 QUICKSTART"), desc: cardio360QS_desc, program: "Cardio_360_Quick_Start.xml", icon: "WF/WF_Button_Cardio_360.png", image: "WF/WF_301_C360_Quick_Start.png" }
var prog_cardio360video = { label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Video"), desc: cardio360video_desc, program: "Cardio_360_Video.xml",icon: "WF/WF_Button_Cardio_360.png", image: "WF/WF_302_C360_Video.png" }
var prog_cardio360arms = { label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Arm Sculptor"), desc: cardio360arms_desc, program: "Cardio_360_Arm_Sculptor.xml", icon: "WF/WF_Button_Cardio_360.png", image: "WF/WF_303_C360_Arm_Sculptor.png" }
var prog_cardio360legs = { label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Leg Shaper"), desc: cardio360legs_desc, program: "Cardio_360_Leg_Shaper.xml", icon: "WF/WF_Button_Cardio_360.png", image: "WF/WF_304_C360_Leg_Shaper.png", modestyImage: "WF/MaleOnly/WF_304_C360_Leg_Shaper.png"  }
var prog_cardio360custom = { label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Custom"), desc: cardio360custom_desc, program: "Cardio360_Custom_Workout.xml", icon: "WF/WF_Button_Cardio_360.png", image: "WF/WF_305_C360_Custom.png" }

// ===== CUSTOM Programs ====
var custom_pace_desc = QT_TRANSLATE_NOOP("Menu", "Set up your own speed intervals.  Easy to change setup screens allow you to customize any PACE SETTER (RPM) profile to add variation to your cardio session.")
var custom_hill_desc = QT_TRANSLATE_NOOP("Menu", "Easy to change WORKLOAD interval workouts that simulate hills.  User friendly setup screens allow you to create any hill profile.")
var custom_ultra_desc = QT_TRANSLATE_NOOP("Menu", "Do you have trouble finding a workout that fits your specific needs?  Try setting up your own!  This completely customizable workout setup allows WORKLOAD and PACE SETTER interval control as well as the ability to control interval time.")
var custom_hrc_desc = QT_TRANSLATE_NOOP("Menu", "Set up your own heart rate intervals.  Specify WORK and REST targets and let the machine make all the adjustments." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var prog_custom_pace = { label: QT_TRANSLATE_NOOP("Menu", "Custom Pace"),   desc: custom_pace_desc, program: "Custom_Pace.xml", dummy: QT_TRANSLATE_NOOP("Menu", "Custom Pace"), icon: "WF/WF_Button_Pace_Workout.png", image: "WF/WF_321_Custom_Pace.png", modestyImage: "WF/MaleOnly/WF_321_Custom_Pace.png" }
var prog_custom_hill = { label: QT_TRANSLATE_NOOP("Menu", "Custom Hill"),   desc: custom_hill_desc, program: "Custom_Hills.xml",  dummy: QT_TRANSLATE_NOOP("Menu", "Custom Hills"), icon: "WF/WF_Button_Hill_Workout.png", image: "WF/WF_322_Custom_Hills.png", modestyImage: "WF/MaleOnly/WF_322_Custom_Hills.png" }
var prog_custom_ultra = { label: QT_TRANSLATE_NOOP("Menu", "Custom Ultra"),   desc: custom_ultra_desc, program: "Custom_Ultra.xml", dummy: QT_TRANSLATE_NOOP("Menu", "Custom Ultra"), icon: "WF/WF_Button_Custom.png", image: "WF/WF_323_Custom_Ultra.png", modestyImage: "WF/MaleOnly/WF_323_Custom_Ultra.png" }
var prog_custom_hrc = { label: QT_TRANSLATE_NOOP("Menu", "Custom HRC"),   desc: custom_hrc_desc, program: "Custom_HRC_Intervals.xml", dummy: QT_TRANSLATE_NOOP("Menu", "Custom HRC Intervals"), icon: "WF/WF_Button_HRC.png", image: "WF/WF_324_Custom_Hrc.png" }

var prog_manual = { label: QT_TRANSLATE_NOOP("Menu", "Manual Workout"),   desc: desc_prog_manual, program: "Manual.xml", icon: "WF/WF_Button_Manual.png", image: "WF/WF_207_Manual_Workout.png", modestyImage: "WF/MaleOnly/WF_207_Manual_Workout.png" }

// ===== Menus =====

var menu_hills = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "HILL WORKOUTS"), desc: hill_workouts_desc,
        icon: "WF/WF_Button_Hill_Workout.png", navicon: "navbar/Navigation_Hill", image: "WF/WF_318_Hill_Workouts.png", modestyImage: "WF/MaleOnly/WF_318_Hill_Workouts.png",
        children: [
            !main.isCSA ? prog_rolling_hills : null,
            !main.isCSA ? prog_single_hill : null,
            prog_hill_intervals,
            prog_random_hills,
            prog_shim
        ]
    }
}

var menu_elliptical_pace = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "PACE WORKOUTS"), desc: pace_workouts_desc,
        icon: "WF/WF_Button_Pace_Workout.png", navicon: "navbar/Navigation_Pace", image: "WF/WF_317_Pace_Workout.png", modestyImage: "WF/MaleOnly/WF_317_Pace_Workout.png",
        children: [
            !main.isCSA ? prog_walkrun_intervals : null,
            !main.isCSA ? prog_pace_ramp : null,
            prog_pace_intervals,
            prog_shim,
            prog_shim
        ]
    }
}

var menu_bike_pace = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "PACE WORKOUTS"), desc: pace_workouts_desc,
        icon: "WF/WF_Button_Pace_Workout.png", navicon: "navbar/Navigation_Pace", image: "WF/WF_317_Pace_Workout.png", modestyImage: "WF/MaleOnly/WF_317_Pace_Workout.png",
        children: [
            prog_shim,
            prog_pace_ramp,
            prog_pace_intervals,
            prog_shim,
            prog_shim
        ]
    }
}

var menu_HRC = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "HEART RATE"), desc: desc_menu_hrc,
        icon: "WF/WF_Button_HRC.png", navicon: "navbar/Navigation_HRC", image: "WF/WF_204_Hrc_Workouts.png", modestyImage: "WF/MaleOnly/WF_204_Hrc_Workouts.png",
        children: [
            prog_hrc_target,
            prog_hrc_weightloss,
            !main.isCSA ? prog_hrc_aerobic : null,
            prog_hrc_distance,
            !main.isCSA ? prog_hrc_intervals : null
        ]
    };
}

var menu_bike_HRC = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "HEART RATE"), desc: desc_menu_hrc,
        icon: "WF/WF_Button_HRC.png", navicon: "navbar/Navigation_HRC", image: "WF/WF_204_Hrc_Workouts.png", modestyImage: "WF/MaleOnly/WF_204_Hrc_Workouts.png",
        children: [
            prog_hrc_target,
            prog_hrc_weightloss,
            prog_hrc_aerobic,
            prog_hrc_distance,
            prog_hrc_intervals
        ]
    }
}


var menu_cardio360 = function()  {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "Cardio360"), desc: cardio360menu_desc,
        icon: "WF/WF_Button_Cardio_360.png", navicon: "navbar/Navigation_360", image: "WF/WF_202_Cardio_360_Workouts.png", modestyImage: "WF/MaleOnly/WF_202_Cardio_360_Workouts.png",

        children: [
            prog_cardio360QS,
            prog_cardio360,
            !main.isCSA ? prog_cardio360arms : null,
            !main.isCSA ? prog_cardio360legs : null,
            prog_cardio360custom,
        ]
    };
};


var menu_bike_performance = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "PERFORMANCE"), desc: desc_menu_performance,
        icon: "WF/WF_Button_Performance.png", navicon: "navbar/Navigation_Performance", image: "WF/WF_205_Performance.png",
        children: [
            prog_cardio_challange,
            menu_bike_pace(),
            menu_hills(),
            prog_fitness_test,
            prog_shim
        ]
    }
};

var menu_elliptical_performance = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "PERFORMANCE"), desc: desc_menu_performance,
        icon: "WF/WF_Button_Performance.png", navicon: "navbar/Navigation_Performance", image: "WF/WF_205_Performance.png",
        children: [
            !main.isCSA ? prog_cardio_challange : null,
            menu_elliptical_pace(),
            menu_hills(),
            prog_cardio360,
            prog_fitness_test,
            main.isCSA ? prog_stride_intervals : null
        ]
    };
}


var menu_bike_weightloss = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "WEIGHT LOSS"), desc: desc_menu_weightloss,
        icon: "WF/WF_Button_Weight_Loss.png", navicon: "navbar/Navigation_WL", image: "WF/WF_203_Weight_Loss_Workout.png", modestyImage: "WF/MaleOnly/WF_203_Weight_Loss_Workout.png",
        children: [
            prog_calorie_goal,
            prog_glutebuster,
            prog_legshaper,
            prog_hrc_weightloss,
            prog_shim
        ]
    }
}

var menu_elliptical_weightloss = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "WEIGHT LOSS"), desc: desc_menu_weightloss,
        icon: "WF/WF_Button_Weight_Loss.png", navicon: "navbar/Navigation_WL", image: "WF/WF_203_Weight_Loss_Workout.png", modestyImage: "WF/MaleOnly/WF_203_Weight_Loss_Workout.png",
        children: [
            prog_calorie_goal,
            prog_cardio360QS,
            prog_glutebuster,
            prog_legshaper,
            prog_hrc_weightloss
        ]
    };
}

var menu_elliptical_custom = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "CUSTOM"), desc: desc_menu_custom,
        icon: "WF/WF_Button_Custom.png", navicon: "navbar/Navigation_Custom", image: "WF/WF_206_Custom_Workouts.png", modestyImage: "WF/MaleOnly/WF_206_Custom_Workouts.png",
        children: [
            !main.isCSA ? prog_custom_pace : null,
            !main.isCSA ? prog_custom_hill : null,
            prog_custom_ultra,
            prog_custom_hrc,
            prog_saved
        ]
    };
}
var menu_bike_custom = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "CUSTOM"), desc: desc_menu_custom,
        icon: "WF/WF_Button_Custom.png", navicon: "navbar/Navigation_Custom", image: "WF/WF_206_Custom_Workouts.png", modestyImage: "WF/MaleOnly/WF_206_Custom_Workouts.png",
        children: [
            prog_custom_pace,
            prog_custom_hill,
            prog_custom_ultra,
            prog_custom_hrc,
            prog_saved
        ]
    }
}


var menu_bike_top  = function() {
    return {
        desc: "workout finder", navicon: "navbar/Navigation_WF",
        children: [
            menu_bike_weightloss(),
            menu_bike_HRC(),
            menu_bike_performance(),
            menu_bike_custom(),
            prog_manual,
        ]
    }
}

var menu_elliptical_top = function() {
    return {
        desc: "workout finder", navicon: "navbar/Navigation_WF",
        children: [
            menu_cardio360(),
            menu_elliptical_weightloss(),
            menu_HRC(),
            menu_elliptical_performance(),
            menu_elliptical_custom(),
            prog_manual
        ]
    };
};

var menu_bike_all = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "All Programs"),
        navicon: "navbar/Navigation_All_Presets",
        children: [
            prog_manual,
            prog_hrc_target,
            prog_hrc_weightloss,
            prog_hrc_aerobic,
            prog_hrc_5k,
            prog_hrc_10k,
            prog_hrc_2mile,
            prog_hrc_4mile,
            prog_hrc_intervals,
            prog_custom_hrc,
            prog_calorie_goal,
            prog_glutebuster,
            prog_legshaper,
            prog_rolling_hills,
            prog_single_hill,
            prog_hill_intervals,
            prog_random_hills,
            prog_pace_intervals,
            prog_pace_ramp,
            prog_custom_pace,
            prog_custom_hill,
            prog_custom_ultra,
            prog_cardio_challange,
            //prog_distance,
            prog_distance_5k,
            prog_distance_10k,
            prog_distance_2mile,
            prog_distance_4mile,

        ]
    }
}

var menu_csa_all = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "All Programs"),
        navicon: "navbar/Navigation_All_Presets",
        children: [
            prog_cardio360,
            prog_cardio360custom,
            prog_stride_intervals,
            prog_calorie_goal,
            prog_glutebuster,
            prog_legshaper,
            prog_hrc_weightloss,
            prog_hrc_target,
            prog_custom_hrc,
            prog_hill_intervals,
            prog_random_hills,
            prog_pace_intervals,
            prog_manual,
            prog_stride_5k,
            prog_fitness_test,
            prog_custom_ultra,
            options.saveWorkoutEnabled ? prog_saved : null,
            main.isCSA ? prog_shim : null
        ]
    }
}

var menu_elliptical_all = function() {
    return {
        label: QT_TRANSLATE_NOOP("Menu", "All Programs"),
        navicon: "navbar/Navigation_All_Presets",
        children: [
            prog_manual,
            prog_cardio360,
            prog_cardio360arms,
            prog_cardio360legs,
            prog_cardio360custom,
            prog_cardio360QS,
            prog_hrc_target,
            prog_hrc_weightloss,
            prog_hrc_aerobic,
            prog_hrc_5k,
            prog_hrc_10k,
            prog_hrc_2mile,
            prog_hrc_4mile,
            prog_hrc_intervals,
            prog_calorie_goal,
            prog_glutebuster,
            prog_legshaper,
            prog_rolling_hills,
            prog_single_hill,
            prog_hill_intervals,
            prog_random_hills,
            prog_walkrun_intervals,
            prog_pace_intervals,
            prog_pace_ramp,
            prog_custom_pace,
            prog_custom_hill,
            prog_custom_ultra,
            prog_custom_hrc,
            prog_cardio_challange,
            prog_distance_5k,
            prog_distance_10k,
            prog_distance_2mile,
            prog_distance_4mile,
            prog_fitness_test,
            options.saveWorkoutEnabled ? prog_saved : null
        ]
    }
}

