#!/usr/bin/env python

import subprocess
import sys
import shlex
import fcntl
from threading import Thread
import os
import hashlib

def md5sum(s):
  return hashlib.md5(s).hexdigest()

def print_out(s):
  sys.stdout.write( s)
  sys.stdout.flush()

def read_data(stdout, stderr):
  while True:
    data = non_block_read(stdout).strip()
    err = non_block_read(stderr).strip()
    if data != '':
      print_out( '>>stdout\n')
      print_out( '%s\n' % data)
    if err != '':
      print_out( '>>stderr\n')
      print_out( '%s\n' % err)

def non_block_read(output):
    ''' even in a thread, a normal read with block until the buffer is full '''
    fd = output.fileno()
    fl = fcntl.fcntl(fd, fcntl.F_GETFL)
    fcntl.fcntl(fd, fcntl.F_SETFL, fl | os.O_NONBLOCK)
    try:
        return output.read()
    except:
        return ''

if __name__ == '__main__':
  args = shlex.split(sys.argv[1])
  #filename is md5 sum of command and arguments, to be unique
  fname = md5sum(sys.argv[1])+'.out'
  proc = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
  thread = Thread(target=read_data, args=[proc.stdout, proc.stderr])
  thread.daemon = True
  thread.start()
  
  proc.wait()
  thread.join(timeout=1)

